@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: tr-window.h 13625 2012-12-05 17:29:46Z jordan $
- *
  * Copyright (c) Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -22,15 +20,12 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
-#ifndef GTR_WINDOW_H
-#define GTR_WINDOW_H
+#pragma once
 
 #include <gtk/gtk.h>
 #include "tr-core.h"
 
-GtkWidget        * gtr_window_new (GtkApplication * app, GtkUIManager * uim, TrCore * core);
-GtkTreeSelection * gtr_window_get_selection (GtkWindow *);
-void               gtr_window_set_busy (GtkWindow *, gboolean isBusy);
-void               gtr_window_refresh (GtkWindow *);
-
-#endif /* GTR_WINDOW_H */
+GtkWidget* gtr_window_new(GtkApplication* app, GtkUIManager* uim, TrCore* core);
+GtkTreeSelection* gtr_window_get_selection(GtkWindow*);
+void gtr_window_set_busy(GtkWindow*, gboolean isBusy);
+void gtr_window_refresh(GtkWindow*);
