@@ -4,20 +4,16 @@
  * It may be used under the GNU GPL versions 2 or 3
  * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: clients.h 14241 2014-01-21 03:10:30Z jordan $
  */
 
-#ifndef __TRANSMISSION__
- #error only libtransmission should #include this header.
-#endif
+#pragma once
 
-#ifndef TR_CLIENTS_H
-#define TR_CLIENTS_H
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
 
 /**
  * @brief parse a peer-id into a human-readable client name and version number
  * @ingroup utils
  */
-char* tr_clientForId (char * buf, size_t buflen, const void * peer_id);
-
-#endif
+char* tr_clientForId(char* buf, size_t buflen, void const* peer_id);
