@@ -1,21 +1,16 @@
 /*
- * This file Copyright (C) Mnemosyne LLC
+ * This file Copyright (C) 2007-2014 Mnemosyne LLC
  *
- * This file is licensed by the GPL version 2. Works owned by the
- * Transmission project are granted a special exemption to clause 2 (b)
- * so that the bulk of its code can remain under the MIT license.
- * This exemption does not extend to derived works not owned by
- * the Transmission project.
+ * It may be used under the GNU GPL versions 2 or 3
+ * or any future license endorsed by Mnemosyne LLC.
  *
- * $Id: list.h 13625 2012-12-05 17:29:46Z jordan $
  */
 
-#ifndef __TRANSMISSION__
- #error only libtransmission should #include this header.
-#endif
+#pragma once
 
-#ifndef TR_LIST_H
-#define TR_LIST_H
+#ifndef __TRANSMISSION__
+#error only libtransmission should #include this header.
+#endif
 
 /**
  * @addtogroup utils Utilities
@@ -27,48 +22,48 @@
 /** @brief simple list structure similar to glib's GList */
 typedef struct tr_list
 {
-    void *  data;
-    struct tr_list  * next;
-    struct tr_list  * prev;
+    void* data;
+    struct tr_list* next;
+    struct tr_list* prev;
 }
 tr_list;
 
-typedef int (*TrListCompareFunc)(const void * a, const void * b);
-typedef void (*TrListForeachFunc)(void *);
+typedef tr_voidptr_compare_func TrListCompareFunc;
+typedef void (* TrListForeachFunc)(void*);
 
 /**
  * @brief return the number of items in the list
  * @return the number of items in the list
  */
-int      tr_list_size (const tr_list * list);
+int tr_list_size(tr_list const* list);
 
 /**
  * @brief free the specified list and set its pointer to NULL
  * @param list pointer to the list to be freed
  * @param func optional function to invoke on each item in the list
  */
-void     tr_list_free (tr_list ** list, TrListForeachFunc data_free_func);
+void tr_list_free(tr_list** list, TrListForeachFunc data_free_func);
 
 /**
  * @brief append an item to the specified list
  * @param list pointer to the list
  * @param item the item to append
  */
-void tr_list_append (tr_list ** list, void * data);
+void tr_list_append(tr_list** list, void* data);
 
 /**
  * @brief prepend an item to the specified list
  * @param list pointer to the list
  * @param item the item to prepend
  */
-void tr_list_prepend (tr_list ** list, void * data);
+void tr_list_prepend(tr_list** list, void* data);
 
 /**
  * @brief remove the next item in the list
  * @return the next item in the list, or NULL if the list is empty
  * @param list pointer to the list
  */
-void* tr_list_pop_front (tr_list ** list);
+void* tr_list_pop_front(tr_list** list);
 
 /**
  * @brief remove the list's node that contains the specified data pointer
@@ -76,7 +71,7 @@ void* tr_list_pop_front (tr_list ** list);
  * @param data data to remove
  * @return the removed data pointer, or NULL if no match was found
  */
-void* tr_list_remove_data (tr_list ** list, const void * data);
+void* tr_list_remove_data(tr_list** list, void const* data);
 
 /**
  * @brief remove the list's node that compares equal to "b" when compared with "compare_func"
@@ -85,9 +80,7 @@ void* tr_list_remove_data (tr_list ** list, const void * data);
  * @param compare_func the comparison function. The arguments passed to it will be the list's pointers and the comparison key "b"
  * @return the removed data pointer, or NULL if no match was found
  */
-void*    tr_list_remove (tr_list **        list,
-                         const void *      b,
-                         TrListCompareFunc compare_func);
+void* tr_list_remove(tr_list** list, void const* b, TrListCompareFunc compare_func);
 
 /**
  * @brief find the list node whose data that compares equal to "b" when compared with "compare_func"
@@ -96,9 +89,7 @@ void*    tr_list_remove (tr_list **        list,
  * @param compare_func the comparison function. The arguments passed to it will be the list's pointers and the comparison key "b"
  * @return the matching list node, or NULL if not match was found
  */
-tr_list* tr_list_find (tr_list *         list,
-                       const void *      b,
-                       TrListCompareFunc compare_func);
+tr_list* tr_list_find(tr_list* list, void const* b, TrListCompareFunc compare_func);
 
 /**
  * @brief Insert in an ordered list
@@ -106,12 +97,6 @@ tr_list* tr_list_find (tr_list *         list,
  * @param item the item to be inserted
  * @param compare the comparison function.
  */
-void tr_list_insert_sorted (tr_list          ** list,
-                            void              * data,
-                            TrListCompareFunc   compare);
-
-
+void tr_list_insert_sorted(tr_list** list, void* data, TrListCompareFunc compare);
 
 /* @} */
-#endif /* TR_LIST_H */
-
