@@ -19,31 +19,30 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  * THE SOFTWARE.
  *
- * $Id: tr-dht.h 13625 2012-12-05 17:29:46Z jordan $
  *
  */
 
+#pragma once
+
 #ifndef __TRANSMISSION__
- #error only libtransmission should #include this header.
+#error only libtransmission should #include this header.
 #endif
 
 enum
 {
-    TR_DHT_STOPPED      = 0,
-    TR_DHT_BROKEN       = 1,
-    TR_DHT_POOR         = 2,
-    TR_DHT_FIREWALLED   = 3,
-    TR_DHT_GOOD         = 4
+    TR_DHT_STOPPED = 0,
+    TR_DHT_BROKEN = 1,
+    TR_DHT_POOR = 2,
+    TR_DHT_FIREWALLED = 3,
+    TR_DHT_GOOD = 4
 };
 
-int  tr_dhtInit (tr_session *);
-void tr_dhtUninit (tr_session *);
-bool tr_dhtEnabled (const tr_session *);
-tr_port tr_dhtPort (tr_session *);
-int tr_dhtStatus (tr_session *, int af, int * setme_nodeCount);
-const char *tr_dhtPrintableStatus (int status);
-int tr_dhtAddNode (tr_session *, const tr_address *, tr_port, bool bootstrap);
-void tr_dhtUpkeep (tr_session *);
-void tr_dhtCallback (unsigned char *buf, int buflen,
-                    struct sockaddr *from, socklen_t fromlen,
-                    void *sv);
+int tr_dhtInit(tr_session*);
+void tr_dhtUninit(tr_session*);
+bool tr_dhtEnabled(tr_session const*);
+tr_port tr_dhtPort(tr_session*);
+int tr_dhtStatus(tr_session*, int af, int* setme_nodeCount);
+char const* tr_dhtPrintableStatus(int status);
+bool tr_dhtAddNode(tr_session*, tr_address const*, tr_port, bool bootstrap);
+void tr_dhtUpkeep(tr_session*);
+void tr_dhtCallback(unsigned char* buf, int buflen, struct sockaddr* from, socklen_t fromlen, void* sv);
