@@ -23,23 +23,22 @@ THE SOFTWARE.
 /* ansi */
 #include <errno.h>
 #include <stdio.h>
-#include <string.h> /* strlen (), strncpy (), strstr (), memset () */
+#include <string.h> /* strlen(), strncpy(), strstr(), memset() */
 
 /* posix */
 #include <signal.h> /* sig_atomic_t */
-#include <sys/time.h>
-#include <unistd.h> /* close () */
-#include <ctype.h> /* toupper () */
-#ifdef WIN32
-  #include <w32api.h>
-  #define WINDOWS  WindowsXP  /* freeaddrinfo (),getaddrinfo (),getnameinfo () */
-  #include <inttypes.h>
-  #include <ws2tcpip.h>
-  typedef uint16_t in_port_t;			/* all missing */
+#include <ctype.h> /* toupper() */
+
+#ifdef _WIN32
+#include <inttypes.h>
+#include <ws2tcpip.h>
+typedef uint16_t in_port_t; /* all missing */
 #else
-  #include <sys/types.h>
-  #include <sys/socket.h> /* socket (), bind () */
-  #include <netinet/in.h> /* sockaddr_in */
+#include <sys/time.h>
+#include <unistd.h> /* close() */
+#include <sys/types.h>
+#include <sys/socket.h> /* socket(), bind() */
+#include <netinet/in.h> /* sockaddr_in */
 #endif
 
 /* third party */
@@ -50,9 +49,10 @@ THE SOFTWARE.
 #include "transmission.h"
 #include "log.h"
 #include "net.h"
-#include "peer-mgr.h" /* tr_peerMgrAddPex () */
+#include "peer-mgr.h" /* tr_peerMgrAddPex() */
 #include "session.h"
-#include "torrent.h" /* tr_torrentFindFromHash () */
+#include "torrent.h" /* tr_torrentFindFromHash() */
+#include "tr-assert.h"
 #include "tr-lpd.h"
 #include "utils.h"
 #include "version.h"
@@ -64,37 +64,44 @@ THE SOFTWARE.
 * This module implements the Local Peer Discovery (LPD) protocol as supported by the
 * uTorrent client application. A typical LPD datagram is 119 bytes long.
 *
-* $Id: tr-lpd.c 14192 2013-09-08 17:58:14Z jordan $
 */
 
-static void event_callback (evutil_socket_t, short, void*);
+static void event_callback(evutil_socket_t, short, void*);
 
-enum {
-   UPKEEP_INTERVAL_SECS = 5
+enum
+{
+    UPKEEP_INTERVAL_SECS = 5
 };
-static struct event * upkeep_timer = NULL;
 
-static int lpd_socket; /**<separate multicast receive socket */
-static int lpd_socket2; /**<and multicast send socket */
-static struct event * lpd_event = NULL;
+static struct event* upkeep_timer = NULL;
+
+static tr_socket_t lpd_socket; /**<separate multicast receive socket */
+static tr_socket_t lpd_socket2; /**<and multicast send socket */
+static struct event* lpd_event = NULL;
 static tr_port lpd_port;
 
 static tr_torrent* lpd_torStaticType UNUSED; /* just a helper for static type analysis */
 static tr_session* session;
 
-enum { lpd_maxDatagramLength = 200 }; /**<the size an LPD datagram must not exceed */
-const char lpd_mcastGroup[] = "239.192.152.143"; /**<LPD multicast group */
-const int lpd_mcastPort = 6771; /**<LPD source and destination UPD port */
+enum
+{
+    lpd_maxDatagramLength = 200 /**<the size an LPD datagram must not exceed */
+};
+
+char const lpd_mcastGroup[] = "239.192.152.143"; /**<LPD multicast group */
+int const lpd_mcastPort = 6771; /**<LPD source and destination UPD port */
 static struct sockaddr_in lpd_mcastAddr; /**<initialized from the above constants in tr_lpdInit */
 
 /**
 * @brief Protocol-related information carried by a Local Peer Discovery packet */
 struct lpd_protocolVersion
 {
-    int major, minor;
+    int major;
+    int minor;
 };
 
-enum lpd_enumTimeToLive {
+enum lpd_enumTimeToLive
+{
     lpd_ttlSameSubnet = 1,
     lpd_ttlSameSite = 32,
     lpd_ttlSameRegion = 64,
@@ -102,12 +109,12 @@ enum lpd_enumTimeToLive {
     lpd_ttlUnrestricted = 255
 };
 
-enum {
+enum
+{
     lpd_announceInterval = 4 * 60, /**<4 min announce interval per torrent */
     lpd_announceScope = lpd_ttlSameSubnet /**<the maximum scope for LPD datagrams */
 };
 
-
 /**
 * @defgroup DoS Message Flood Protection
 * @{
@@ -126,7 +133,10 @@ enum {
 * @ingroup DoS
 * @brief allow at most ten messages per second (interval average)
 * @note this constraint is only enforced once per housekeeping interval */
-enum { lpd_announceCapFactor = 10 };
+enum
+{
+    lpd_announceCapFactor = 10
+};
 
 /**
 * @ingroup DoS
@@ -139,7 +149,6 @@ static int lpd_unsolicitedMsgCounter;
 * @brief a line-feed, as understood by the LPD protocol */
 #define CRLF "\r\n"
 
-
 /**
 * @defgroup HttpReqProc HTTP-style request handling
 * @{
@@ -160,32 +169,40 @@ static int lpd_unsolicitedMsgCounter;
 * If parameter is not NULL, the declared protocol version is returned as part of
 * the lpd_protocolVersion structure.
 */
-static const char* lpd_extractHeader (const char* s, struct lpd_protocolVersion* const ver)
+static char const* lpd_extractHeader(char const* s, struct lpd_protocolVersion* const ver)
 {
-    int major = -1, minor = -1;
-    size_t len;
+    TR_ASSERT(s != NULL);
 
-    assert (s != NULL);
-    len = strlen (s);
+    int major = -1;
+    int minor = -1;
+    size_t len = strlen(s);
 
     /* something might be rotten with this chunk of data */
     if (len == 0 || len > lpd_maxDatagramLength)
+    {
         return NULL;
+    }
 
     /* now we can attempt to look up the BT-SEARCH header */
-    if (sscanf (s, "BT-SEARCH * HTTP/%d.%d" CRLF, &major, &minor) != 2)
+    if (sscanf(s, "BT-SEARCH * HTTP/%d.%d" CRLF, &major, &minor) != 2)
+    {
         return NULL;
+    }
 
     if (major < 0 || minor < 0)
+    {
         return NULL;
+    }
 
     {
         /* a pair of blank lines at the end of the string, no place else */
-        const char* const two_blank = CRLF CRLF CRLF;
-        const char* const end = strstr (s, two_blank);
+        char const* const two_blank = CRLF CRLF CRLF;
+        char const* const end = strstr(s, two_blank);
 
-        if (end == NULL || strlen (end) > strlen (two_blank))
+        if (end == NULL || strlen(end) > strlen(two_blank))
+        {
             return NULL;
+        }
     }
 
     if (ver != NULL)
@@ -195,7 +212,7 @@ static const char* lpd_extractHeader (const char* s, struct lpd_protocolVersion*
     }
 
     /* separate the header, begins with CRLF */
-    return strstr (s, CRLF);
+    return strstr(s, CRLF);
 }
 
 /**
@@ -212,29 +229,39 @@ static const char* lpd_extractHeader (const char* s, struct lpd_protocolVersion*
 *   - assemble search string "\r\nName: " and locate position
 *   - copy back value from end to next "\r\n"
 */
-static int lpd_extractParam (const char* const str, const char* const name, int n, char* const val)
+static bool lpd_extractParam(char const* const str, char const* const name, int n, char* const val)
 {
-    /* configure maximum length of search string here */
-    enum { maxLength = 30 };
+    TR_ASSERT(str != NULL);
+    TR_ASSERT(name != NULL);
+    TR_ASSERT(val != NULL);
+
+    enum
+    {
+        /* configure maximum length of search string here */
+        maxLength = 30
+    };
+
     char sstr[maxLength] = { 0 };
-    const char* pos;
+    char const* pos;
 
-    assert (str != NULL && name != NULL);
-    assert (val != NULL);
-
-    if (strlen (name) > maxLength - strlen (CRLF ": "))
-        return 0;
+    if (strlen(name) > maxLength - strlen(CRLF ": "))
+    {
+        return false;
+    }
 
     /* compose the string token to search for */
-    tr_snprintf (sstr, maxLength, CRLF "%s: ", name);
+    tr_snprintf(sstr, maxLength, CRLF "%s: ", name);
+
+    pos = strstr(str, sstr);
 
-    pos = strstr (str, sstr);
     if (pos == NULL)
-        return 0; /* search was not successful */
+    {
+        return false; /* search was not successful */
+    }
 
     {
-        const char* const beg = pos + strlen (sstr);
-        const char* const new_line = strstr (beg, CRLF);
+        char const* const beg = pos + strlen(sstr);
+        char const* const new_line = strstr(beg, CRLF);
 
         /* the value is delimited by the next CRLF */
         int len = new_line - beg;
@@ -242,20 +269,22 @@ static int lpd_extractParam (const char* const str, const char* const name, int
         /* if value string hits the length limit n,
          * leave space for a trailing '\0' character */
         if (len < n--)
+        {
             n = len;
+        }
 
-        strncpy (val, beg, n);
+        strncpy(val, beg, n);
         val[n] = 0;
     }
 
     /* we successfully returned the value string */
-    return 1;
+    return true;
 }
 
 /**
 * @} */
 
-static void on_upkeep_timer (evutil_socket_t, short, void *);
+static void on_upkeep_timer(evutil_socket_t, short, void*);
 
 /**
 * @brief Initializes Local Peer Discovery for this node
@@ -266,79 +295,104 @@ static void on_upkeep_timer (evutil_socket_t, short, void *);
 * @remark Since the LPD service does not use another protocol family yet, this code is
 * IPv4 only for the time being.
 */
-int tr_lpdInit (tr_session* ss, tr_address* tr_addr UNUSED)
+int tr_lpdInit(tr_session* ss, tr_address* tr_addr UNUSED)
 {
     struct ip_mreq mcastReq;
-    const int opt_on = 1, opt_off = 0;
+    int const opt_on = 1;
+    int const opt_off = 0;
 
-    if (session) /* already initialized */
+    if (session != NULL) /* already initialized */
+    {
         return -1;
+    }
 
-    assert (lpd_announceInterval > 0);
-    assert (lpd_announceScope > 0);
+    TR_ASSERT(lpd_announceInterval > 0);
+    TR_ASSERT(lpd_announceScope > 0);
+
+    lpd_port = tr_sessionGetPeerPort(ss);
 
-    lpd_port = tr_sessionGetPeerPort (ss);
     if (lpd_port <= 0)
+    {
         return -1;
+    }
 
-    tr_logAddNamedDbg ("LPD", "Initialising Local Peer Discovery");
+    tr_logAddNamedDbg("LPD", "Initialising Local Peer Discovery");
 
     /* setup datagram socket (receive) */
     {
-        lpd_socket = socket (PF_INET, SOCK_DGRAM, 0);
-        if (lpd_socket < 0)
-            goto fail;
+        lpd_socket = socket(PF_INET, SOCK_DGRAM, 0);
 
-        if (evutil_make_socket_nonblocking (lpd_socket) < 0)
+        if (lpd_socket == TR_BAD_SOCKET)
+        {
             goto fail;
+        }
 
-        if (setsockopt (lpd_socket, SOL_SOCKET, SO_REUSEADDR,
-                &opt_on, sizeof opt_on) < 0)
+        if (evutil_make_socket_nonblocking(lpd_socket) == -1)
+        {
             goto fail;
+        }
 
-        memset (&lpd_mcastAddr, 0, sizeof lpd_mcastAddr);
+        if (setsockopt(lpd_socket, SOL_SOCKET, SO_REUSEADDR, (void const*)&opt_on, sizeof(opt_on)) == -1)
+        {
+            goto fail;
+        }
+
+        memset(&lpd_mcastAddr, 0, sizeof(lpd_mcastAddr));
         lpd_mcastAddr.sin_family = AF_INET;
-        lpd_mcastAddr.sin_port = htons (lpd_mcastPort);
-        if (evutil_inet_pton (lpd_mcastAddr.sin_family, lpd_mcastGroup,
-                &lpd_mcastAddr.sin_addr) < 0)
-            goto fail;
+        lpd_mcastAddr.sin_port = htons(lpd_mcastPort);
 
-        if (bind (lpd_socket, (struct sockaddr*) &lpd_mcastAddr,
-                sizeof lpd_mcastAddr) < 0)
+        if (evutil_inet_pton(lpd_mcastAddr.sin_family, lpd_mcastGroup, &lpd_mcastAddr.sin_addr) == -1)
+        {
             goto fail;
+        }
+
+        if (bind(lpd_socket, (struct sockaddr*)&lpd_mcastAddr, sizeof(lpd_mcastAddr)) == -1)
+        {
+            goto fail;
+        }
 
         /* we want to join that LPD multicast group */
-        memset (&mcastReq, 0, sizeof mcastReq);
+        memset(&mcastReq, 0, sizeof(mcastReq));
         mcastReq.imr_multiaddr = lpd_mcastAddr.sin_addr;
-        mcastReq.imr_interface.s_addr = htonl (INADDR_ANY);
-        if (setsockopt (lpd_socket, IPPROTO_IP, IP_ADD_MEMBERSHIP,
-                &mcastReq, sizeof mcastReq) < 0)
-            goto fail;
+        mcastReq.imr_interface.s_addr = htonl(INADDR_ANY);
 
-        if (setsockopt (lpd_socket, IPPROTO_IP, IP_MULTICAST_LOOP,
-                &opt_off, sizeof opt_off) < 0)
+        if (setsockopt(lpd_socket, IPPROTO_IP, IP_ADD_MEMBERSHIP, (void const*)&mcastReq, sizeof(mcastReq)) == -1)
+        {
             goto fail;
+        }
+
+        if (setsockopt(lpd_socket, IPPROTO_IP, IP_MULTICAST_LOOP, (void const*)&opt_off, sizeof(opt_off)) == -1)
+        {
+            goto fail;
+        }
     }
 
     /* setup datagram socket (send) */
     {
-        const unsigned char scope = lpd_announceScope;
+        unsigned char const scope = lpd_announceScope;
 
-        lpd_socket2 = socket (PF_INET, SOCK_DGRAM, 0);
-        if (lpd_socket2 < 0)
-            goto fail;
+        lpd_socket2 = socket(PF_INET, SOCK_DGRAM, 0);
 
-        if (evutil_make_socket_nonblocking (lpd_socket2) < 0)
+        if (lpd_socket2 == TR_BAD_SOCKET)
+        {
             goto fail;
+        }
+
+        if (evutil_make_socket_nonblocking(lpd_socket2) == -1)
+        {
+            goto fail;
+        }
 
         /* configure outbound multicast TTL */
-        if (setsockopt (lpd_socket2, IPPROTO_IP, IP_MULTICAST_TTL,
-                &scope, sizeof scope) < 0)
+        if (setsockopt(lpd_socket2, IPPROTO_IP, IP_MULTICAST_TTL, (void const*)&scope, sizeof(scope)) == -1)
+        {
             goto fail;
+        }
 
-        if (setsockopt (lpd_socket2, IPPROTO_IP, IP_MULTICAST_LOOP,
-                &opt_off, sizeof opt_off) < 0)
+        if (setsockopt(lpd_socket2, IPPROTO_IP, IP_MULTICAST_LOOP, (void const*)&opt_off, sizeof(opt_off)) == -1)
+        {
             goto fail;
+        }
     }
 
     session = ss;
@@ -346,77 +400,76 @@ int tr_lpdInit (tr_session* ss, tr_address* tr_addr UNUSED)
     /* Note: lpd_unsolicitedMsgCounter remains 0 until the first timeout event, thus
      * any announcement received during the initial interval will be discarded. */
 
-    lpd_event = event_new (ss->event_base, lpd_socket, EV_READ | EV_PERSIST, event_callback, NULL);
-    event_add (lpd_event, NULL);
+    lpd_event = event_new(ss->event_base, lpd_socket, EV_READ | EV_PERSIST, event_callback, NULL);
+    event_add(lpd_event, NULL);
 
-    upkeep_timer = evtimer_new (ss->event_base, on_upkeep_timer, ss);
-    tr_timerAdd (upkeep_timer, UPKEEP_INTERVAL_SECS, 0);
+    upkeep_timer = evtimer_new(ss->event_base, on_upkeep_timer, ss);
+    tr_timerAdd(upkeep_timer, UPKEEP_INTERVAL_SECS, 0);
 
-    tr_logAddNamedDbg ("LPD", "Local Peer Discovery initialised");
+    tr_logAddNamedDbg("LPD", "Local Peer Discovery initialised");
 
     return 1;
 
-    fail:
+fail:
     {
-        const int save = errno;
-        close (lpd_socket);
-        close (lpd_socket2);
-        lpd_socket = lpd_socket2 = -1;
+        int const save = errno;
+        evutil_closesocket(lpd_socket);
+        evutil_closesocket(lpd_socket2);
+        lpd_socket = lpd_socket2 = TR_BAD_SOCKET;
         session = NULL;
-        tr_logAddNamedDbg ("LPD", "LPD initialisation failed (errno = %d)", save);
+        tr_logAddNamedDbg("LPD", "LPD initialisation failed (errno = %d)", save);
         errno = save;
     }
 
-
     return -1;
 }
 
-void tr_lpdUninit (tr_session* ss)
+void tr_lpdUninit(tr_session* ss)
 {
     if (session != ss)
+    {
         return;
+    }
 
-    tr_logAddNamedDbg ("LPD", "Uninitialising Local Peer Discovery");
+    tr_logAddNamedDbg("LPD", "Uninitialising Local Peer Discovery");
 
-    event_free (lpd_event);
+    event_free(lpd_event);
     lpd_event = NULL;
 
-    evtimer_del (upkeep_timer);
+    evtimer_del(upkeep_timer);
     upkeep_timer = NULL;
 
     /* just shut down, we won't remember any former nodes */
-    evutil_closesocket (lpd_socket);
-    evutil_closesocket (lpd_socket2);
-    tr_logAddNamedDbg ("LPD", "Done uninitialising Local Peer Discovery");
+    evutil_closesocket(lpd_socket);
+    evutil_closesocket(lpd_socket2);
+    tr_logAddNamedDbg("LPD", "Done uninitialising Local Peer Discovery");
 
     session = NULL;
 }
 
-bool
-tr_lpdEnabled (const tr_session* ss)
+bool tr_lpdEnabled(tr_session const* ss)
 {
-    return ss && (ss == session);
+    return ss != NULL && ss == session;
 }
 
-
 /**
 * @cond
 * @brief Performs some (internal) software consistency checks at compile time.
 * @remark Declared inline for the compiler not to allege us of feeding unused
 * functions. In any other respect, lpd_consistencyCheck is an orphaned function.
 */
-static inline void lpd_consistencyCheck (void)
+UNUSED static inline void lpd_consistencyCheck(void)
 {
     /* if the following check fails, the definition of a hash string has changed
      * without our knowledge; revise string handling in functions tr_lpdSendAnnounce
      * and tr_lpdConsiderAnnounce. However, the code is designed to function as long
      * as interfaces to the rest of the lib remain compatible with char* strings. */
-    STATIC_ASSERT (sizeof (lpd_torStaticType->info.hashString[0]) == sizeof (char));
+    TR_STATIC_ASSERT(sizeof(lpd_torStaticType->info.hashString[0]) == sizeof(char), "");
 }
+
 /**
 * @endcond */
 
-
 /**
 * @defgroup LdsProto LPD announcement processing
 * @{
@@ -432,11 +485,9 @@ static inline void lpd_consistencyCheck (void)
 * matter). A listening client on the same network might react by adding us to his
 * peer pool for torrent t.
 */
-bool
-tr_lpdSendAnnounce (const tr_torrent* t)
+bool tr_lpdSendAnnounce(tr_torrent const* t)
 {
-    size_t i;
-    const char fmt[] =
+    char const fmt[] =
         "BT-SEARCH * HTTP/%u.%u" CRLF
         "Host: %s:%u" CRLF
         "Port: %u" CRLF
@@ -444,34 +495,39 @@ tr_lpdSendAnnounce (const tr_torrent* t)
         CRLF
         CRLF;
 
-    char hashString[lengthof (t->info.hashString)];
+    char hashString[lengthof(t->info.hashString)];
     char query[lpd_maxDatagramLength + 1] = { 0 };
 
     if (t == NULL)
+    {
         return false;
+    }
 
     /* make sure the hash string is normalized, just in case */
-    for (i = 0; i < sizeof hashString; i++)
-        hashString[i] = toupper (t->info.hashString[i]);
+    for (size_t i = 0; i < TR_N_ELEMENTS(hashString); ++i)
+    {
+        hashString[i] = toupper(t->info.hashString[i]);
+    }
 
     /* prepare a zero-terminated announce message */
-    tr_snprintf (query, lpd_maxDatagramLength + 1, fmt, 1, 1,
-                 lpd_mcastGroup, lpd_mcastPort, lpd_port, hashString);
+    tr_snprintf(query, lpd_maxDatagramLength + 1, fmt, 1, 1, lpd_mcastGroup, lpd_mcastPort, lpd_port, hashString);
 
     /* actually send the query out using [lpd_socket2] */
     {
-        const int len = strlen (query);
+        int const len = strlen(query);
 
-        /* destination address info has already been set up in tr_lpdInit (),
+        /* destination address info has already been set up in tr_lpdInit(),
          * so we refrain from preparing another sockaddr_in here */
-        int res = sendto (lpd_socket2, query, len, 0,
-          (const struct sockaddr*) &lpd_mcastAddr, sizeof lpd_mcastAddr);
+        int res = sendto(lpd_socket2, (void const*)query, len, 0, (struct sockaddr const*)&lpd_mcastAddr,
+            sizeof(lpd_mcastAddr));
 
         if (res != len)
+        {
             return false;
+        }
     }
 
-    tr_logAddTorDbg (t, "LPD announce message away");
+    tr_logAddTorDbg(t, "LPD announce message away");
 
     return true;
 }
@@ -490,57 +546,68 @@ tr_lpdSendAnnounce (const tr_torrent* t)
 * is able to extract the necessary information from the announce message. That is, if
 * return != 0, the caller may retrieve the value from the passed structure.
 */
-static int tr_lpdConsiderAnnounce (tr_pex* peer, const char* const msg)
+static int tr_lpdConsiderAnnounce(tr_pex* peer, char const* const msg)
 {
     enum
     {
         maxValueLen = 25,
-        maxHashLen = lengthof (lpd_torStaticType->info.hashString)
+        maxHashLen = lengthof(lpd_torStaticType->info.hashString)
     };
 
-    struct lpd_protocolVersion ver = { -1, -1 };
+    struct lpd_protocolVersion ver = { .major = -1, .minor = -1 };
     char value[maxValueLen] = { 0 };
     char hashString[maxHashLen] = { 0 };
-    int res = 0, peerPort = 0;
+    int res = 0;
+    int peerPort = 0;
 
     if (peer != NULL && msg != NULL)
     {
         tr_torrent* tor = NULL;
 
-        const char* params = lpd_extractHeader (msg, &ver);
+        char const* params = lpd_extractHeader(msg, &ver);
+
         if (params == NULL || ver.major != 1) /* allow messages of protocol v1 */
+        {
             return 0;
+        }
 
         /* save the effort to check Host, which seems to be optional anyway */
 
-        if (lpd_extractParam (params, "Port", maxValueLen, value) == 0)
+        if (!lpd_extractParam(params, "Port", maxValueLen, value))
+        {
             return 0;
+        }
 
         /* determine announced peer port, refuse if value too large */
-        if (sscanf (value, "%d", &peerPort) != 1 || peerPort > (in_port_t)-1)
+        if (sscanf(value, "%d", &peerPort) != 1 || peerPort > (in_port_t)-1)
+        {
             return 0;
+        }
 
-        peer->port = htons (peerPort);
+        peer->port = htons(peerPort);
         res = -1; /* signal caller side-effect to peer->port via return != 0 */
 
-        if (lpd_extractParam (params, "Infohash", maxHashLen, hashString) == 0)
+        if (!lpd_extractParam(params, "Infohash", maxHashLen, hashString))
+        {
             return res;
+        }
 
-        tor = tr_torrentFindFromHashString (session, hashString);
+        tor = tr_torrentFindFromHashString(session, hashString);
 
-        if (tr_isTorrent (tor) && tr_torrentAllowsLPD (tor))
+        if (tr_isTorrent(tor) && tr_torrentAllowsLPD(tor))
         {
             /* we found a suitable peer, add it to the torrent */
-            tr_peerMgrAddPex (tor, TR_PEER_FROM_LPD, peer, -1);
-            tr_logAddTorDbg (tor, "Learned %d local peer from LPD (%s:%u)",
-                1, tr_address_to_string (&peer->addr), peerPort);
+            tr_peerMgrAddPex(tor, TR_PEER_FROM_LPD, peer, -1);
+            tr_logAddTorDbg(tor, "Learned %d local peer from LPD (%s:%u)", 1, tr_address_to_string(&peer->addr), peerPort);
 
-            /* periodic reconnectPulse () deals with the rest... */
+            /* periodic reconnectPulse() deals with the rest... */
 
             return 1;
         }
         else
-            tr_logAddNamedDbg ("LPD", "Cannot serve torrent #%s", hashString);
+        {
+            tr_logAddNamedDbg("LPD", "Cannot serve torrent #%s", hashString);
+        }
     }
 
     return res;
@@ -559,45 +626,50 @@ static int tr_lpdConsiderAnnounce (tr_pex* peer, const char* const msg)
 * most of the previous paragraph isn't true anymore... we weren't using that functionality
 * before. are there cases where we should? if not, should we remove the bells & whistles?
 */
-static int
-tr_lpdAnnounceMore (const time_t now, const int interval)
+static int tr_lpdAnnounceMore(time_t const now, int const interval)
 {
     tr_torrent* tor = NULL;
     int announcesSent = 0;
 
-    if (!tr_isSession (session))
-        return -1;
-
-    while ((tor = tr_torrentNext (session, tor))
-          && tr_sessionAllowsLPD (session))
+    if (!tr_isSession(session))
     {
-        if (tr_isTorrent (tor))
+        return -1;
+    }
+
+    while ((tor = tr_torrentNext(session, tor)) != NULL && tr_sessionAllowsLPD(session))
+    {
+        if (tr_isTorrent(tor))
         {
             int announcePrio = 0;
 
-            if (!tr_torrentAllowsLPD (tor))
+            if (!tr_torrentAllowsLPD(tor))
+            {
                 continue;
+            }
 
             /* issue #3208: prioritize downloads before seeds */
-            switch (tr_torrentGetActivity (tor))
+            switch (tr_torrentGetActivity(tor))
             {
             case TR_STATUS_DOWNLOAD:
                 announcePrio = 1;
                 break;
+
             case TR_STATUS_SEED:
                 announcePrio = 2;
                 break;
+
             default: /* fall through */
                 break;
             }
 
             if (announcePrio > 0 && tor->lpdAnnounceAt <= now)
             {
-                if (tr_lpdSendAnnounce (tor))
+                if (tr_lpdSendAnnounce(tor))
+                {
                     announcesSent++;
+                }
 
-                tor->lpdAnnounceAt = now +
-                    lpd_announceInterval * announcePrio;
+                tor->lpdAnnounceAt = now + lpd_announceInterval * announcePrio;
 
                 break; /* that's enough; for this interval */
             }
@@ -606,11 +678,13 @@ tr_lpdAnnounceMore (const time_t now, const int interval)
 
     /* perform housekeeping for the flood protection mechanism */
     {
-        const int maxAnnounceCap = interval * lpd_announceCapFactor;
+        int const maxAnnounceCap = interval * lpd_announceCapFactor;
 
         if (lpd_unsolicitedMsgCounter < 0)
-            tr_logAddNamedInfo ("LPD", "Dropped %d announces in the last interval (max. %d "
-                     "allowed)", -lpd_unsolicitedMsgCounter, maxAnnounceCap);
+        {
+            tr_logAddNamedInfo("LPD", "Dropped %d announces in the last interval (max. %d allowed)", -lpd_unsolicitedMsgCounter,
+                maxAnnounceCap);
+        }
 
         lpd_unsolicitedMsgCounter = maxAnnounceCap;
     }
@@ -618,56 +692,62 @@ tr_lpdAnnounceMore (const time_t now, const int interval)
     return announcesSent;
 }
 
-static void
-on_upkeep_timer (evutil_socket_t foo UNUSED, short bar UNUSED, void * vsession UNUSED)
+static void on_upkeep_timer(evutil_socket_t foo UNUSED, short bar UNUSED, void* vsession UNUSED)
 {
-    const time_t now = tr_time ();
-    tr_lpdAnnounceMore (now, UPKEEP_INTERVAL_SECS);
-    tr_timerAdd (upkeep_timer, UPKEEP_INTERVAL_SECS, 0);
+    time_t const now = tr_time();
+    tr_lpdAnnounceMore(now, UPKEEP_INTERVAL_SECS);
+    tr_timerAdd(upkeep_timer, UPKEEP_INTERVAL_SECS, 0);
 }
 
 /**
 * @brief Processing of timeout notifications and incoming data on the socket
 * @note maximum rate of read events is limited according to @a lpd_maxAnnounceCap
 * @see DoS */
-static void event_callback (evutil_socket_t s UNUSED, short type, void* ignore UNUSED)
+static void event_callback(evutil_socket_t s UNUSED, short type, void* ignore UNUSED)
 {
-    assert (tr_isSession (session));
+    TR_ASSERT(tr_isSession(session));
 
     /* do not allow announces to be processed if LPD is disabled */
-    if (!tr_sessionAllowsLPD (session))
+    if (!tr_sessionAllowsLPD(session))
+    {
         return;
+    }
 
     if ((type & EV_READ) != 0)
     {
         struct sockaddr_in foreignAddr;
-        int addrLen = sizeof foreignAddr;
-
-        /* be paranoid enough about zero terminating the foreign string */
-        char foreignMsg[lpd_maxDatagramLength + 1] = { 0 };
+        int addrLen = sizeof(foreignAddr);
+        char foreignMsg[lpd_maxDatagramLength + 1];
 
         /* process local announcement from foreign peer */
-        int res = recvfrom (lpd_socket, foreignMsg, lpd_maxDatagramLength,
-            0, (struct sockaddr*) &foreignAddr, (socklen_t*) &addrLen);
+        int res = recvfrom(lpd_socket, (void*)foreignMsg, lpd_maxDatagramLength, 0, (struct sockaddr*)&foreignAddr,
+            (socklen_t*)&addrLen);
 
         /* besides, do we get flooded? then bail out! */
         if (--lpd_unsolicitedMsgCounter < 0)
+        {
             return;
+        }
 
         if (res > 0 && res <= lpd_maxDatagramLength)
         {
             struct tr_pex foreignPeer =
-                {
-                    .port = 0, /* the peer-to-peer port is yet unknown */
-                    .flags = 0
-                };
+            {
+                .port = 0, /* the peer-to-peer port is yet unknown */
+                .flags = 0
+            };
+
+            /* be paranoid enough about zero terminating the foreign string */
+            foreignMsg[res] = '\0';
 
             foreignPeer.addr.addr.addr4 = foreignAddr.sin_addr;
-            if (tr_lpdConsiderAnnounce (&foreignPeer, foreignMsg) != 0)
+
+            if (tr_lpdConsiderAnnounce(&foreignPeer, foreignMsg) != 0)
+            {
                 return; /* OK so far, no log message */
+            }
         }
 
-        tr_logAddNamedDbg ("LPD", "Discarded invalid multicast message");
+        tr_logAddNamedDbg("LPD", "Discarded invalid multicast message");
     }
 }
-
