@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: AddMagnetWindowController.h 13479 2012-09-08 03:48:12Z livings124 $
- *
  * Copyright (c) 2010-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -24,6 +22,8 @@
 
 #import <Cocoa/Cocoa.h>
 
+#import "Torrent.h"
+
 @class Controller;
 @class Torrent;
 
@@ -33,20 +33,21 @@
     IBOutlet NSTextField * fNameField, * fLocationField;
     IBOutlet NSButton * fStartCheck;
     IBOutlet NSPopUpButton * fGroupPopUp, * fPriorityPopUp;
-    
+
     //remove these when switching to auto layout
     IBOutlet NSTextField * fMagnetLinkLabel;
     IBOutlet NSTextField * fDownloadToLabel, * fGroupLabel, * fPriorityLabel;
     IBOutlet NSButton * fChangeDestinationButton;
     IBOutlet NSBox * fDownloadToBox;
     IBOutlet NSButton * fAddButton, * fCancelButton;
-    
+
     Controller * fController;
-    
+
     Torrent * fTorrent;
     NSString * fDestination;
-    
+
     NSInteger fGroupValue;
+    TorrentDeterminationType fGroupDeterminationType;
 }
 
 - (id) initWithTorrent: (Torrent *) torrent destination: (NSString *) path controller: (Controller *) controller;
