@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: AddMagnetWindowController.m 13602 2012-10-30 00:22:10Z livings124 $
- *
  * Copyright (c) 2010-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -53,10 +51,10 @@
     if ((self = [super initWithWindowNibName: @"AddMagnetWindow"]))
     {
         fTorrent = torrent;
-        fDestination = [[path stringByExpandingTildeInPath] retain];
-        
+        fDestination = [path stringByExpandingTildeInPath];
+
         fController = controller;
-        
+
         fGroupValue = [torrent groupValue];
         fGroupDeterminationType = TorrentDeterminationAutomatic;
     }
@@ -67,27 +65,29 @@
 {
     [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(updateGroupMenu:)
         name: @"UpdateGroups" object: nil];
-    
+
     NSString * name = [fTorrent name];
     [[self window] setTitle: name];
     [fNameField setStringValue: name];
     [fNameField setToolTip: name];
-    
+
     [self setGroupsMenu];
     [fGroupPopUp selectItemWithTag: fGroupValue];
-    
+
     NSInteger priorityIndex;
     switch ([fTorrent priority])
     {
         case TR_PRI_HIGH: priorityIndex = POPUP_PRIORITY_HIGH; break;
         case TR_PRI_NORMAL: priorityIndex = POPUP_PRIORITY_NORMAL; break;
         case TR_PRI_LOW: priorityIndex = POPUP_PRIORITY_LOW; break;
-        default: NSAssert1(NO, @"Unknown priority for adding torrent: %d", [fTorrent priority]);
+        default:
+            NSAssert1(NO, @"Unknown priority for adding torrent: %d", [fTorrent priority]);
+            priorityIndex = POPUP_PRIORITY_NORMAL;
     }
     [fPriorityPopUp selectItemAtIndex: priorityIndex];
-    
+
     [fStartCheck setState: [[NSUserDefaults standardUserDefaults] boolForKey: @"AutoStartDownload"] ? NSOnState : NSOffState];
-    
+
     if (fDestination)
         [self setDestinationPath: fDestination determinationType: TorrentDeterminationAutomatic];
     else
@@ -95,10 +95,10 @@
         [fLocationField setStringValue: @""];
         [fLocationImageView setImage: nil];
     }
-    
+
     #warning when 10.7-only, switch to auto layout
     [fMagnetLinkLabel sizeToFit];
-    
+
     const CGFloat downloadToLabelOldWidth = [fDownloadToLabel frame].size.width;
     [fDownloadToLabel sizeToFit];
     const CGFloat changeDestOldWidth = [fChangeDestinationButton frame].size.width;
@@ -106,13 +106,13 @@
     NSRect changeDestFrame = [fChangeDestinationButton frame];
     changeDestFrame.origin.x -= changeDestFrame.size.width - changeDestOldWidth;
     [fChangeDestinationButton setFrame: changeDestFrame];
-    
+
     NSRect downloadToBoxFrame = [fDownloadToBox frame];
     const CGFloat downloadToBoxSizeDiff = ([fDownloadToLabel frame].size.width - downloadToLabelOldWidth) + (changeDestFrame.size.width - changeDestOldWidth);
     downloadToBoxFrame.size.width -= downloadToBoxSizeDiff;
     downloadToBoxFrame.origin.x -= downloadToLabelOldWidth - [fDownloadToLabel frame].size.width;
     [fDownloadToBox setFrame: downloadToBoxFrame];
-    
+
     NSRect groupPopUpFrame = [fGroupPopUp frame];
     NSRect priorityPopUpFrame = [fPriorityPopUp frame];
     const CGFloat popUpOffset = groupPopUpFrame.origin.x - NSMaxX([fGroupLabel frame]);
@@ -133,7 +133,7 @@
     [fGroupPopUp setFrame: groupPopUpFrame];
     [fPriorityLabel setFrame: priorityLabelFrame];
     [fPriorityPopUp setFrame: priorityPopUpFrame];
-    
+
     const CGFloat minButtonWidth = 82.0;
     const CGFloat oldAddButtonWidth = [fAddButton bounds].size.width;
     const CGFloat oldCancelButtonWidth = [fCancelButton bounds].size.width;
@@ -150,7 +150,7 @@
     cancelButtonFrame.origin.x -= addButtonWidthIncrease + (buttonWidth - oldCancelButtonWidth);
     [fAddButton setFrame: addButtonFrame];
     [fCancelButton setFrame: cancelButtonFrame];
-    
+
     [fStartCheck sizeToFit];
 }
 
@@ -164,10 +164,6 @@
 - (void) dealloc
 {
     [[NSNotificationCenter defaultCenter] removeObserver: self];
-    
-    [fDestination release];
-    
-    [super dealloc];
 }
 
 - (Torrent *) torrent
@@ -184,13 +180,13 @@
     [panel setCanChooseFiles: NO];
     [panel setCanChooseDirectories: YES];
     [panel setCanCreateDirectories: YES];
-    
+
     [panel setMessage: [NSString stringWithFormat: NSLocalizedString(@"Select the download folder for \"%@\"",
                         "Add -> select destination folder"), [fTorrent name]]];
-    
+
     [panel beginSheetModalForWindow: [self window] completionHandler: ^(NSInteger result) {
         if (result == NSFileHandlingPanelOKButton)
-            [self setDestinationPath: [[[panel URLs] objectAtIndex: 0] path] determinationType:TorrentDeterminationUserSpecified];
+            [self setDestinationPath: [[panel URLs][0] path] determinationType:TorrentDeterminationUserSpecified];
         else
         {
             if (!fDestination)
@@ -213,7 +209,7 @@
         [alert addButtonWithTitle: NSLocalizedString(@"Cancel", "Add torrent -> same name -> button")];
         [alert addButtonWithTitle: NSLocalizedString(@"Add", "Add torrent -> same name -> button")];
         [alert setShowsSuppressionButton: YES];
-        
+
         [alert beginSheetModalForWindow: [self window] modalDelegate: self
             didEndSelector: @selector(sameNameAlertDidEnd:returnCode:contextInfo:) contextInfo: nil];
     }
@@ -241,7 +237,9 @@
         case POPUP_PRIORITY_HIGH: priority = TR_PRI_HIGH; break;
         case POPUP_PRIORITY_NORMAL: priority = TR_PRI_NORMAL; break;
         case POPUP_PRIORITY_LOW: priority = TR_PRI_LOW; break;
-        default: NSAssert1(NO, @"Unknown priority tag for adding torrent: %ld", [sender tag]);
+        default:
+            NSAssert1(NO, @"Unknown priority tag for adding torrent: %ld", [sender tag]);
+            priority = TR_PRI_NORMAL;
     }
     [fTorrent setPriority: priority];
 }
@@ -252,7 +250,7 @@
     if (![fGroupPopUp selectItemWithTag: fGroupValue])
     {
         fGroupValue = -1;
-		fGroupDeterminationType = TorrentDeterminationAutomatic;
+        fGroupDeterminationType = TorrentDeterminationAutomatic;
         [fGroupPopUp selectItemWithTag: fGroupValue];
     }
 }
@@ -264,31 +262,29 @@
 - (void) confirmAdd
 {
     [fTorrent setGroupValue: fGroupValue determinationType: fGroupDeterminationType];
-    
+
     if ([fStartCheck state] == NSOnState)
         [fTorrent startTransfer];
-    
+
     [self close];
-    [fController askOpenMagnetConfirmed: self add: YES]; //ensure last, since it releases this controller
+    [fController askOpenMagnetConfirmed: self add: YES];
 }
 
 - (void) setDestinationPath: (NSString *) destination determinationType: (TorrentDeterminationType) determinationType
 {
     destination = [destination stringByExpandingTildeInPath];
     if (!fDestination || ![fDestination isEqualToString: destination])
-    { 
-        [fDestination release];
-        fDestination = [destination retain];
-        
+    {
+        fDestination = destination;
+
         [fTorrent changeDownloadFolderBeforeUsing: fDestination determinationType: determinationType];
     }
-    
+
     [fLocationField setStringValue: [fDestination stringByAbbreviatingWithTildeInPath]];
     [fLocationField setToolTip: fDestination];
-    
+
     ExpandedPathToIconTransformer * iconTransformer = [[ExpandedPathToIconTransformer alloc] init];
     [fLocationImageView setImage: [iconTransformer transformedValue: fDestination]];
-    [iconTransformer release];
 }
 
 - (void) setGroupsMenu
@@ -300,7 +296,7 @@
 - (void) changeGroupValue: (id) sender
 {
     NSInteger previousGroup = fGroupValue;
-    fGroupValue = [sender tag]; 
+    fGroupValue = [sender tag];
     fGroupDeterminationType = TorrentDeterminationUserSpecified;
 
     if ([[GroupsController groups] usesCustomDownloadLocationForIndex: fGroupValue])
@@ -314,9 +310,8 @@
 {
     if ([[alert suppressionButton] state] == NSOnState)
         [[NSUserDefaults standardUserDefaults] setBool: NO forKey: @"WarningFolderDataSameName"];
-    
-    [alert release];
-    
+
+
     if (returnCode == NSAlertSecondButtonReturn)
         [self performSelectorOnMainThread: @selector(confirmAdd) withObject: nil waitUntilDone: NO];
 }
