@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: BadgeView.m 13162 2012-01-14 17:12:04Z livings124 $
- *
  * Copyright (c) 2007-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -40,7 +38,7 @@
     if ((self = [super init]))
     {
         fLib = lib;
-        
+
         fDownloadRate = 0.0;
         fUploadRate = 0.0;
         fQuitting = NO;
@@ -48,18 +46,13 @@
     return self;
 }
 
-- (void) dealloc
-{
-    [fAttributes release];
-    [super dealloc];
-}
 
 - (BOOL) setRatesWithDownload: (CGFloat) downloadRate upload: (CGFloat) uploadRate
 {
     //only needs update if the badges were displayed or are displayed now
     if (fDownloadRate == downloadRate && fUploadRate == uploadRate)
         return NO;
-    
+
     fDownloadRate = downloadRate;
     fUploadRate = uploadRate;
     return YES;
@@ -73,27 +66,27 @@
 - (void) drawRect: (NSRect) rect
 {
     [[NSApp applicationIconImage] drawInRect: rect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0];
-    
+
     if (fQuitting)
     {
-        NSImage * quitBadge = [NSImage imageNamed: @"QuitBadge.png"];
+        NSImage * quitBadge = [NSImage imageNamed: @"QuitBadge"];
         [self badge: quitBadge string: NSLocalizedString(@"Quitting", "Dock Badger -> quit")
                 atHeight: (NSHeight(rect) - [quitBadge size].height) * 0.5 adjustForQuit: YES];
         return;
     }
-    
+
     const BOOL upload = fUploadRate >= 0.1,
             download = fDownloadRate >= 0.1;
     CGFloat bottom = 0.0;
     if (upload)
     {
-        NSImage * uploadBadge = [NSImage imageNamed: @"UploadBadge.png"];
+        NSImage * uploadBadge = [NSImage imageNamed: @"UploadBadge"];
         [self badge: uploadBadge string: [NSString stringForSpeedAbbrev: fUploadRate] atHeight: bottom adjustForQuit: NO];
         if (download)
             bottom += [uploadBadge size].height + BETWEEN_PADDING; //download rate above upload rate
     }
     if (download)
-        [self badge: [NSImage imageNamed: @"DownloadBadge.png"] string: [NSString stringForSpeedAbbrev: fDownloadRate]
+        [self badge: [NSImage imageNamed: @"DownloadBadge"] string: [NSString stringForSpeedAbbrev: fDownloadRate]
                 atHeight: bottom adjustForQuit: NO];
 }
 
@@ -108,37 +101,36 @@
         NSShadow * stringShadow = [[NSShadow alloc] init];
         [stringShadow setShadowOffset: NSMakeSize(2.0, -2.0)];
         [stringShadow setShadowBlurRadius: 4.0];
-        
+
         fAttributes = [[NSMutableDictionary alloc] initWithCapacity: 3];
-        [fAttributes setObject: [NSColor whiteColor] forKey: NSForegroundColorAttributeName];
-        [fAttributes setObject: stringShadow forKey: NSShadowAttributeName];
-        
-        [stringShadow release];
+        fAttributes[NSForegroundColorAttributeName] = [NSColor whiteColor];
+        fAttributes[NSShadowAttributeName] = stringShadow;
+
     }
-    
+
     NSRect badgeRect;
     badgeRect.size = [badge size];
     badgeRect.origin.x = 0.0;
     badgeRect.origin.y = height;
-    
+
     [badge drawInRect: badgeRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0];
-    
+
     //make sure text fits on the badge
     CGFloat fontSize = 26.0;
     NSSize stringSize;
     do
     {
-        [fAttributes setObject: [NSFont boldSystemFontOfSize: fontSize] forKey: NSFontAttributeName];
+        fAttributes[NSFontAttributeName] = [NSFont boldSystemFontOfSize: fontSize];
         stringSize = [string sizeWithAttributes: fAttributes];
         fontSize -= 1.0;
     } while (NSWidth(badgeRect) < stringSize.width);
-    
+
     //string is in center of image
     NSRect stringRect;
     stringRect.origin.x = NSMidX(badgeRect) - stringSize.width * 0.5;
     stringRect.origin.y = NSMidY(badgeRect) - stringSize.height * 0.5 + (quit ? 2.0 : 1.0); //adjust for shadow, extra for quit
     stringRect.size = stringSize;
-    
+
     [string drawInRect: stringRect withAttributes: fAttributes];
 }
 
