@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: BlocklistDownloader.m 13326 2012-05-29 01:03:21Z livings124 $
- *
  * Copyright (c) 2008-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -44,7 +42,7 @@ BlocklistDownloader * fBLDownloader = nil;
         fBLDownloader = [[BlocklistDownloader alloc] init];
         [fBLDownloader startDownload];
     }
-    
+
     return fBLDownloader;
 }
 
@@ -73,23 +71,16 @@ BlocklistDownloader * fBLDownloader = nil;
     }
 }
 
-- (void) dealloc
-{
-    [fDownload release];
-    [fDestination release];
-    [super dealloc];
-}
 
 - (void) cancelDownload
 {
     [fViewController setFinished];
-    
+
     [fDownload cancel];
-    
+
     [[BlocklistScheduler scheduler] updateSchedule];
-    
+
     fBLDownloader = nil;
-    [self release];
 }
 
 //using the actual filename is the best bet
@@ -100,17 +91,16 @@ BlocklistDownloader * fBLDownloader = nil;
 
 - (void) download: (NSURLDownload *) download didCreateDestination: (NSString *) path
 {
-    [fDestination release];
-    fDestination = [path retain];
+    fDestination = path;
 }
 
 - (void) download: (NSURLDownload *) download didReceiveResponse: (NSURLResponse *) response
 {
     fState = BLOCKLIST_DL_DOWNLOADING;
-    
+
     fCurrentSize = 0;
     fExpectedSize = [response expectedContentLength];
-    
+
     [fViewController setStatusProgressForCurrentSize: fCurrentSize expectedSize: fExpectedSize];
 }
 
@@ -123,47 +113,45 @@ BlocklistDownloader * fBLDownloader = nil;
 - (void) download: (NSURLDownload *) download didFailWithError: (NSError *) error
 {
     [fViewController setFailed: [error localizedDescription]];
-    
+
     [[NSUserDefaults standardUserDefaults] setObject: [NSDate date] forKey: @"BlocklistNewLastUpdate"];
     [[BlocklistScheduler scheduler] updateSchedule];
-    
+
     fBLDownloader = nil;
-    [self release];
 }
 
 - (void) downloadDidFinish: (NSURLDownload *) download
 {
     fState = BLOCKLIST_DL_PROCESSING;
-    
+
     [fViewController setStatusProcessing];
-    
+
     NSAssert(fDestination != nil, @"the blocklist file destination has not been specified");
-    
+
     dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0), ^{
         [self decompressBlocklist];
-        
+
         dispatch_async(dispatch_get_main_queue(), ^{
             const int count = tr_blocklistSetContent([(Controller *)[NSApp delegate] sessionHandle], [fDestination UTF8String]);
-            
+
             //delete downloaded file
             [[NSFileManager defaultManager] removeItemAtPath: fDestination error: NULL];
-            
+
             if (count > 0)
                 [fViewController setFinished];
             else
                 [fViewController setFailed: NSLocalizedString(@"The specified blocklist file did not contain any valid rules.",
                                                               "blocklist fail message")];
-            
+
             //update last updated date for schedule
             NSDate * date = [NSDate date];
             [[NSUserDefaults standardUserDefaults] setObject: date forKey: @"BlocklistNewLastUpdate"];
             [[NSUserDefaults standardUserDefaults] setObject: date forKey: @"BlocklistNewLastUpdateSuccess"];
             [[BlocklistScheduler scheduler] updateSchedule];
-            
+
             [[NSNotificationCenter defaultCenter] postNotificationName: @"BlocklistUpdated" object: nil];
-            
+
             fBLDownloader = nil;
-            [self release];
         });
     });
 }
@@ -180,87 +168,84 @@ BlocklistDownloader * fBLDownloader = nil;
 - (void) startDownload
 {
     fState = BLOCKLIST_DL_START;
-    
+
     [[BlocklistScheduler scheduler] cancelSchedule];
-    
+
     NSString * urlString = [[NSUserDefaults standardUserDefaults] stringForKey: @"BlocklistURL"];
     if (!urlString)
         urlString = @"";
     else if (![urlString isEqualToString: @""] && [urlString rangeOfString: @"://"].location == NSNotFound)
         urlString = [@"http://" stringByAppendingString: urlString];
-    
+
     NSURLRequest * request = [NSURLRequest requestWithURL: [NSURL URLWithString: urlString]];
-    
+
     fDownload = [[NSURLDownload alloc] initWithRequest: request delegate: self];
 }
 
 //.gz, .tar.gz, .tgz, and .bgz will be decompressed by NSURLDownload for us. However, we have to do .zip files manually.
 - (void) decompressBlocklist
 {
-	if ([[[fDestination pathExtension] lowercaseString] isEqualToString: @"zip"]) {
-		BOOL success = NO;
-        
+    if ([[[fDestination pathExtension] lowercaseString] isEqualToString: @"zip"]) {
+        BOOL success = NO;
+
         NSString * workingDirectory = [fDestination stringByDeletingLastPathComponent];
-		
-		//First, perform the actual unzipping
-		NSTask	* unzip = [[NSTask alloc] init];
-		[unzip setLaunchPath: @"/usr/bin/unzip"];
-		[unzip setCurrentDirectoryPath: workingDirectory];
-		[unzip setArguments: [NSArray arrayWithObjects:
+
+        //First, perform the actual unzipping
+        NSTask  * unzip = [[NSTask alloc] init];
+        [unzip setLaunchPath: @"/usr/bin/unzip"];
+        [unzip setCurrentDirectoryPath: workingDirectory];
+        [unzip setArguments: @[
                                 @"-o",  /* overwrite */
                                 @"-q", /* quiet! */
                                 fDestination, /* source zip file */
-                                @"-d", workingDirectory, /*destination*/
-                                nil]];
-		
-		@try
-		{
-			[unzip launch];
-			[unzip waitUntilExit];
-			
-			if ([unzip terminationStatus] == 0)
-				success = YES;
-		}
-		@catch(id exc)
-		{
-			success = NO;
-		}
-		[unzip release];
-		
-		if (success) {
-			//Now find out what file we actually extracted; don't just assume it matches the zipfile's name
-			NSTask *zipinfo;
-			
-			zipinfo = [[NSTask alloc] init];
-			[zipinfo setLaunchPath: @"/usr/bin/zipinfo"];
-			[zipinfo setArguments: [NSArray arrayWithObjects:
-                                    @"-1",  /* just the filename */
-                                    fDestination, /* source zip file */
-                                    nil]];
-			[zipinfo setStandardOutput: [NSPipe pipe]];
-						
-			@try
-			{
-				NSFileHandle * zipinfoOutput = [[zipinfo standardOutput] fileHandleForReading];
+                                @"-d", workingDirectory /*destination*/
+                                ]];
 
-				[zipinfo launch];
-				[zipinfo waitUntilExit];
-				
-				NSString * actualFilename = [[[NSString alloc] initWithData: [zipinfoOutput readDataToEndOfFile]
-                                                encoding: NSUTF8StringEncoding] autorelease];
-				actualFilename = [actualFilename stringByTrimmingCharactersInSet: [NSCharacterSet whitespaceAndNewlineCharacterSet]];
-				NSString * newBlocklistPath = [workingDirectory stringByAppendingPathComponent: actualFilename];
-				
-				//Finally, delete the ZIP file; we're done with it, and we'll return the unzipped blocklist
-				[[NSFileManager defaultManager] removeItemAtPath: fDestination error: NULL];
-                
-                [fDestination release];
-                fDestination = [newBlocklistPath retain];
-			}
+        @try
+        {
+            [unzip launch];
+            [unzip waitUntilExit];
+
+            if ([unzip terminationStatus] == 0)
+                success = YES;
+        }
+        @catch(id exc)
+        {
+            success = NO;
+        }
+
+        if (success) {
+            //Now find out what file we actually extracted; don't just assume it matches the zipfile's name
+            NSTask *zipinfo;
+
+            zipinfo = [[NSTask alloc] init];
+            [zipinfo setLaunchPath: @"/usr/bin/zipinfo"];
+            [zipinfo setArguments: @[
+                                    @"-1",  /* just the filename */
+                                    fDestination /* source zip file */
+                                    ]];
+            [zipinfo setStandardOutput: [NSPipe pipe]];
+
+            @try
+            {
+                NSFileHandle * zipinfoOutput = [[zipinfo standardOutput] fileHandleForReading];
+
+                [zipinfo launch];
+                [zipinfo waitUntilExit];
+
+                NSString * actualFilename = [[NSString alloc] initWithData: [zipinfoOutput readDataToEndOfFile]
+                                                encoding: NSUTF8StringEncoding];
+                actualFilename = [actualFilename stringByTrimmingCharactersInSet: [NSCharacterSet whitespaceAndNewlineCharacterSet]];
+                NSString * newBlocklistPath = [workingDirectory stringByAppendingPathComponent: actualFilename];
+
+                //Finally, delete the ZIP file; we're done with it, and we'll return the unzipped blocklist
+                [[NSFileManager defaultManager] removeItemAtPath: fDestination error: NULL];
+
+                fDestination = newBlocklistPath;
+            }
             @catch(id exc) {}
-			[zipinfo release];
-		}		
-	}
+        }
+    }
 }
 
 @end
