@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: BlocklistDownloaderViewController.m 13162 2012-01-14 17:12:04Z livings124 $
- *
  * Copyright (c) 2008-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -37,23 +35,27 @@
 
 @implementation BlocklistDownloaderViewController
 
+BlocklistDownloaderViewController * fBLViewController = nil;
 + (void) downloadWithPrefsController: (PrefsController *) prefsController
 {
-    BlocklistDownloaderViewController * downloader = [[BlocklistDownloaderViewController alloc] initWithPrefsController: prefsController];
-    [downloader startDownload];
+    if (!fBLViewController)
+    {
+        fBLViewController = [[BlocklistDownloaderViewController alloc] initWithPrefsController: prefsController];
+        [fBLViewController startDownload];
+    }
 }
 
 - (void) awakeFromNib
 {
     [fButton setTitle: NSLocalizedString(@"Cancel", "Blocklist -> cancel button")];
-    
+
     const CGFloat oldWidth = NSWidth([fButton frame]);
     [fButton sizeToFit];
     NSRect buttonFrame = [fButton frame];
     buttonFrame.size.width += 12.0; //sizeToFit sizes a bit too small
     buttonFrame.origin.x -= NSWidth(buttonFrame) - oldWidth;
     [fButton setFrame: buttonFrame];
-    
+
     [fProgressBar setUsesThreadedAnimation: YES];
     [fProgressBar startAnimation: self];
 }
@@ -75,14 +77,14 @@
     if (expectedSize != NSURLResponseUnknownLength)
     {
         [fProgressBar setIndeterminate: NO];
-        
+
         NSString * substring = [NSString stringForFilePartialSize: currentSize fullSize: expectedSize];
         string = [string stringByAppendingFormat: @" (%@)",  substring];
         [fProgressBar setDoubleValue: (double)currentSize / expectedSize];
     }
     else
         string = [string stringByAppendingFormat: @" (%@)",  [NSString stringForFileSize: currentSize]];
-    
+
     [fTextField setStringValue: string];
 }
 
@@ -91,7 +93,7 @@
     //change to indeterminate while processing
     [fProgressBar setIndeterminate: YES];
     [fProgressBar startAnimation: self];
-    
+
     [fTextField setStringValue: [NSLocalizedString(@"Processing blocklist", "Blocklist -> message") stringByAppendingEllipsis]];
     [fButton setEnabled: NO];
 }
@@ -100,22 +102,22 @@
 {
     [NSApp endSheet: fStatusWindow];
     [fStatusWindow orderOut: self];
-    
-    [self release];
+
+    fBLViewController = nil;
 }
 
 - (void) setFailed: (NSString *) error
 {
     [NSApp endSheet: fStatusWindow];
     [fStatusWindow orderOut: self];
-    
-    NSAlert * alert = [[[NSAlert alloc] init] autorelease];
+
+    NSAlert * alert = [[NSAlert alloc] init];
     [alert addButtonWithTitle: NSLocalizedString(@"OK", "Blocklist -> button")];
     [alert setMessageText: NSLocalizedString(@"Download of the blocklist failed.", "Blocklist -> message")];
     [alert setAlertStyle: NSWarningAlertStyle];
-    
+
     [alert setInformativeText: error];
-    
+
     [alert beginSheetModalForWindow: [fPrefsController window] modalDelegate: self
         didEndSelector: @selector(failureSheetClosed:returnCode:contextInfo:) contextInfo: nil];
 }
@@ -130,25 +132,26 @@
     {
         fPrefsController = prefsController;
     }
-    
+
     return self;
 }
 
 - (void) startDownload
 {
     //load window and show as sheet
-    [NSBundle loadNibNamed: @"BlocklistStatusWindow" owner: self];
-    
+    [[NSBundle mainBundle] loadNibNamed: @"BlocklistStatusWindow" owner: self topLevelObjects: NULL];
+
     BlocklistDownloader * downloader = [BlocklistDownloader downloader];
     [downloader setViewController: self]; //do before showing the sheet to ensure it doesn't slide out with placeholder text
-    
+
     [NSApp beginSheet: fStatusWindow modalForWindow: [fPrefsController window] modalDelegate: nil didEndSelector: nil contextInfo: nil];
 }
 
 - (void) failureSheetClosed: (NSAlert *) alert returnCode: (NSInteger) code contextInfo: (void *) info
 {
     [[alert window] orderOut: self];
-    [self release];
+
+    fBLViewController = nil;
 }
 
 @end
