@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: ButtonToolbarItem.m 13251 2012-03-13 02:52:11Z livings124 $
- * 
  * Copyright (c) 2007-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -36,8 +34,8 @@
     NSMenuItem * menuItem = [[NSMenuItem alloc] initWithTitle: [self label] action: [self action] keyEquivalent: @""];
     [menuItem setTarget: [self target]];
     [menuItem setEnabled: [[self target] validateToolbarItem: self]];
-    
-    return [menuItem autorelease];
+
+    return menuItem;
 }
 
 @end
