@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: FileOutlineView.m 13251 2012-03-13 02:52:11Z livings124 $
- * 
  * Copyright (c) 2007-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -35,22 +33,16 @@
 {
     FileNameCell * nameCell = [[FileNameCell alloc] init];
     [[self tableColumnWithIdentifier: @"Name"] setDataCell: nameCell];
-    [nameCell release];
-    
+
     FilePriorityCell * priorityCell = [[FilePriorityCell alloc] init];
     [[self tableColumnWithIdentifier: @"Priority"] setDataCell: priorityCell];
-    [priorityCell release];
-    
+
     [self setAutoresizesOutlineColumn: NO];
     [self setIndentationPerLevel: 14.0];
-    
+
     fMouseRow = -1;
 }
 
-- (void) dealloc
-{
-    [super dealloc];
-}
 
 - (void) mouseDown: (NSEvent *) event
 {
@@ -61,7 +53,7 @@
 - (NSMenu *) menuForEvent: (NSEvent *) event
 {
     const NSInteger row = [self rowAtPoint: [self convertPoint: [event locationInWindow] fromView: nil]];
-    
+
     if (row >= 0)
     {
         if (![self isRowSelected: row])
@@ -69,7 +61,7 @@
     }
     else
         [self deselectAll: self];
-    
+
     return [self menu];
 }
 
@@ -77,7 +69,7 @@
 {
     FileNameCell * cell = (FileNameCell *)[self preparedCellAtColumn: [self columnWithIdentifier: @"Name"] row: row];
     NSRect iconRect = [cell imageRectForBounds: [self rectOfRow: row]];
-    
+
     iconRect.origin.x += [self indentationPerLevel] * (CGFloat)([self levelForRow: row] + 1);
     return iconRect;
 }
@@ -85,24 +77,24 @@
 - (void) updateTrackingAreas
 {
     [super updateTrackingAreas];
-    
+
     for (NSTrackingArea * area in [self trackingAreas])
     {
-        if ([area owner] == self && [[area userInfo] objectForKey: @"Row"])
+        if ([area owner] == self && [area userInfo][@"Row"])
             [self removeTrackingArea: area];
     }
-    
+
     NSRange visibleRows = [self rowsInRect: [self visibleRect]];
     if (visibleRows.length == 0)
         return;
-    
-    NSPoint mouseLocation = [self convertPoint: [[self window] convertScreenToBase: [NSEvent mouseLocation]] fromView: nil];
-    
-    for (NSInteger row = visibleRows.location, col = [self columnWithIdentifier: @"Priority"]; row < NSMaxRange(visibleRows); row++)
+
+    NSPoint mouseLocation = [self convertPoint: [[self window] mouseLocationOutsideOfEventStream] fromView: nil];
+
+    for (NSInteger row = visibleRows.location, col = [self columnWithIdentifier: @"Priority"]; (NSUInteger)row < NSMaxRange(visibleRows); row++)
     {
         FilePriorityCell * cell = (FilePriorityCell *)[self preparedCellAtColumn: col row: row];
-        
-        NSDictionary * userInfo = [NSDictionary dictionaryWithObject: [NSNumber numberWithInt: row] forKey: @"Row"];
+
+        NSDictionary * userInfo = @{@"Row": @(row)};
         [cell addTrackingAreasForView: self inRect: [self frameOfCellAtColumn: col row: row] withUserInfo: userInfo
                 mouseLocation: mouseLocation];
     }
@@ -116,7 +108,7 @@
 - (void) mouseEntered: (NSEvent *) event
 {
     NSNumber * row;
-    if ((row = [(NSDictionary *)[event userData] objectForKey: @"Row"]))
+    if ((row = ((NSDictionary *)[event userData])[@"Row"]))
     {
         fMouseRow = [row intValue];
         [self setNeedsDisplayInRect: [self frameOfCellAtColumn: [self columnWithIdentifier: @"Priority"] row: fMouseRow]];
@@ -126,7 +118,7 @@
 - (void) mouseExited: (NSEvent *) event
 {
     NSNumber * row;
-    if ((row = [(NSDictionary *)[event userData] objectForKey: @"Row"]))
+    if ((row = ((NSDictionary *)[event userData])[@"Row"]))
     {
         [self setNeedsDisplayInRect: [self frameOfCellAtColumn: [self columnWithIdentifier: @"Priority"] row: [row intValue]]];
         fMouseRow = -1;
