@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: FilePriorityCell.m 13162 2012-01-14 17:12:04Z livings124 $
- * 
  * Copyright (c) 2007-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -39,17 +37,17 @@
         [self setTrackingMode: NSSegmentSwitchTrackingSelectAny];
         [self setControlSize: NSMiniControlSize];
         [self setSegmentCount: 3];
-        
+
         for (NSInteger i = 0; i < [self segmentCount]; i++)
         {
             [self setLabel: @"" forSegment: i];
             [self setWidth: 9.0f forSegment: i]; //9 is minimum size to get proper look
         }
-        
-        [self setImage: [NSImage imageNamed: @"PriorityControlLow.png"] forSegment: 0];
-        [self setImage: [NSImage imageNamed: @"PriorityControlNormal.png"] forSegment: 1];
-        [self setImage: [NSImage imageNamed: @"PriorityControlHigh.png"] forSegment: 2];
-        
+
+        [self setImage: [NSImage imageNamed: @"PriorityControlLow"] forSegment: 0];
+        [self setImage: [NSImage imageNamed: @"PriorityControlNormal"] forSegment: 1];
+        [self setImage: [NSImage imageNamed: @"PriorityControlHigh"] forSegment: 2];
+
         fHoverRow = NO;
     }
     return self;
@@ -65,7 +63,7 @@
 - (void) setSelected: (BOOL) flag forSegment: (NSInteger) segment
 {
     [super setSelected: flag forSegment: segment];
-    
+
     //only for when clicking manually
     NSInteger priority;
     switch (segment)
@@ -80,10 +78,10 @@
             priority = TR_PRI_HIGH;
             break;
     }
-    
+
     Torrent * torrent = [(FileListNode *)[self representedObject] torrent];
     [torrent setFilePriority: priority forIndexes: [(FileListNode *)[self representedObject] indexes]];
-    
+
     FileOutlineView * controlView = (FileOutlineView *)[self controlView];
     [controlView setNeedsDisplay: YES];
 }
@@ -92,16 +90,15 @@
             mouseLocation: (NSPoint) mouseLocation
 {
     NSTrackingAreaOptions options = NSTrackingEnabledDuringMouseDrag | NSTrackingMouseEnteredAndExited | NSTrackingActiveAlways;
-    
+
     if (NSMouseInRect(mouseLocation, cellFrame, [controlView isFlipped]))
     {
         options |= NSTrackingAssumeInside;
         [controlView setNeedsDisplayInRect: cellFrame];
     }
-    
+
     NSTrackingArea * area = [[NSTrackingArea alloc] initWithRect: cellFrame options: options owner: controlView userInfo: userInfo];
     [controlView addTrackingArea: area];
-    [area release];
 }
 
 - (void) setHovered: (BOOL) hovered
@@ -114,26 +111,26 @@
     FileListNode * node = [self representedObject];
     Torrent * torrent = [node torrent];
     NSSet * priorities = [torrent filePrioritiesForIndexes: [node indexes]];
-    
+
     const NSUInteger count = [priorities count];
     if (fHoverRow && count > 0)
     {
-        [super setSelected: [priorities containsObject: [NSNumber numberWithInteger: TR_PRI_LOW]] forSegment: 0];
-        [super setSelected: [priorities containsObject: [NSNumber numberWithInteger: TR_PRI_NORMAL]] forSegment: 1];
-        [super setSelected: [priorities containsObject: [NSNumber numberWithInteger: TR_PRI_HIGH]] forSegment: 2];
-        
+        [super setSelected: [priorities containsObject: @(TR_PRI_LOW)] forSegment: 0];
+        [super setSelected: [priorities containsObject: @(TR_PRI_NORMAL)] forSegment: 1];
+        [super setSelected: [priorities containsObject: @(TR_PRI_HIGH)] forSegment: 2];
+
         [super drawWithFrame: cellFrame inView: controlView];
     }
     else
     {
-        NSMutableArray * images = [NSMutableArray arrayWithCapacity: MAX(count, 1)];
+        NSMutableArray * images = [NSMutableArray arrayWithCapacity: MAX(count, 1u)];
         CGFloat totalWidth;
-        
+
         if (count == 0)
         {
             //if ([self backgroundStyle] != NSBackgroundStyleDark)
             {
-                NSImage * image = [[NSImage imageNamed: @"PriorityNormalTemplate.png"] imageWithColor: [NSColor lightGrayColor]];
+                NSImage * image = [[NSImage imageNamed: @"PriorityNormalTemplate"] imageWithColor: [NSColor lightGrayColor]];
                 [images addObject: image];
                 totalWidth = [image size].width;
             }
@@ -141,40 +138,40 @@
         else
         {
             NSColor * priorityColor = [self backgroundStyle] == NSBackgroundStyleDark ? [NSColor whiteColor] : [NSColor darkGrayColor];
-            
+
             totalWidth = 0.0;
-            if ([priorities containsObject: [NSNumber numberWithInteger: TR_PRI_LOW]])
+            if ([priorities containsObject: @(TR_PRI_LOW)])
             {
-                NSImage * image = [[NSImage imageNamed: @"PriorityLowTemplate.png"] imageWithColor: priorityColor];
+                NSImage * image = [[NSImage imageNamed: @"PriorityLowTemplate"] imageWithColor: priorityColor];
                 [images addObject: image];
                 totalWidth += [image size].width;
             }
-            if ([priorities containsObject: [NSNumber numberWithInteger: TR_PRI_NORMAL]])
+            if ([priorities containsObject: @(TR_PRI_NORMAL)])
             {
-                NSImage * image = [[NSImage imageNamed: @"PriorityNormalTemplate.png"] imageWithColor: priorityColor];
+                NSImage * image = [[NSImage imageNamed: @"PriorityNormalTemplate"] imageWithColor: priorityColor];
                 [images addObject: image];
                 totalWidth += [image size].width;
             }
-            if ([priorities containsObject: [NSNumber numberWithInteger: TR_PRI_HIGH]])
+            if ([priorities containsObject: @(TR_PRI_HIGH)])
             {
-                NSImage * image = [[NSImage imageNamed: @"PriorityHighTemplate.png"] imageWithColor: priorityColor];
+                NSImage * image = [[NSImage imageNamed: @"PriorityHighTemplate"] imageWithColor: priorityColor];
                 [images addObject: image];
                 totalWidth += [image size].width;
             }
         }
-        
+
         if (count > 1)
             totalWidth -= IMAGE_OVERLAP * (count-1);
-        
+
         CGFloat currentWidth = floor(NSMidX(cellFrame) - totalWidth * 0.5);
-        
+
         for (NSImage * image in images)
         {
             const NSSize imageSize = [image size];
             const NSRect imageRect = NSMakeRect(currentWidth, floor(NSMidY(cellFrame) - imageSize.height * 0.5), imageSize.width, imageSize.height);
-            
+
             [image drawInRect: imageRect fromRect: NSZeroRect operation: NSCompositeSourceOver fraction: 1.0 respectFlipped: YES hints: nil];
-            
+
             currentWidth += imageSize.width - IMAGE_OVERLAP;
         }
     }
