@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: FilterBarController.m 13414 2012-07-25 12:49:11Z livings124 $
- * 
  * Copyright (c) 2011-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -56,26 +54,26 @@
     [fDownloadFilterButton setTitle: NSLocalizedString(@"Downloading", "Filter Bar -> filter button")];
     [fSeedFilterButton setTitle: NSLocalizedString(@"Seeding", "Filter Bar -> filter button")];
     [fPauseFilterButton setTitle: NSLocalizedString(@"Paused", "Filter Bar -> filter button")];
-    
+
     [[fNoFilterButton cell] setBackgroundStyle: NSBackgroundStyleRaised];
     [[fActiveFilterButton cell] setBackgroundStyle: NSBackgroundStyleRaised];
     [[fDownloadFilterButton cell] setBackgroundStyle: NSBackgroundStyleRaised];
     [[fSeedFilterButton cell] setBackgroundStyle: NSBackgroundStyleRaised];
     [[fPauseFilterButton cell] setBackgroundStyle: NSBackgroundStyleRaised];
-    
+
     [[[[fSearchField cell] searchMenuTemplate] itemWithTag: FILTER_TYPE_TAG_NAME] setTitle:
         NSLocalizedString(@"Name", "Filter Bar -> filter menu")];
     [[[[fSearchField cell] searchMenuTemplate] itemWithTag: FILTER_TYPE_TAG_TRACKER] setTitle:
         NSLocalizedString(@"Tracker", "Filter Bar -> filter menu")];
-    
+
     [[[fGroupsButton menu] itemWithTag: GROUP_FILTER_ALL_TAG] setTitle:
         NSLocalizedString(@"All Groups", "Filter Bar -> group filter menu")];
-    
+
     [self resizeBar];
-    
+
     //set current filter
     NSString * filterType = [[NSUserDefaults standardUserDefaults] stringForKey: @"Filter"];
-    
+
     NSButton * currentFilterButton;
     if ([filterType isEqualToString: FILTER_ACTIVE])
         currentFilterButton = fActiveFilterButton;
@@ -93,10 +91,10 @@
         currentFilterButton = fNoFilterButton;
     }
     [currentFilterButton setState: NSOnState];
-    
+
     //set filter search type
     NSString * filterSearchType = [[NSUserDefaults standardUserDefaults] stringForKey: @"FilterSearchType"];
-    
+
     NSMenu * filterSearchMenu = [[fSearchField cell] searchMenuTemplate];
     NSString * filterSearchTypeTitle;
     if ([filterSearchType isEqualToString: FILTER_TYPE_TRACKER])
@@ -109,16 +107,16 @@
         filterSearchTypeTitle = [[filterSearchMenu itemWithTag: FILTER_TYPE_TAG_NAME] title];
     }
     [[fSearchField cell] setPlaceholderString: filterSearchTypeTitle];
-    
+
     NSString * searchString;
     if ((searchString = [[NSUserDefaults standardUserDefaults] stringForKey: @"FilterSearchString"]))
         [fSearchField setStringValue: searchString];
-    
+
     [self updateGroupsButton];
-    
+
     [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(resizeBar)
         name: NSWindowDidResizeNotification object: [[self view] window]];
-    
+
     //update when groups change
     [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(updateGroups:)
         name: @"UpdateGroups" object: nil];
@@ -127,14 +125,12 @@
 - (void) dealloc
 {
     [[NSNotificationCenter defaultCenter] removeObserver: self];
-    
-    [super dealloc];
 }
 
 - (void) setFilter: (id) sender
 {
     NSString * oldFilterType = [[NSUserDefaults standardUserDefaults] stringForKey: @"Filter"];
-    
+
     NSButton * prevFilterButton;
     if ([oldFilterType isEqualToString: FILTER_PAUSE])
         prevFilterButton = fPauseFilterButton;
@@ -146,7 +142,7 @@
         prevFilterButton = fDownloadFilterButton;
     else
         prevFilterButton = fNoFilterButton;
-    
+
     if (sender != prevFilterButton)
     {
         [prevFilterButton setState: NSOffState];
@@ -168,14 +164,14 @@
     }
     else
         [sender setState: NSOnState];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"ApplyFilter" object: nil];
 }
 
 - (void) switchFilter: (BOOL) right
 {
     NSString * filterType = [[NSUserDefaults standardUserDefaults] stringForKey: @"Filter"];
-    
+
     NSButton * button;
     if ([filterType isEqualToString: FILTER_NONE])
         button = right ? fActiveFilterButton : fPauseFilterButton;
@@ -189,7 +185,7 @@
         button = right ? fNoFilterButton : fSeedFilterButton;
     else
         button = fNoFilterButton;
-    
+
     [self setFilter: button];
 }
 
@@ -207,13 +203,13 @@
 - (void) setSearchType: (id) sender
 {
     NSString * oldFilterType = [[NSUserDefaults standardUserDefaults] stringForKey: @"FilterSearchType"];
-    
+
     NSInteger prevTag, currentTag = [sender tag];
     if ([oldFilterType isEqualToString: FILTER_TYPE_TRACKER])
         prevTag = FILTER_TYPE_TAG_TRACKER;
     else
         prevTag = FILTER_TYPE_TAG_NAME;
-    
+
     if (currentTag != prevTag)
     {
         NSString * filterType;
@@ -221,12 +217,12 @@
             filterType = FILTER_TYPE_TRACKER;
         else
             filterType = FILTER_TYPE_NAME;
-        
+
         [[NSUserDefaults standardUserDefaults] setObject: filterType forKey: @"FilterSearchType"];
-        
+
         [[fSearchField cell] setPlaceholderString: [sender title]];
     }
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"ApplyFilter" object: nil];
 }
 
@@ -234,20 +230,20 @@
 {
     [[NSUserDefaults standardUserDefaults] setInteger: [sender tag] forKey: @"FilterGroup"];
     [self updateGroupsButton];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"ApplyFilter" object: nil];
 }
 
 - (void) reset: (BOOL) updateUI
 {
     [[NSUserDefaults standardUserDefaults] setInteger: GROUP_FILTER_ALL_TAG forKey: @"FilterGroup"];
-    
+
     if (updateUI)
-    {   
+    {
         [self updateGroupsButton];
-        
+
         [self setFilter: fNoFilterButton];
-        
+
         [fSearchField setStringValue: @""];
         [self setSearchText: fSearchField];
     }
@@ -279,16 +275,15 @@
     {
         for (NSInteger i = [menu numberOfItems]-1; i >= 3; i--)
             [menu removeItemAtIndex: i];
-        
+
         NSMenu * groupMenu = [[GroupsController groups] groupMenuWithTarget: self action: @selector(setGroupFilter:) isSmall: YES];
-        
+
         const NSInteger groupMenuCount = [groupMenu numberOfItems];
         for (NSInteger i = 0; i < groupMenuCount; i++)
         {
-            NSMenuItem * item = [[groupMenu itemAtIndex: 0] retain];
+            NSMenuItem * item = [groupMenu itemAtIndex: 0];
             [groupMenu removeItemAtIndex: 0];
             [menu addItem: item];
-            [item release];
         }
     }
 }
@@ -296,29 +291,29 @@
 - (BOOL) validateMenuItem: (NSMenuItem *) menuItem
 {
     const SEL action = [menuItem action];
-    
+
     //check proper filter search item
     if (action == @selector(setSearchType:))
     {
         NSString * filterType = [[NSUserDefaults standardUserDefaults] stringForKey: @"FilterSearchType"];
-        
+
         BOOL state;
         if ([menuItem tag] == FILTER_TYPE_TAG_TRACKER)
             state = [filterType isEqualToString: FILTER_TYPE_TRACKER];
         else
             state = [filterType isEqualToString: FILTER_TYPE_NAME];
-        
+
         [menuItem setState: state ? NSOnState : NSOffState];
         return YES;
     }
-    
+
     if (action == @selector(setGroupFilter:))
     {
         [menuItem setState: [menuItem tag] == [[NSUserDefaults standardUserDefaults] integerForKey: @"FilterGroup"]
                                                 ? NSOnState : NSOffState];
         return YES;
     }
-    
+
     return YES;
 }
 
@@ -334,18 +329,18 @@
     [fDownloadFilterButton sizeToFit];
     [fSeedFilterButton sizeToFit];
     [fPauseFilterButton sizeToFit];
-    
+
     NSRect allRect = [fNoFilterButton frame];
     NSRect activeRect = [fActiveFilterButton frame];
     NSRect downloadRect = [fDownloadFilterButton frame];
     NSRect seedRect = [fSeedFilterButton frame];
     NSRect pauseRect = [fPauseFilterButton frame];
-    
+
     //size search filter to not overlap buttons
     NSRect searchFrame = [fSearchField frame];
     searchFrame.origin.x = NSMaxX(pauseRect) + 5.0;
     searchFrame.size.width = NSWidth([[self view] frame]) - searchFrame.origin.x - 5.0;
-    
+
     //make sure it is not too long
     if (NSWidth(searchFrame) > SEARCH_MAX_WIDTH)
     {
@@ -356,13 +351,13 @@
     {
         searchFrame.origin.x += NSWidth(searchFrame) - SEARCH_MIN_WIDTH;
         searchFrame.size.width = SEARCH_MIN_WIDTH;
-        
+
         //calculate width the buttons can take up
         const CGFloat allowedWidth = (searchFrame.origin.x - 5.0) - allRect.origin.x;
         const CGFloat currentWidth = NSWidth(allRect) + NSWidth(activeRect) + NSWidth(downloadRect) + NSWidth(seedRect)
                                         + NSWidth(pauseRect) + 4.0; //add 4 for space between buttons
         const CGFloat ratio = allowedWidth / currentWidth;
-        
+
         //decrease button widths proportionally
         allRect.size.width  = NSWidth(allRect) * ratio;
         activeRect.size.width = NSWidth(activeRect) * ratio;
@@ -371,25 +366,25 @@
         pauseRect.size.width = NSWidth(pauseRect) * ratio;
     }
     else;
-    
+
     activeRect.origin.x = NSMaxX(allRect) + 1.0;
     downloadRect.origin.x = NSMaxX(activeRect) + 1.0;
     seedRect.origin.x = NSMaxX(downloadRect) + 1.0;
     pauseRect.origin.x = NSMaxX(seedRect) + 1.0;
-    
+
     [fNoFilterButton setFrame: allRect];
     [fActiveFilterButton setFrame: activeRect];
     [fDownloadFilterButton setFrame: downloadRect];
     [fSeedFilterButton setFrame: seedRect];
     [fPauseFilterButton setFrame: pauseRect];
-    
+
     [fSearchField setFrame: searchFrame];
 }
 
 - (void) updateGroupsButton
 {
     const NSInteger groupIndex = [[NSUserDefaults standardUserDefaults] integerForKey: @"FilterGroup"];
-    
+
     NSImage * icon;
     NSString * toolTip;
     if (groupIndex == GROUP_FILTER_ALL_TAG)
@@ -404,7 +399,7 @@
                                                 : NSLocalizedString(@"None", "Groups -> Button");
         toolTip = [NSLocalizedString(@"Group", "Groups -> Button") stringByAppendingFormat: @": %@", groupName];
     }
-    
+
     [[[fGroupsButton menu] itemAtIndex: 0] setImage: icon];
     [fGroupsButton setToolTip: toolTip];
 }
