@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: InfoFileViewController.m 13309 2012-05-20 00:19:55Z livings124 $
- *
  * Copyright (c) 2010-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -44,7 +42,7 @@
     {
         [self setTitle: NSLocalizedString(@"Files", "Inspector view -> title")];
     }
-    
+
     return self;
 }
 
@@ -57,46 +55,39 @@
         viewRect.size.height = height;
         [[self view] setFrame: viewRect];
     }
-    
+
     [[fFileFilterField cell] setPlaceholderString: NSLocalizedString(@"Filter", "inspector -> file filter")];
-    
+
     //localize and place all and none buttons
     [fCheckAllButton setTitle: NSLocalizedString(@"All", "inspector -> check all")];
     [fUncheckAllButton setTitle: NSLocalizedString(@"None", "inspector -> check all")];
-    
+
     NSRect checkAllFrame = [fCheckAllButton frame];
     NSRect uncheckAllFrame = [fUncheckAllButton frame];
     const CGFloat oldAllWidth = checkAllFrame.size.width;
     const CGFloat oldNoneWidth = uncheckAllFrame.size.width;
-    
+
     [fCheckAllButton sizeToFit];
     [fUncheckAllButton sizeToFit];
     const CGFloat newWidth = MAX([fCheckAllButton bounds].size.width, [fUncheckAllButton bounds].size.width);
-    
+
     const CGFloat uncheckAllChange = newWidth - oldNoneWidth;
     uncheckAllFrame.size.width = newWidth;
     uncheckAllFrame.origin.x -= uncheckAllChange;
     [fUncheckAllButton setFrame: uncheckAllFrame];
-    
+
     const CGFloat checkAllChange = newWidth - oldAllWidth;
     checkAllFrame.size.width = newWidth;
     checkAllFrame.origin.x -= (checkAllChange + uncheckAllChange);
     [fCheckAllButton setFrame: checkAllFrame];
 }
 
-- (void) dealloc
-{
-    [fTorrents release];
-    
-    [super dealloc];
-}
 
 - (void) setInfoForTorrents: (NSArray *) torrents
 {
     //don't check if it's the same in case the metadata changed
-    [fTorrents release];
-    fTorrents = [torrents retain];
-    
+    fTorrents = torrents;
+
     fSet = NO;
 }
 
@@ -104,13 +95,13 @@
 {
     if (!fSet)
         [self setupInfo];
-    
+
     if ([fTorrents count] == 1)
     {
         [fFileController refresh];
-        
+
         #warning use TorrentFileCheckChange notification as well
-        Torrent * torrent = [fTorrents objectAtIndex: 0];
+        Torrent * torrent = fTorrents[0];
         if ([torrent isFolder])
         {
             const NSInteger filesCheckState = [torrent checkForFiles: [NSIndexSet indexSetWithIndexesInRange: NSMakeRange(0, [torrent fileCount])]];
@@ -143,17 +134,17 @@
 - (NSArray *) quickLookURLs
 {
     FileOutlineView * fileOutlineView = [fFileController outlineView];
-    Torrent * torrent = [fTorrents objectAtIndex: 0];
+    Torrent * torrent = fTorrents[0];
     NSIndexSet * indexes = [fileOutlineView selectedRowIndexes];
     NSMutableArray * urlArray = [NSMutableArray arrayWithCapacity: [indexes count]];
-    
+
     for (NSUInteger i = [indexes firstIndex]; i != NSNotFound; i = [indexes indexGreaterThanIndex: i])
     {
         FileListNode * item = [fileOutlineView itemAtRow: i];
         if ([self canQuickLookFile: item])
             [urlArray addObject: [NSURL fileURLWithPath: [torrent fileLocation: item]]];
     }
-    
+
     return urlArray;
 }
 
@@ -161,46 +152,46 @@
 {
     if ([fTorrents count] != 1)
         return NO;
-    
-    Torrent * torrent = [fTorrents objectAtIndex: 0];
+
+    Torrent * torrent = fTorrents[0];
     if (![torrent isFolder])
         return NO;
-    
+
     FileOutlineView * fileOutlineView = [fFileController outlineView];
     NSIndexSet * indexes = [fileOutlineView selectedRowIndexes];
-    
+
     for (NSUInteger i = [indexes firstIndex]; i != NSNotFound; i = [indexes indexGreaterThanIndex: i])
         if ([self canQuickLookFile: [fileOutlineView itemAtRow: i]])
             return YES;
-    
+
     return NO;
 }
 
 - (NSRect) quickLookSourceFrameForPreviewItem: (id <QLPreviewItem>) item
 {
     FileOutlineView * fileOutlineView = [fFileController outlineView];
-    
+
     NSString * fullPath = [(NSURL *)item path];
-    Torrent * torrent = [fTorrents objectAtIndex: 0];
+    Torrent * torrent = fTorrents[0];
     NSRange visibleRows = [fileOutlineView rowsInRect: [fileOutlineView bounds]];
-    
+
     for (NSUInteger row = visibleRows.location; row < NSMaxRange(visibleRows); row++)
     {
         FileListNode * rowItem = [fileOutlineView itemAtRow: row];
         if ([[torrent fileLocation: rowItem] isEqualToString: fullPath])
         {
             NSRect frame = [fileOutlineView iconRectForRow: row];
-            
+
             if (!NSIntersectsRect([fileOutlineView visibleRect], frame))
                 return NSZeroRect;
-            
+
             frame.origin = [fileOutlineView convertPoint: frame.origin toView: nil];
-            frame.origin = [[[self view] window] convertBaseToScreen: frame.origin];
+            frame = [[[self view] window] convertRectToScreen: frame];
             frame.origin.y -= frame.size.height;
             return frame;
         }
     }
-    
+
     return NSZeroRect;
 }
 
@@ -211,16 +202,16 @@
 - (void) setupInfo
 {
     [fFileFilterField setStringValue: @""];
-    
+
     if ([fTorrents count] == 1)
     {
-        Torrent * torrent = [fTorrents objectAtIndex: 0];
-        
+        Torrent * torrent = fTorrents[0];
+
         [fFileController setTorrent: torrent];
-        
+
         const BOOL isFolder = [torrent isFolder];
         [fFileFilterField setEnabled: isFolder];
-        
+
         if (!isFolder)
         {
             [fCheckAllButton setEnabled: NO];
@@ -230,19 +221,19 @@
     else
     {
         [fFileController setTorrent: nil];
-        
+
         [fFileFilterField setEnabled: NO];
-        
+
         [fCheckAllButton setEnabled: NO];
         [fUncheckAllButton setEnabled: NO];
     }
-    
+
     fSet = YES;
 }
 
 - (BOOL) canQuickLookFile: (FileListNode *) item
 {
-    Torrent * torrent = [fTorrents objectAtIndex: 0];
+    Torrent * torrent = fTorrents[0];
     return ([item isFolder] || [torrent fileProgress: item] >= 1.0) && [torrent fileLocation: item];
 }
 
