@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: InfoOptionsViewController.m 13601 2012-10-29 22:44:12Z livings124 $
- *
  * Copyright (c) 2010-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -52,100 +50,28 @@
     {
         [self setTitle: NSLocalizedString(@"Options", "Inspector view -> title")];
     }
-    
+
     return self;
 }
 
 - (void) awakeFromNib
 {
     [self setGlobalLabels];
-    
+
     [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(setGlobalLabels) name: @"UpdateGlobalOptions" object: nil];
     [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(updateOptionsNotification:) name: @"UpdateOptionsNotification" object: nil];
-    
-    #warning remove when 10.7-only with auto layout
-    const CGFloat padding = 6.0; //this shows as 8 in IB
-    [fPrioritySectionLabel sizeToFit];
-    [fPriorityLabel sizeToFit];
-    NSRect priorityPopUpFrame = [fPriorityPopUp frame];
-    priorityPopUpFrame.origin.x = NSMaxX([fPriorityLabel frame]) + padding;
-    [fPriorityPopUp setFrame: priorityPopUpFrame];
-    
-    [fTransferBandwidthSectionLabel sizeToFit];
-    [fDownloadLimitCheck sizeToFit];
-    [fUploadLimitCheck sizeToFit];
-    NSRect downloadLimitFieldFrame = [fDownloadLimitField frame];
-    NSRect uploadLimitFieldFrame = [fUploadLimitField frame];
-    const CGFloat speedLimitFieldX = MAX(NSMaxX([fDownloadLimitCheck frame]), NSMaxX([fUploadLimitCheck frame])) + padding;
-    downloadLimitFieldFrame.origin.x = speedLimitFieldX;
-    uploadLimitFieldFrame.origin.x = speedLimitFieldX;
-    [fDownloadLimitField setFrame: downloadLimitFieldFrame];
-    [fUploadLimitField setFrame: uploadLimitFieldFrame];
-    [fDownloadLimitLabel sizeToFit];
-    [fUploadLimitLabel sizeToFit];
-    NSRect downloadLimitLabelFrame = [fDownloadLimitLabel frame];
-    NSRect uploadLimitLabelFrame = [fUploadLimitLabel frame];
-    downloadLimitLabelFrame.origin.x = NSMaxX([fDownloadLimitField frame]) + padding;
-    uploadLimitLabelFrame.origin.x = NSMaxX([fUploadLimitField frame]) + padding;
-    [fDownloadLimitLabel setFrame: downloadLimitLabelFrame];
-    [fUploadLimitLabel setFrame: uploadLimitLabelFrame];
-    [fGlobalLimitCheck sizeToFit];
-    
-    [fSeedingLimitsSectionLabel sizeToFit];
-    [fRatioLabel sizeToFit];
-    [fInactivityLabel sizeToFit];
-    NSRect ratioPopUpFrame = [fRatioPopUp frame];
-    NSRect idlePopUpFrame = [fIdlePopUp frame];
-    const CGFloat seedingLimitPopUpX = MAX(NSMaxX([fRatioLabel frame]), NSMaxX([fInactivityLabel frame])) + padding;
-    ratioPopUpFrame.origin.x = seedingLimitPopUpX;
-    idlePopUpFrame.origin.x = seedingLimitPopUpX;
-    [fRatioPopUp setFrame: ratioPopUpFrame];
-    [fIdlePopUp setFrame: idlePopUpFrame];
-    NSRect ratioLimitFieldFrame = [fRatioLimitField frame];
-    NSRect idleLimitFieldFrame = [fIdleLimitField frame];
-    const CGFloat seedingLimitFieldX = NSMaxX(ratioPopUpFrame) + padding;
-    ratioLimitFieldFrame.origin.x = seedingLimitFieldX + 2.0;
-    idleLimitFieldFrame.origin.x = seedingLimitFieldX + 2.0;
-    [fRatioLimitField setFrame: ratioLimitFieldFrame];
-    [fIdleLimitField setFrame: idleLimitFieldFrame];
-    [fIdleLimitLabel sizeToFit];
-    NSRect idleLimitLabelFrame = [fIdleLimitLabel frame];
-    idleLimitLabelFrame.origin.x = NSMaxX(idleLimitFieldFrame) + padding;
-    [fIdleLimitLabel setFrame: idleLimitLabelFrame];
-    NSRect ratioLimitGlobalLabelFrame = [fRatioLimitGlobalLabel frame];
-    NSRect idleLimitGlobalLabelFrame = [fIdleLimitGlobalLabel frame];
-    ratioLimitGlobalLabelFrame.origin.x = seedingLimitFieldX;
-    idleLimitGlobalLabelFrame.origin.x = seedingLimitFieldX;
-    [fRatioLimitGlobalLabel setFrame: ratioLimitGlobalLabelFrame];
-    [fIdleLimitGlobalLabel setFrame: idleLimitGlobalLabelFrame];
-    [fRemoveSeedingCompleteCheck sizeToFit];
-    
-    [fAdvancedSectionLabel sizeToFit];
-    [fMaxConnectionsLabel sizeToFit];
-    NSRect peersConnectFrame = [fPeersConnectField frame];
-    peersConnectFrame.origin.x = NSMaxX([fMaxConnectionsLabel frame]) + padding;
-    [fPeersConnectField setFrame: peersConnectFrame];
-    [fPeersConnectLabel sizeToFit];
-    NSRect peersConnectLabelFrame = [fPeersConnectLabel frame];
-    peersConnectLabelFrame.origin.x = NSMaxX(peersConnectFrame) + padding;
-    [fPeersConnectLabel setFrame: peersConnectLabelFrame];
 }
 
 - (void) dealloc
 {
     [[NSNotificationCenter defaultCenter] removeObserver: self];
-    
-    [fTorrents release];
-    
-    [super dealloc];
 }
 
 - (void) setInfoForTorrents: (NSArray *) torrents
 {
     //don't check if it's the same in case the metadata changed
-    [fTorrents release];
-    fTorrents = [torrents retain];
-    
+    fTorrents = torrents;
+
     fSet = NO;
 }
 
@@ -153,7 +79,7 @@
 {
     if (!fSet)
         [self setupInfo];
-    
+
     fSet = YES;
 }
 
@@ -161,17 +87,17 @@
 {
     if ([fTorrents count] == 0)
         return;
-    
+
     //get bandwidth info
     NSEnumerator * enumerator = [fTorrents objectEnumerator];
     Torrent * torrent = [enumerator nextObject]; //first torrent
-    
+
     NSInteger uploadUseSpeedLimit = [torrent usesSpeedLimit: YES] ? NSOnState : NSOffState,
                 uploadSpeedLimit = [torrent speedLimit: YES],
                 downloadUseSpeedLimit = [torrent usesSpeedLimit: NO] ? NSOnState : NSOffState,
                 downloadSpeedLimit = [torrent speedLimit: NO],
                 globalUseSpeedLimit = [torrent usesGlobalSpeedLimit] ? NSOnState : NSOffState;
-    
+
     while ((torrent = [enumerator nextObject])
             && (uploadUseSpeedLimit != NSMixedState || uploadSpeedLimit != INVALID
                 || downloadUseSpeedLimit != NSMixedState || downloadSpeedLimit != INVALID
@@ -179,74 +105,74 @@
     {
         if (uploadUseSpeedLimit != NSMixedState && uploadUseSpeedLimit != ([torrent usesSpeedLimit: YES] ? NSOnState : NSOffState))
             uploadUseSpeedLimit = NSMixedState;
-        
+
         if (uploadSpeedLimit != INVALID && uploadSpeedLimit != [torrent speedLimit: YES])
             uploadSpeedLimit = INVALID;
-        
+
         if (downloadUseSpeedLimit != NSMixedState && downloadUseSpeedLimit != ([torrent usesSpeedLimit: NO] ? NSOnState : NSOffState))
             downloadUseSpeedLimit = NSMixedState;
-        
+
         if (downloadSpeedLimit != INVALID && downloadSpeedLimit != [torrent speedLimit: NO])
             downloadSpeedLimit = INVALID;
-        
+
         if (globalUseSpeedLimit != NSMixedState && globalUseSpeedLimit != ([torrent usesGlobalSpeedLimit] ? NSOnState : NSOffState))
             globalUseSpeedLimit = NSMixedState;
     }
-    
+
     //set upload view
     [fUploadLimitCheck setState: uploadUseSpeedLimit];
     [fUploadLimitCheck setEnabled: YES];
-    
+
     [fUploadLimitLabel setEnabled: uploadUseSpeedLimit == NSOnState];
     [fUploadLimitField setEnabled: uploadUseSpeedLimit == NSOnState];
     if (uploadSpeedLimit != INVALID)
         [fUploadLimitField setIntValue: uploadSpeedLimit];
     else
         [fUploadLimitField setStringValue: @""];
-    
+
     //set download view
     [fDownloadLimitCheck setState: downloadUseSpeedLimit];
     [fDownloadLimitCheck setEnabled: YES];
-    
+
     [fDownloadLimitLabel setEnabled: downloadUseSpeedLimit == NSOnState];
     [fDownloadLimitField setEnabled: downloadUseSpeedLimit == NSOnState];
     if (downloadSpeedLimit != INVALID)
         [fDownloadLimitField setIntValue: downloadSpeedLimit];
     else
         [fDownloadLimitField setStringValue: @""];
-    
+
     //set global check
     [fGlobalLimitCheck setState: globalUseSpeedLimit];
     [fGlobalLimitCheck setEnabled: YES];
-    
+
     //get ratio and idle info
     enumerator = [fTorrents objectEnumerator];
     torrent = [enumerator nextObject]; //first torrent
-    
+
     NSInteger checkRatio = [torrent ratioSetting], checkIdle = [torrent idleSetting],
             removeWhenFinishSeeding = [torrent removeWhenFinishSeeding] ? NSOnState : NSOffState;
     CGFloat ratioLimit = [torrent ratioLimit];
     NSUInteger idleLimit = [torrent idleLimitMinutes];
-    
+
     while ((torrent = [enumerator nextObject])
             && (checkRatio != INVALID || ratioLimit != INVALID || checkIdle != INVALID || idleLimit != INVALID))
     {
         if (checkRatio != INVALID && checkRatio != [torrent ratioSetting])
             checkRatio = INVALID;
-        
+
         if (ratioLimit != INVALID && ratioLimit != [torrent ratioLimit])
             ratioLimit = INVALID;
-        
+
         if (checkIdle != INVALID && checkIdle != [torrent idleSetting])
             checkIdle = INVALID;
-        
+
         if (idleLimit != INVALID && idleLimit != [torrent idleLimitMinutes])
             idleLimit = INVALID;
-        
+
         if (removeWhenFinishSeeding != NSMixedState && removeWhenFinishSeeding != ([torrent removeWhenFinishSeeding] ? NSOnState : NSOffState))
             removeWhenFinishSeeding = NSMixedState;
     }
-    
+
     //set ratio view
     NSInteger index;
     if (checkRatio == TR_RATIOLIMIT_SINGLE)
@@ -259,15 +185,15 @@
         index = -1;
     [fRatioPopUp selectItemAtIndex: index];
     [fRatioPopUp setEnabled: YES];
-    
+
     [fRatioLimitField setHidden: checkRatio != TR_RATIOLIMIT_SINGLE];
     if (ratioLimit != INVALID)
         [fRatioLimitField setFloatValue: ratioLimit];
     else
         [fRatioLimitField setStringValue: @""];
-    
+
     [fRatioLimitGlobalLabel setHidden: checkRatio != TR_RATIOLIMIT_GLOBAL];
-    
+
     //set idle view
     if (checkIdle == TR_IDLELIMIT_SINGLE)
         index = OPTION_POPUP_LIMIT;
@@ -279,32 +205,32 @@
         index = -1;
     [fIdlePopUp selectItemAtIndex: index];
     [fIdlePopUp setEnabled: YES];
-    
+
     [fIdleLimitField setHidden: checkIdle != TR_IDLELIMIT_SINGLE];
     if (idleLimit != INVALID)
         [fIdleLimitField setIntegerValue: idleLimit];
     else
         [fIdleLimitField setStringValue: @""];
     [fIdleLimitLabel setHidden: checkIdle != TR_IDLELIMIT_SINGLE];
-    
+
     [fIdleLimitGlobalLabel setHidden: checkIdle != TR_IDLELIMIT_GLOBAL];
-    
+
     //set remove transfer when seeding finishes
     [fRemoveSeedingCompleteCheck setState: removeWhenFinishSeeding];
     [fRemoveSeedingCompleteCheck setEnabled: YES];
-    
+
     //get priority info
     enumerator = [fTorrents objectEnumerator];
     torrent = [enumerator nextObject]; //first torrent
-    
+
     NSInteger priority = [torrent priority];
-    
+
     while ((torrent = [enumerator nextObject]) && priority != INVALID)
     {
         if (priority != INVALID && priority != [torrent priority])
             priority = INVALID;
     }
-    
+
     //set priority view
     if (priority == TR_PRI_HIGH)
         index = OPTION_POPUP_PRIORITY_HIGH;
@@ -316,13 +242,13 @@
         index = -1;
     [fPriorityPopUp selectItemAtIndex: index];
     [fPriorityPopUp setEnabled: YES];
-    
+
     //get peer info
     enumerator = [fTorrents objectEnumerator];
     torrent = [enumerator nextObject]; //first torrent
-    
+
     NSInteger maxPeers = [torrent maxPeerConnect];
-    
+
     while ((torrent = [enumerator nextObject]))
     {
         if (maxPeers != [torrent maxPeerConnect])
@@ -331,7 +257,7 @@
             break;
         }
     }
-    
+
     //set peer view
     [fPeersConnectField setEnabled: YES];
     [fPeersConnectLabel setEnabled: YES];
@@ -344,14 +270,14 @@
 - (void) setUseSpeedLimit: (id) sender
 {
     const BOOL upload = sender == fUploadLimitCheck;
-    
+
     if ([(NSButton *)sender state] == NSMixedState)
         [sender setState: NSOnState];
     const BOOL limit = [(NSButton *)sender state] == NSOnState;
-    
+
     for (Torrent * torrent in fTorrents)
         [torrent setUseSpeedLimit: limit upload: upload];
-    
+
     NSTextField * field = upload ? fUploadLimitField : fDownloadLimitField;
     [field setEnabled: limit];
     if (limit)
@@ -359,10 +285,10 @@
         [field selectText: self];
         [[[self view] window] makeKeyAndOrderFront: self];
     }
-    
+
     NSTextField * label = upload ? fUploadLimitLabel : fDownloadLimitLabel;
     [label setEnabled: limit];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptionsNotification" object: self];
 }
 
@@ -371,10 +297,10 @@
     if ([(NSButton *)sender state] == NSMixedState)
         [sender setState: NSOnState];
     const BOOL limit = [(NSButton *)sender state] == NSOnState;
-    
+
     for (Torrent * torrent in fTorrents)
         [torrent setUseGlobalSpeedLimit: limit];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptionsNotification" object: self];
 }
 
@@ -382,10 +308,10 @@
 {
     const BOOL upload = sender == fUploadLimitField;
     const NSInteger limit = [sender intValue];
-    
+
     for (Torrent * torrent in fTorrents)
         [torrent setSpeedLimit: limit upload: upload];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptionsNotification" object: self];
 }
 
@@ -409,29 +335,29 @@
             NSAssert1(NO, @"Unknown option selected in ratio popup: %ld", [sender indexOfSelectedItem]);
             return;
     }
-    
+
     for (Torrent * torrent in fTorrents)
         [torrent setRatioSetting: setting];
-    
+
     [fRatioLimitField setHidden: !single];
     if (single)
     {
         [fRatioLimitField selectText: self];
         [[[self view] window] makeKeyAndOrderFront: self];
     }
-    
+
     [fRatioLimitGlobalLabel setHidden: setting != TR_RATIOLIMIT_GLOBAL];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptionsNotification" object: self];
 }
 
 - (void) setRatioLimit: (id) sender
 {
     const CGFloat limit = [sender floatValue];
-    
+
     for (Torrent * torrent in fTorrents)
         [torrent setRatioLimit: limit];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptionsNotification" object: self];
 }
 
@@ -455,10 +381,10 @@
             NSAssert1(NO, @"Unknown option selected in idle popup: %ld", [sender indexOfSelectedItem]);
             return;
     }
-    
+
     for (Torrent * torrent in fTorrents)
         [torrent setIdleSetting: setting];
-    
+
     [fIdleLimitField setHidden: !single];
     [fIdleLimitLabel setHidden: !single];
     if (single)
@@ -466,19 +392,19 @@
         [fIdleLimitField selectText: self];
         [[[self view] window] makeKeyAndOrderFront: self];
     }
-    
+
     [fIdleLimitGlobalLabel setHidden: setting != TR_IDLELIMIT_GLOBAL];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptionsNotification" object: self];
 }
 
 - (void) setIdleLimit: (id) sender
 {
     const NSUInteger limit = [sender integerValue];
-    
+
     for (Torrent * torrent in fTorrents)
         [torrent setIdleLimitMinutes: limit];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptionsNotification" object: self];
 }
 
@@ -487,10 +413,10 @@
     if ([(NSButton *)sender state] == NSMixedState)
         [sender setState: NSOnState];
     const BOOL enable = [(NSButton *)sender state] == NSOnState;
-    
+
     for (Torrent * torrent in fTorrents)
         [torrent setRemoveWhenFinishSeeding: enable];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptionsNotification" object: self];
 }
 
@@ -512,30 +438,29 @@
             NSAssert1(NO, @"Unknown option selected in priority popup: %ld", [sender indexOfSelectedItem]);
             return;
     }
-    
+
     for (Torrent * torrent in fTorrents)
         [torrent setPriority: priority];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateUI" object: nil];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptionsNotification" object: self];
 }
 
 - (void) setPeersConnectLimit: (id) sender
 {
     NSInteger limit = [sender intValue];
-    
+
     for (Torrent * torrent in fTorrents)
         [torrent setMaxPeerConnect: limit];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptionsNotification" object: self];
 }
 
 - (BOOL) control: (NSControl *) control textShouldBeginEditing: (NSText *) fieldEditor
 {
-    [fInitialString release];
-    fInitialString = [[control stringValue] retain];
-    
+    fInitialString = [control stringValue];
+
     return YES;
 }
 
@@ -545,7 +470,6 @@
     if (fInitialString)
     {
         [control setStringValue: fInitialString];
-        [fInitialString release];
         fInitialString = nil;
     }
     return NO;
@@ -564,35 +488,35 @@
         [fUploadLimitField setEnabled: NO];
         [fUploadLimitLabel setEnabled: NO];
         [fUploadLimitField setStringValue: @""];
-        
+
         [fDownloadLimitCheck setEnabled: NO];
         [fDownloadLimitCheck setState: NSOffState];
         [fDownloadLimitField setEnabled: NO];
         [fDownloadLimitLabel setEnabled: NO];
         [fDownloadLimitField setStringValue: @""];
-        
+
         [fGlobalLimitCheck setEnabled: NO];
         [fGlobalLimitCheck setState: NSOffState];
-        
+
         [fPriorityPopUp setEnabled: NO];
         [fPriorityPopUp selectItemAtIndex: -1];
-        
+
         [fRatioPopUp setEnabled: NO];
         [fRatioPopUp selectItemAtIndex: -1];
         [fRatioLimitField setHidden: YES];
         [fRatioLimitField setStringValue: @""];
         [fRatioLimitGlobalLabel setHidden: YES];
-        
+
         [fIdlePopUp setEnabled: NO];
         [fIdlePopUp selectItemAtIndex: -1];
         [fIdleLimitField setHidden: YES];
         [fIdleLimitField setStringValue: @""];
         [fIdleLimitLabel setHidden: YES];
         [fIdleLimitGlobalLabel setHidden: YES];
-        
+
         [fRemoveSeedingCompleteCheck setEnabled: NO];
         [fRemoveSeedingCompleteCheck setState: NSOffState];
-        
+
         [fPeersConnectField setEnabled: NO];
         [fPeersConnectField setStringValue: @""];
         [fPeersConnectLabel setEnabled: NO];
@@ -607,7 +531,7 @@
         ? [NSString stringForRatio: [[NSUserDefaults standardUserDefaults] floatForKey: @"RatioLimit"]]
         : NSLocalizedString(@"disabled", "Info options -> global setting");
     [fRatioLimitGlobalLabel setStringValue: global];
-    
+
     //idle field
     NSString * globalIdle;
     if ([[NSUserDefaults standardUserDefaults] boolForKey: @"IdleLimitCheck"])
