@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: InfoPeersViewController.m 13434 2012-08-13 00:52:04Z livings124 $
- *
  * Copyright (c) 2010-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -22,6 +20,9 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
+#include <libtransmission/transmission.h>
+#include <libtransmission/utils.h>
+
 #import "InfoPeersViewController.h"
 #import "NSApplicationAdditions.h"
 #import "NSStringAdditions.h"
@@ -29,8 +30,8 @@
 #import "Torrent.h"
 #import "WebSeedTableView.h"
 
-#import "transmission.h" // required by utils.h
-#import "utils.h"
+#define ANIMATION_ID_KEY @"animationId"
+#define WEB_SEED_ANIMATION_ID @"webSeed"
 
 @interface InfoPeersViewController (Private)
 
@@ -49,7 +50,7 @@
     {
         [self setTitle: NSLocalizedString(@"Peers", "Inspector view -> title")];
     }
-    
+
     return self;
 }
 
@@ -62,7 +63,7 @@
         viewRect.size.height = height;
         [[self view] setFrame: viewRect];
     }
-    
+
     //set table header text
     [[[fPeerTable tableColumnWithIdentifier: @"IP"] headerCell] setStringValue: NSLocalizedString(@"IP Address",
                                                                         "inspector -> peer table -> header")];
@@ -72,12 +73,12 @@
                                                                         "inspector -> peer table -> header")];
     [[[fPeerTable tableColumnWithIdentifier: @"UL To"] headerCell] setStringValue: NSLocalizedString(@"UL",
                                                                         "inspector -> peer table -> header")];
-    
+
     [[[fWebSeedTable tableColumnWithIdentifier: @"Address"] headerCell] setStringValue: NSLocalizedString(@"Web Seeds",
                                                                         "inspector -> web seed table -> header")];
     [[[fWebSeedTable tableColumnWithIdentifier: @"DL From"] headerCell] setStringValue: NSLocalizedString(@"DL",
                                                                         "inspector -> web seed table -> header")];
-    
+
     //set table header tool tips
     [[fPeerTable tableColumnWithIdentifier: @"Encryption"] setHeaderToolTip: NSLocalizedString(@"Encrypted Connection",
                                                                         "inspector -> peer table -> header tool tip")];
@@ -87,37 +88,30 @@
                                                                         "inspector -> peer table -> header tool tip")];
     [[fPeerTable tableColumnWithIdentifier: @"UL To"] setHeaderToolTip: NSLocalizedString(@"Uploading To Peer",
                                                                         "inspector -> peer table -> header tool tip")];
-    
+
     [[fWebSeedTable tableColumnWithIdentifier: @"DL From"] setHeaderToolTip: NSLocalizedString(@"Downloading From Web Seed",
                                                                         "inspector -> web seed table -> header tool tip")];
-    
+
     //prepare for animating peer table and web seed table
-    NSRect webSeedTableFrame = [[fWebSeedTable enclosingScrollView] frame];
-    fWebSeedTableHeight = webSeedTableFrame.size.height;
-    fSpaceBetweenWebSeedAndPeer = webSeedTableFrame.origin.y - NSMaxY([[fPeerTable enclosingScrollView] frame]);
-    
+    fViewTopMargin = fWebSeedTableTopConstraint.constant;
+
+    CABasicAnimation * webSeedTableAnimation = [CABasicAnimation animation];
+    [webSeedTableAnimation setTimingFunction: [CAMediaTimingFunction functionWithName: kCAMediaTimingFunctionLinear]];
+    [webSeedTableAnimation setDuration: 0.125];
+    [webSeedTableAnimation setDelegate: self];
+    [webSeedTableAnimation setValue: WEB_SEED_ANIMATION_ID forKey: ANIMATION_ID_KEY];
+    [fWebSeedTableTopConstraint setAnimations: @{ @"constant": webSeedTableAnimation }];
+
     [self setWebSeedTableHidden: YES animate: NO];
 }
 
-- (void) dealloc
-{
-    [fTorrents release];
-    
-    [fPeers release];
-    [fWebSeeds release];
-    
-    [fWebSeedTableAnimation release];
-    
-    [super dealloc];
-}
 
 #warning subclass?
 - (void) setInfoForTorrents: (NSArray *) torrents
 {
     //don't check if it's the same in case the metadata changed
-    [fTorrents release];
-    fTorrents = [torrents retain];
-    
+    fTorrents = torrents;
+
     fSet = NO;
 }
 
@@ -125,20 +119,20 @@
 {
     if (!fSet)
         [self setupInfo];
-    
+
     if ([fTorrents count] == 0)
         return;
-    
+
     if (!fPeers)
         fPeers = [[NSMutableArray alloc] init];
     else
         [fPeers removeAllObjects];
-    
+
     if (!fWebSeeds)
         fWebSeeds = [[NSMutableArray alloc] init];
     else
         [fWebSeeds removeAllObjects];
-    
+
     NSUInteger connected = 0, tracker = 0, incoming = 0, cache = 0, lpd = 0, pex = 0, dht = 0, ltep = 0,
                 toUs = 0, fromUs = 0;
     BOOL anyActive = false;
@@ -146,12 +140,12 @@
     {
         if ([torrent webSeedCount] > 0)
             [fWebSeeds addObjectsFromArray: [torrent webSeeds]];
-        
+
         if ([torrent isActive])
         {
             anyActive = YES;
             [fPeers addObjectsFromArray: [torrent peers]];
-            
+
             const NSUInteger connectedThis = [torrent totalPeersConnected];
             if (connectedThis > 0)
             {
@@ -163,25 +157,25 @@
                 pex += [torrent totalPeersPex];
                 dht += [torrent totalPeersDHT];
                 ltep += [torrent totalPeersLTEP];
-                
+
                 toUs += [torrent peersSendingToUs];
                 fromUs += [torrent peersGettingFromUs];
             }
         }
     }
-    
+
     [fPeers sortUsingDescriptors: [self peerSortDescriptors]];
     [fPeerTable reloadData];
-    
+
     [fWebSeeds sortUsingDescriptors: [fWebSeedTable sortDescriptors]];
     [fWebSeedTable reloadData];
     [fWebSeedTable setWebSeeds: fWebSeeds];
-    
+
     if (anyActive)
     {
         NSString * connectedText = [NSString stringWithFormat: NSLocalizedString(@"%d Connected", "Inspector -> Peers tab -> peers"),
                                     connected];
-        
+
         if (connected > 0)
         {
             NSMutableArray * upDownComponents = [NSMutableArray arrayWithCapacity: 2];
@@ -193,7 +187,7 @@
                                         NSLocalizedString(@"UL to %d", "Inspector -> Peers tab -> peers"), fromUs]];
             if ([upDownComponents count] > 0)
                 connectedText = [connectedText stringByAppendingFormat: @": %@", [upDownComponents componentsJoinedByString: @", "]];
-            
+
             NSMutableArray * fromComponents = [NSMutableArray arrayWithCapacity: 7];
             if (tracker > 0)
                 [fromComponents addObject: [NSString stringWithFormat:
@@ -216,10 +210,10 @@
             if (ltep > 0)
                 [fromComponents addObject: [NSString stringWithFormat:
                                         NSLocalizedString(@"%d LTEP", "Inspector -> Peers tab -> peers"), ltep]];
-            
+
             connectedText = [connectedText stringByAppendingFormat: @"\n%@", [fromComponents componentsJoinedByString: @", "]];
         }
-        
+
         [fConnectedPeersField setStringValue: connectedText];
     }
     else
@@ -229,7 +223,7 @@
             notActiveString = NSLocalizedString(@"Transfer Not Active", "Inspector -> Peers tab -> peers");
         else
             notActiveString = NSLocalizedString(@"Transfers Not Active", "Inspector -> Peers tab -> peers");
-        
+
         [fConnectedPeersField setStringValue: notActiveString];
     }
 }
@@ -241,13 +235,7 @@
 
 - (void) clearView
 {
-    //if in the middle of animating, just stop and resize immediately
-    if (fWebSeedTableAnimation)
-        [self setWebSeedTableHidden: !fWebSeeds animate: NO];
-    
-    [fPeers release];
     fPeers = nil;
-    [fWebSeeds release];
     fWebSeeds = nil;
 }
 
@@ -264,39 +252,39 @@
     if (tableView == fWebSeedTable)
     {
         NSString * ident = [column identifier];
-        NSDictionary * webSeed = [fWebSeeds objectAtIndex: row];
-        
+        NSDictionary * webSeed = fWebSeeds[row];
+
         if ([ident isEqualToString: @"DL From"])
         {
             NSNumber * rate;
-            return (rate = [webSeed objectForKey: @"DL From Rate"]) ? [NSString stringForSpeedAbbrev: [rate doubleValue]] : @"";
+            return (rate = webSeed[@"DL From Rate"]) ? [NSString stringForSpeedAbbrev: [rate doubleValue]] : @"";
         }
         else
-            return [webSeed objectForKey: @"Address"];
+            return webSeed[@"Address"];
     }
     else
     {
         NSString * ident = [column identifier];
-        NSDictionary * peer = [fPeers objectAtIndex: row];
-        
+        NSDictionary * peer = fPeers[row];
+
         if ([ident isEqualToString: @"Encryption"])
-            return [[peer objectForKey: @"Encryption"] boolValue] ? [NSImage imageNamed: @"Lock"] : nil;
+            return [peer[@"Encryption"] boolValue] ? [NSImage imageNamed: @"Lock"] : nil;
         else if ([ident isEqualToString: @"Client"])
-            return [peer objectForKey: @"Client"];
+            return peer[@"Client"];
         else if  ([ident isEqualToString: @"Progress"])
-            return [peer objectForKey: @"Progress"];
+            return peer[@"Progress"];
         else if ([ident isEqualToString: @"UL To"])
         {
             NSNumber * rate;
-            return (rate = [peer objectForKey: @"UL To Rate"]) ? [NSString stringForSpeedAbbrev: [rate doubleValue]] : @"";
+            return (rate = peer[@"UL To Rate"]) ? [NSString stringForSpeedAbbrev: [rate doubleValue]] : @"";
         }
         else if ([ident isEqualToString: @"DL From"])
         {
             NSNumber * rate;
-            return (rate = [peer objectForKey: @"DL From Rate"]) ? [NSString stringForSpeedAbbrev: [rate doubleValue]] : @"";
+            return (rate = peer[@"DL From Rate"]) ? [NSString stringForSpeedAbbrev: [rate doubleValue]] : @"";
         }
         else
-            return [peer objectForKey: @"IP"];
+            return peer[@"IP"];
     }
 }
 
@@ -306,11 +294,11 @@
     if (tableView == fPeerTable)
     {
         NSString * ident = [tableColumn identifier];
-        
+
         if  ([ident isEqualToString: @"Progress"])
         {
-            NSDictionary * peer = [fPeers objectAtIndex: row];
-            [(PeerProgressIndicatorCell *)cell setSeed: [[peer objectForKey: @"Seed"] boolValue]];
+            NSDictionary * peer = fPeers[row];
+            [(PeerProgressIndicatorCell *)cell setSeed: [peer[@"Seed"] boolValue]];
         }
     }
 }
@@ -346,40 +334,40 @@
     if (tableView == fPeerTable)
     {
         const BOOL multiple = [fTorrents count] > 1;
-        
-        NSDictionary * peer = [fPeers objectAtIndex: row];
+
+        NSDictionary * peer = fPeers[row];
         NSMutableArray * components = [NSMutableArray arrayWithCapacity: multiple ? 6 : 5];
-        
+
         if (multiple)
-            [components addObject: [peer objectForKey: @"Name"]];
-        
-        const CGFloat progress = [[peer objectForKey: @"Progress"] floatValue];
+            [components addObject: peer[@"Name"]];
+
+        const CGFloat progress = [peer[@"Progress"] floatValue];
         NSString * progressString = [NSString stringWithFormat: NSLocalizedString(@"Progress: %@",
                                         "Inspector -> Peers tab -> table row tooltip"),
                                         [NSString percentString: progress longDecimals: NO]];
-        if (progress < 1.0 && [[peer objectForKey: @"Seed"] boolValue])
+        if (progress < 1.0 && [peer[@"Seed"] boolValue])
             progressString = [progressString stringByAppendingFormat: @" (%@)", NSLocalizedString(@"Partial Seed",
                                 "Inspector -> Peers tab -> table row tooltip")];
         [components addObject: progressString];
-        
-        NSString * protocolString = [[peer objectForKey: @"uTP"] boolValue] ? @"\u00b5TP" : @"TCP";
-        if ([[peer objectForKey: @"Encryption"] boolValue])
+
+        NSString * protocolString = [peer[@"uTP"] boolValue] ? @"\u00b5TP" : @"TCP";
+        if ([peer[@"Encryption"] boolValue])
             protocolString = [protocolString stringByAppendingFormat: @" (%@)",
                                 NSLocalizedString(@"encrypted", "Inspector -> Peers tab -> table row tooltip")];
         [components addObject: [NSString stringWithFormat:
                                 NSLocalizedString(@"Protocol: %@", "Inspector -> Peers tab -> table row tooltip"),
                                 protocolString]];
-        
+
         NSString * portString;
         NSInteger port;
-        if ((port = [[peer objectForKey: @"Port"] intValue]) > 0)
+        if ((port = [peer[@"Port"] intValue]) > 0)
             portString = [NSString stringWithFormat: @"%ld", port];
         else
             portString = NSLocalizedString(@"N/A", "Inspector -> Peers tab -> table row tooltip");
         [components addObject: [NSString stringWithFormat: @"%@: %@", NSLocalizedString(@"Port",
             "Inspector -> Peers tab -> table row tooltip"), portString]];
-        
-        const NSInteger peerFrom = [[peer objectForKey: @"From"] integerValue];
+
+        const NSInteger peerFrom = [peer[@"From"] integerValue];
         switch (peerFrom)
         {
             case TR_PEER_FROM_TRACKER:
@@ -407,11 +395,11 @@
             default:
                 NSAssert1(NO, @"Peer from unknown source: %ld", peerFrom);
         }
-        
+
         //determing status strings from flags
         NSMutableArray * statusArray = [NSMutableArray arrayWithCapacity: 6];
-        NSString * flags = [peer objectForKey: @"Flags"];
-        
+        NSString * flags = peer[@"Flags"];
+
         if ([flags rangeOfString: @"D"].location != NSNotFound)
             [statusArray addObject: NSLocalizedString(@"Currently downloading (interested and not choked)",
                 "Inspector -> peer -> status")];
@@ -430,41 +418,38 @@
         if ([flags rangeOfString: @"?"].location != NSNotFound)
             [statusArray addObject: NSLocalizedString(@"You unchoked the peer, but the peer is not interested",
                 "Inspector -> peer -> status")];
-        
+
         if ([statusArray count] > 0)
         {
             NSString * statusStrings = [statusArray componentsJoinedByString: @"\n\n"];
             [components addObject: [@"\n" stringByAppendingString: statusStrings]];
         }
-        
+
         return [components componentsJoinedByString: @"\n"];
     }
     else
     {
         if ([fTorrents count] > 1)
-            return [[fWebSeeds objectAtIndex: row] objectForKey: @"Name"];
+            return fWebSeeds[row][@"Name"];
     }
-    
+
     return nil;
 }
 
-- (void) animationDidEnd: (NSAnimation *) animation
+- (void) animationDidStart: (CAAnimation *) animation
 {
-    if (animation == fWebSeedTableAnimation)
-    {
-        [fWebSeedTableAnimation release];
-        fWebSeedTableAnimation = nil;
-    }
+    if (![[animation valueForKey: ANIMATION_ID_KEY] isEqualToString: WEB_SEED_ANIMATION_ID])
+        return;
+
+    [[fWebSeedTable enclosingScrollView] setHidden: NO];
 }
 
-- (void) stopWebSeedAnimation
+- (void) animationDidStop: (CAAnimation *) animation finished: (BOOL) finished
 {
-    if (fWebSeedTableAnimation)
-    {
-        [fWebSeedTableAnimation stopAnimation]; // jumps to end frame
-        [fWebSeedTableAnimation release];
-        fWebSeedTableAnimation = nil;
-    }
+    if (![[animation valueForKey: ANIMATION_ID_KEY] isEqualToString: WEB_SEED_ANIMATION_ID])
+        return;
+
+    [[fWebSeedTable enclosingScrollView] setHidden: finished && fWebSeedTableTopConstraint.constant < 0];
 }
 
 @end
@@ -474,13 +459,12 @@
 - (void) setupInfo
 {
     __block BOOL hasWebSeeds = NO;
-    
+
     if ([fTorrents count] == 0)
     {
-        [fPeers release];
         fPeers = nil;
         [fPeerTable reloadData];
-        
+
         [fConnectedPeersField setStringValue: @""];
     }
     else
@@ -493,17 +477,16 @@
             }
         }];
     }
-    
+
     if (!hasWebSeeds)
     {
-        [fWebSeeds release];
         fWebSeeds = nil;
         [fWebSeedTable reloadData];
     }
     else
         [fWebSeedTable deselectAll: self];
     [self setWebSeedTableHidden: !hasWebSeeds animate: YES];
-    
+
     fSet = YES;
 }
 
@@ -511,84 +494,34 @@
 {
     if (animate && (![[self view] window] || ![[[self view] window] isVisible]))
         animate = NO;
-    
-    if (fWebSeedTableAnimation)
-    {
-        [fWebSeedTableAnimation stopAnimation];
-        [fWebSeedTableAnimation release];
-        fWebSeedTableAnimation = nil;
-    }
-    
-    NSRect webSeedFrame = [[fWebSeedTable enclosingScrollView] frame];
-    NSRect peerFrame = [[fPeerTable enclosingScrollView] frame];
-    
-    if (hide)
-    {
-        CGFloat webSeedFrameMaxY = NSMaxY(webSeedFrame);
-        webSeedFrame.size.height = 0;
-        webSeedFrame.origin.y = webSeedFrameMaxY;
-        
-        peerFrame.size.height = webSeedFrameMaxY - peerFrame.origin.y;
-    }
-    else
-    {
-        webSeedFrame.origin.y -= fWebSeedTableHeight - webSeedFrame.size.height;
-        webSeedFrame.size.height = fWebSeedTableHeight;
-        
-        peerFrame.size.height = (webSeedFrame.origin.y - fSpaceBetweenWebSeedAndPeer) - peerFrame.origin.y;
-    }
-    
-    [[fWebSeedTable enclosingScrollView] setHidden: NO]; //this is needed for some reason
-    
-    //actually resize tables
-    if (animate)
-    {
-        NSDictionary * webSeedDict = [NSDictionary dictionaryWithObjectsAndKeys:
-                                    [fWebSeedTable enclosingScrollView], NSViewAnimationTargetKey,
-                                    [NSValue valueWithRect: [[fWebSeedTable enclosingScrollView] frame]], NSViewAnimationStartFrameKey,
-                                    [NSValue valueWithRect: webSeedFrame], NSViewAnimationEndFrameKey, nil],
-                    * peerDict = [NSDictionary dictionaryWithObjectsAndKeys:
-                                    [fPeerTable enclosingScrollView], NSViewAnimationTargetKey,
-                                    [NSValue valueWithRect: [[fPeerTable enclosingScrollView] frame]], NSViewAnimationStartFrameKey,
-                                    [NSValue valueWithRect: peerFrame], NSViewAnimationEndFrameKey, nil];
-        
-        fWebSeedTableAnimation = [[NSViewAnimation alloc] initWithViewAnimations:
-                                        [NSArray arrayWithObjects: webSeedDict, peerDict, nil]];
-        [fWebSeedTableAnimation setDuration: 0.125];
-        [fWebSeedTableAnimation setAnimationBlockingMode: NSAnimationNonblocking];
-        [fWebSeedTableAnimation setDelegate: self];
-        
-        [fWebSeedTableAnimation startAnimation];
-    }
-    else
-    {
-        [[fWebSeedTable enclosingScrollView] setFrame: webSeedFrame];
-        [[fPeerTable enclosingScrollView] setFrame: peerFrame];
-    }
+
+    const CGFloat webSeedTableTopMargin = hide ? -NSHeight([[fWebSeedTable enclosingScrollView] frame]) : fViewTopMargin;
+
+    [(animate ? [fWebSeedTableTopConstraint animator] : fWebSeedTableTopConstraint) setConstant: webSeedTableTopMargin];
 }
 
 - (NSArray *) peerSortDescriptors
 {
     NSMutableArray * descriptors = [NSMutableArray arrayWithCapacity: 2];
-    
+
     NSArray * oldDescriptors = [fPeerTable sortDescriptors];
     BOOL useSecond = YES, asc = YES;
     if ([oldDescriptors count] > 0)
     {
-        NSSortDescriptor * descriptor = [oldDescriptors objectAtIndex: 0];
+        NSSortDescriptor * descriptor = oldDescriptors[0];
         [descriptors addObject: descriptor];
-        
+
         if ((useSecond = ![[descriptor key] isEqualToString: @"IP"]))
             asc = [descriptor ascending];
     }
-    
+
     //sort by IP after primary sort
     if (useSecond)
     {
         NSSortDescriptor * secondDescriptor = [NSSortDescriptor sortDescriptorWithKey: @"IP" ascending: asc selector: @selector(compareNumeric:)];
         [descriptors addObject: secondDescriptor];
     }
-    
+
     return descriptors;
 }
 
