@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: InfoTabButtonBack.m 13251 2012-03-13 02:52:11Z livings124 $
- *
  * Copyright (c) 2011-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -23,56 +21,60 @@
  *****************************************************************************/
 
 #import "InfoTabButtonBack.h"
+#import "NSApplicationAdditions.h"
 
 @implementation InfoTabButtonBack
 
-- (id) initWithFrame: (NSRect) rect
-{
-    if ((self = [super initWithFrame: rect]))
-    {
-        NSColor * lightColor = [NSColor colorWithCalibratedRed: 245.0/255.0 green: 245.0/255.0 blue: 245.0/255.0 alpha: 1.0];
-        NSColor * darkColor = [NSColor colorWithCalibratedRed: 215.0/255.0 green: 215.0/255.0 blue: 215.0/255.0 alpha: 1.0];
-        fGradient = [[NSGradient alloc] initWithStartingColor: lightColor endingColor: darkColor];
-    }
-    return self;
-}
-
-- (void) dealloc
-{
-    [fGradient release];
-    [super dealloc];
-}
 
 - (void) drawRect: (NSRect) rect
 {
     NSInteger count = 0;
     NSRect gridRects[2];
     NSColor * colorRects[2];
-    
+
     NSRect lineBorderRect = NSMakeRect(NSMinX(rect), NSHeight([self bounds]) - 1.0, NSWidth(rect), 1.0);
     if (NSIntersectsRect(lineBorderRect, rect))
     {
         gridRects[count] = lineBorderRect;
-        colorRects[count] = [NSColor grayColor];
+        if (@available(macOS 10.14, *)) {
+            colorRects[count] = [NSColor separatorColor];
+        } else {
+            colorRects[count] = [NSColor grayColor];
+        }
         ++count;
-        
+
         rect.size.height -= 1.0;
     }
-    
+
     lineBorderRect.origin.y = 0.0;
     if (NSIntersectsRect(lineBorderRect, rect))
     {
         gridRects[count] = lineBorderRect;
-        colorRects[count] = [NSColor grayColor];
+        if (@available(macOS 10.14, *)) {
+            colorRects[count] = [NSColor separatorColor];
+        } else {
+            colorRects[count] = [NSColor grayColor];
+        }
         ++count;
-        
+
         rect.origin.y += 1.0;
         rect.size.height -= 1.0;
     }
-    
+
     NSRectFillListWithColors(gridRects, colorRects, count);
-    
-    [fGradient drawInRect: rect angle: 270.0];
+
+    NSGradient *gradient;
+
+    if ([NSApp isDarkMode]) {
+        NSColor * darkColor = [NSColor colorWithCalibratedRed: 60.0/255.0 green: 60.0/255.0 blue: 60.0/255.0 alpha: 1.0];
+        NSColor * lightColor = [NSColor colorWithCalibratedRed: 90.0/255.0 green: 90.0/255.0 blue: 90.0/255.0 alpha: 1.0];
+        gradient = [[NSGradient alloc] initWithStartingColor: lightColor endingColor: darkColor];
+    } else {
+        NSColor * lightColor = [NSColor colorWithCalibratedRed: 245.0/255.0 green: 245.0/255.0 blue: 245.0/255.0 alpha: 1.0];
+        NSColor * darkColor = [NSColor colorWithCalibratedRed: 215.0/255.0 green: 215.0/255.0 blue: 215.0/255.0 alpha: 1.0];
+        gradient = [[NSGradient alloc] initWithStartingColor: lightColor endingColor: darkColor];
+    }
+    [gradient drawInRect: rect angle: 270.0];
 }
 
 @end
