@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: InfoTrackersViewController.m 13434 2012-08-13 00:52:04Z livings124 $
- *
  * Copyright (c) 2010-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -51,10 +49,10 @@
     if ((self = [super initWithNibName: @"InfoTrackersView" bundle: nil]))
     {
         [self setTitle: NSLocalizedString(@"Trackers", "Inspector view -> title")];
-        
+
         fTrackerCell = [[TrackerCell alloc] init];
     }
-    
+
     return self;
 }
 
@@ -64,7 +62,7 @@
         forSegment: TRACKER_ADD_TAG];
     [[fTrackerAddRemoveControl cell] setToolTip: NSLocalizedString(@"Remove selected trackers", "Inspector view -> tracker buttons")
         forSegment: TRACKER_REMOVE_TAG];
-    
+
     const CGFloat height = [[NSUserDefaults standardUserDefaults] floatForKey: @"InspectorContentHeightTracker"];
     if (height != 0.0)
     {
@@ -74,21 +72,12 @@
     }
 }
 
-- (void) dealloc
-{
-    [fTorrents release];
-    [fTrackers release];
-    [fTrackerCell release];
-    
-    [super dealloc];
-}
 
 - (void) setInfoForTorrents: (NSArray *) torrents
 {
     //don't check if it's the same in case the metadata changed
-    [fTorrents release];
-    fTorrents = [torrents retain];
-    
+    fTorrents = torrents;
+
     fSet = NO;
 }
 
@@ -96,46 +85,44 @@
 {
     if (!fSet)
         [self setupInfo];
-    
+
     if ([fTorrents count] == 0)
         return;
-    
+
     //get updated tracker stats
     if ([fTrackerTable editedRow] == -1)
     {
         NSArray * oldTrackers = fTrackers;
-        
+
         if ([fTorrents count] == 1)
-            fTrackers = [[[fTorrents objectAtIndex: 0] allTrackerStats] retain];
+            fTrackers = [fTorrents[0] allTrackerStats];
         else
         {
             fTrackers = [[NSMutableArray alloc] init];
             for (Torrent * torrent in fTorrents)
                 [fTrackers addObjectsFromArray: [torrent allTrackerStats]];
         }
-        
+
         [fTrackerTable setTrackers: fTrackers];
-        
-        if ([NSApp isOnLionOrBetter] && (oldTrackers && [fTrackers isEqualToArray: oldTrackers]))
+
+        if (oldTrackers && [fTrackers isEqualToArray: oldTrackers])
             [fTrackerTable setNeedsDisplay: YES];
         else
             [fTrackerTable reloadData];
-        
-        [oldTrackers release];
+
     }
     else
     {
         NSAssert1([fTorrents count] == 1, @"Attempting to add tracker with %ld transfers selected", [fTorrents count]);
-        
+
         NSIndexSet * addedIndexes = [NSIndexSet indexSetWithIndexesInRange: NSMakeRange([fTrackers count]-2, 2)];
         NSArray * tierAndTrackerBeingAdded = [fTrackers objectsAtIndexes: addedIndexes];
-        
-        [fTrackers release];
-        fTrackers = [[[fTorrents objectAtIndex: 0] allTrackerStats] retain];
+
+        fTrackers = [fTorrents[0] allTrackerStats];
         [fTrackers addObjectsFromArray: tierAndTrackerBeingAdded];
-        
+
         [fTrackerTable setTrackers: fTrackers];
-        
+
         NSIndexSet * updateIndexes = [NSIndexSet indexSetWithIndexesInRange: NSMakeRange(0, [fTrackers count]-2)],
                 * columnIndexes = [NSIndexSet indexSetWithIndexesInRange: NSMakeRange(0, [[fTrackerTable tableColumns] count])];
         [fTrackerTable reloadDataForRowIndexes: updateIndexes columnIndexes: columnIndexes];
@@ -149,7 +136,6 @@
 
 - (void) clearView
 {
-    [fTrackers release];
     fTrackers = nil;
 }
 
@@ -160,16 +146,16 @@
 
 - (id) tableView: (NSTableView *) tableView objectValueForTableColumn: (NSTableColumn *) column row: (NSInteger) row
 {
-    id item = [fTrackers objectAtIndex: row]; 
-    
+    id item = fTrackers[row];
+
     if ([item isKindOfClass: [NSDictionary class]])
     {
-        const NSInteger tier = [[item objectForKey: @"Tier"] integerValue];
+        const NSInteger tier = [item[@"Tier"] integerValue];
         NSString * tierString = tier == -1 ? NSLocalizedString(@"New Tier", "Inspector -> tracker table")
                                 : [NSString stringWithFormat: NSLocalizedString(@"Tier %d", "Inspector -> tracker table"), tier];
-        
+
         if ([fTorrents count] > 1)
-            tierString = [tierString stringByAppendingFormat: @" - %@", [item objectForKey: @"Name"]];
+            tierString = [tierString stringByAppendingFormat: @" - %@", item[@"Name"]];
         return tierString;
     }
     else
@@ -178,14 +164,14 @@
 
 - (NSCell *) tableView: (NSTableView *) tableView dataCellForTableColumn: (NSTableColumn *) tableColumn row: (NSInteger) row
 {
-    const BOOL tracker = [[fTrackers objectAtIndex: row] isKindOfClass: [TrackerNode class]];
+    const BOOL tracker = [fTrackers[row] isKindOfClass: [TrackerNode class]];
     return tracker ? fTrackerCell : [tableColumn dataCellForRow: row];
 }
 
 - (CGFloat) tableView: (NSTableView *) tableView heightOfRow: (NSInteger) row
 {
     //check for NSDictionay instead of TrackerNode because of display issue when adding a row
-    if ([[fTrackers objectAtIndex: row] isKindOfClass: [NSDictionary class]])
+    if ([fTrackers[row] isKindOfClass: [NSDictionary class]])
         return TRACKER_GROUP_SEPARATOR_HEIGHT;
     else
         return [tableView rowHeight];
@@ -204,13 +190,13 @@
 
 - (BOOL) tableView: (NSTableView *) tableView isGroupRow: (NSInteger) row
 {
-    return ![[fTrackers objectAtIndex: row] isKindOfClass: [TrackerNode class]] && [tableView editedRow] != row;
+    return ![fTrackers[row] isKindOfClass: [TrackerNode class]] && [tableView editedRow] != row;
 }
 
 - (NSString *) tableView: (NSTableView *) tableView toolTipForCell: (NSCell *) cell rect: (NSRectPointer) rect
                 tableColumn: (NSTableColumn *) column row: (NSInteger) row mouseLocation: (NSPoint) mouseLocation
 {
-    id node = [fTrackers objectAtIndex: row];
+    id node = fTrackers[row];
     if ([node isKindOfClass: [TrackerNode class]])
         return [(TrackerNode *)node fullAnnounceAddress];
     else
@@ -220,24 +206,23 @@
 - (void) tableView: (NSTableView *) tableView setObjectValue: (id) object forTableColumn: (NSTableColumn *) tableColumn
     row: (NSInteger) row
 {
-    Torrent * torrent= [fTorrents objectAtIndex: 0];
-    
+    Torrent * torrent= fTorrents[0];
+
     BOOL added = NO;
     for (NSString * tracker in [object componentsSeparatedByString: @"\n"])
         if ([torrent addTrackerToNewTier: tracker])
             added = YES;
-    
+
     if (!added)
         NSBeep();
-    
+
     //reset table with either new or old value
-    [fTrackers release];
-    fTrackers = [[torrent allTrackerStats] retain];
-    
+    fTrackers = [torrent allTrackerStats];
+
     [fTrackerTable setTrackers: fTrackers];
     [fTrackerTable reloadData];
     [fTrackerTable deselectAll: self];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateUI" object: nil]; //incase sort by tracker
 }
 
@@ -246,9 +231,9 @@
     //don't allow add/remove when currently adding - it leads to weird results
     if ([fTrackerTable editedRow] != -1)
         return;
-    
+
     [self updateInfo];
-    
+
     if ([[sender cell] tagForSegment: [sender selectedSegment]] == TRACKER_REMOVE_TAG)
         [self removeTrackers];
     else
@@ -266,28 +251,27 @@
     {
         if (numberSelected == 0)
         {
-            [fTrackers release];
             fTrackers = nil;
-            
+
             [fTrackerTable setTrackers: nil];
             [fTrackerTable reloadData];
         }
-        
+
         [fTrackerTable setTorrent: nil];
-        
+
         [fTrackerAddRemoveControl setEnabled: NO forSegment: TRACKER_ADD_TAG];
         [fTrackerAddRemoveControl setEnabled: NO forSegment: TRACKER_REMOVE_TAG];
     }
     else
     {
-        [fTrackerTable setTorrent: [fTorrents objectAtIndex: 0]];
-        
+        [fTrackerTable setTorrent: fTorrents[0]];
+
         [fTrackerAddRemoveControl setEnabled: YES forSegment: TRACKER_ADD_TAG];
         [fTrackerAddRemoveControl setEnabled: NO forSegment: TRACKER_REMOVE_TAG];
     }
-    
+
     [fTrackerTable deselectAll: self];
-    
+
     fSet = YES;
 }
 
@@ -295,12 +279,12 @@
 - (void) addTrackers
 {
     [[[self view] window] makeKeyWindow];
-    
+
     NSAssert1([fTorrents count] == 1, @"Attempting to add tracker with %ld transfers selected", [fTorrents count]);
-    
-    [fTrackers addObject: [NSDictionary dictionaryWithObject: [NSNumber numberWithInteger: -1] forKey: @"Tier"]];
+
+    [fTrackers addObject: @{@"Tier": @-1}];
     [fTrackers addObject: @""];
-    
+
     [fTrackerTable setTrackers: fTrackers];
     [fTrackerTable reloadData];
     [fTrackerTable selectRowIndexes: [NSIndexSet indexSetWithIndex: [fTrackers count]-1] byExtendingSelection: NO];
@@ -311,29 +295,29 @@
 {
     NSMutableDictionary * removeIdentifiers = [NSMutableDictionary dictionaryWithCapacity: [fTorrents count]];
     NSUInteger removeTrackerCount = 0;
-       
+
     NSIndexSet * selectedIndexes = [fTrackerTable selectedRowIndexes];
     BOOL groupSelected = NO;
     NSUInteger groupRowIndex = NSNotFound;
     NSMutableIndexSet * removeIndexes = [NSMutableIndexSet indexSet];
     for (NSUInteger i = 0; i < [fTrackers count]; ++i)
     {
-        id object = [fTrackers objectAtIndex: i];
+        id object = fTrackers[i];
         if ([object isKindOfClass: [TrackerNode class]])
         {
             if (groupSelected || [selectedIndexes containsIndex: i])
             {
                 Torrent * torrent = [(TrackerNode *)object torrent];
                 NSMutableSet * removeSet;
-                if (!(removeSet = [removeIdentifiers objectForKey: torrent]))
+                if (!(removeSet = removeIdentifiers[torrent]))
                 {
                     removeSet = [NSMutableSet set];
-                    [removeIdentifiers setObject: removeSet forKey: torrent];
+                    removeIdentifiers[torrent] = removeSet;
                 }
-                
+
                 [removeSet addObject: [(TrackerNode *)object fullAnnounceAddress]];
                 ++removeTrackerCount;
-                
+
                 [removeIndexes addIndex: i];
             }
             else
@@ -344,33 +328,33 @@
             //mark the previous group row for removal, if necessary
             if (groupRowIndex != NSNotFound)
                 [removeIndexes addIndex: groupRowIndex];
-            
+
             groupSelected = [selectedIndexes containsIndex: i];
             if (!groupSelected && i > [selectedIndexes lastIndex])
             {
                 groupRowIndex = NSNotFound;
                 break;
             }
-            
+
             groupRowIndex = i;
         }
     }
-    
+
     //mark the last group for removal, too
     if (groupRowIndex != NSNotFound)
         [removeIndexes addIndex: groupRowIndex];
-    
+
     NSAssert2(removeTrackerCount <= [removeIndexes count], @"Marked %ld trackers to remove, but only removing %ld rows", removeTrackerCount, [removeIndexes count]);
-    
+
     //we might have no trackers if remove right after a failed add (race condition ftw)
     #warning look into having a failed add apply right away, so that this can become an assert
     if (removeTrackerCount == 0)
         return;
-    
+
     if ([[NSUserDefaults standardUserDefaults] boolForKey: @"WarningRemoveTrackers"])
     {
         NSAlert * alert = [[NSAlert alloc] init];
-        
+
         if (removeTrackerCount > 1)
         {
             [alert setMessageText: [NSString stringWithFormat: NSLocalizedString(@"Are you sure you want to remove %d trackers?",
@@ -384,50 +368,37 @@
             [alert setInformativeText: NSLocalizedString(@"Once removed, Transmission will no longer attempt to contact it."
                                         " This cannot be undone.", "Remove trackers alert -> message")];
         }
-        
+
         [alert addButtonWithTitle: NSLocalizedString(@"Remove", "Remove trackers alert -> button")];
         [alert addButtonWithTitle: NSLocalizedString(@"Cancel", "Remove trackers alert -> button")];
-        
+
         [alert setShowsSuppressionButton: YES];
 
         NSInteger result = [alert runModal];
         if ([[alert suppressionButton] state] == NSOnState)
             [[NSUserDefaults standardUserDefaults] setBool: NO forKey: @"WarningRemoveTrackers"];
-        [alert release];
-        
+
         if (result != NSAlertFirstButtonReturn)
             return;
     }
-    
-    
-    if ([NSApp isOnLionOrBetter])
-        [fTrackerTable beginUpdates];
-    
+
+
+    [fTrackerTable beginUpdates];
+
     for (Torrent * torrent in removeIdentifiers)
-        [torrent removeTrackers: [removeIdentifiers objectForKey: torrent]];
-    
+        [torrent removeTrackers: removeIdentifiers[torrent]];
+
     //reset table with either new or old value
-    [fTrackers release];
     fTrackers = [[NSMutableArray alloc] init];
     for (Torrent * torrent in fTorrents)
         [fTrackers addObjectsFromArray: [torrent allTrackerStats]];
-    
-    if ([NSApp isOnLionOrBetter])
-    {
-        [fTrackerTable removeRowsAtIndexes: removeIndexes withAnimation: NSTableViewAnimationSlideLeft];
-        
-        [fTrackerTable setTrackers: fTrackers];
-        
-        [fTrackerTable endUpdates];
-    }
-    else
-    {
-        [fTrackerTable setTrackers: fTrackers];
-        
-        [fTrackerTable reloadData];
-        [fTrackerTable deselectAll: self];
-    }
-    
+
+    [fTrackerTable removeRowsAtIndexes: removeIndexes withAnimation: NSTableViewAnimationSlideLeft];
+
+    [fTrackerTable setTrackers: fTrackers];
+
+    [fTrackerTable endUpdates];
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateUI" object: nil]; //incase sort by tracker
 }
 
