@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: InfoWindowController.m 13873 2013-01-26 19:52:08Z livings124 $
- *
  * Copyright (c) 2006-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -74,24 +72,25 @@ typedef enum
 - (void) awakeFromNib
 {
     [fNoneSelectedField setStringValue: NSLocalizedString(@"No Torrents Selected", "Inspector -> selected torrents")];
-    
+
     //window location and size
     NSPanel * window = (NSPanel *)[self window];
-    
+
     [window setFloatingPanel: NO];
-    
+
     const CGFloat windowHeight = NSHeight([window frame]);
-    
+    fMinWindowWidth = [window minSize].width;
+
     [window setFrameAutosaveName: @"InspectorWindow"];
     [window setFrameUsingName: @"InspectorWindow"];
-    
+
     NSRect windowRect = [window frame];
     windowRect.origin.y -= windowHeight - NSHeight(windowRect);
     windowRect.size.height = windowHeight;
     [window setFrame: windowRect display: NO];
-    
+
     [window setBecomesKeyOnlyIfNeeded: YES];
-    
+
     //set tab tooltips
     [fTabMatrix setToolTip: NSLocalizedString(@"General Info", "Inspector -> tab") forCell: [fTabMatrix cellWithTag: TAB_GENERAL_TAG]];
     [fTabMatrix setToolTip: NSLocalizedString(@"Activity", "Inspector -> tab") forCell: [fTabMatrix cellWithTag: TAB_ACTIVITY_TAG]];
@@ -99,7 +98,7 @@ typedef enum
     [fTabMatrix setToolTip: NSLocalizedString(@"Peers", "Inspector -> tab") forCell: [fTabMatrix cellWithTag: TAB_PEERS_TAG]];
     [fTabMatrix setToolTip: NSLocalizedString(@"Files", "Inspector -> tab") forCell: [fTabMatrix cellWithTag: TAB_FILE_TAG]];
     [fTabMatrix setToolTip: NSLocalizedString(@"Options", "Inspector -> tab") forCell: [fTabMatrix cellWithTag: TAB_OPTIONS_TAG]];
-    
+
     //set selected tab
     fCurrentTabTag = INVALID;
     NSString * identifier = [[NSUserDefaults standardUserDefaults] stringForKey: @"InspectorSelected"];
@@ -123,10 +122,10 @@ typedef enum
     }
     [fTabMatrix selectCellWithTag: tag];
     [self setTab: nil];
-    
+
     //set blank inspector
     [self setInfoForTorrents: [NSArray array]];
-    
+
     //allow for update notifications
     NSNotificationCenter * nc = [NSNotificationCenter defaultCenter];
     [nc addObserver: self selector: @selector(resetInfoForTorrent:) name: @"ResetInspector" object: nil];
@@ -137,30 +136,18 @@ typedef enum
 - (void) dealloc
 {
     [[NSNotificationCenter defaultCenter] removeObserver: self];
-    
+
     if ([fViewController respondsToSelector: @selector(saveViewSize)])
         [fViewController saveViewSize];
-    
-    [fGeneralViewController release];
-    [fActivityViewController release];
-    [fTrackersViewController release];
-    [fPeersViewController release];
-    [fFileViewController release];
-    [fOptionsViewController release];
-    
-    [fTorrents release];
-    
-    [super dealloc];
 }
 
 - (void) setInfoForTorrents: (NSArray *) torrents
 {
     if (fTorrents && [fTorrents isEqualToArray: torrents])
         return;
-    
-    [fTorrents release];
-    fTorrents = [torrents retain];
-    
+
+    fTorrents = torrents;
+
     [self resetInfo];
 }
 
@@ -171,14 +158,6 @@ typedef enum
     return windowRect;
 }
 
-- (NSSize) windowWillResize: (NSWindow *) window toSize: (NSSize) proposedFrameSize
-{
-    //this is an edge-case - just stop the animation
-    [fPeersViewController stopWebSeedAnimation];
-    
-    return proposedFrameSize;
-}
-
 - (void) windowWillClose: (NSNotification *) notification
 {
     if (fCurrentTabTag == TAB_FILE_TAG && ([QLPreviewPanel sharedPreviewPanelExists] && [[QLPreviewPanel sharedPreviewPanel] isVisible]))
@@ -191,27 +170,27 @@ typedef enum
     fCurrentTabTag = [fTabMatrix selectedTag];
     if (fCurrentTabTag == oldTabTag)
         return;
-    
+
     //take care of old view
     CGFloat oldHeight = 0;
     if (oldTabTag != INVALID)
     {
         //deselect old tab item
         [(InfoTabButtonCell *)[fTabMatrix cellWithTag: oldTabTag] setSelectedTab: NO];
-        
+
         if ([fViewController respondsToSelector: @selector(saveViewSize)])
             [fViewController saveViewSize];
-        
+
         if ([fViewController respondsToSelector: @selector(clearView)])
             [fViewController clearView];
-        
+
         NSView * oldView = [fViewController view];
         oldHeight = NSHeight([oldView frame]);
-        
+
         //remove old view
         [oldView removeFromSuperview];
     }
-    
+
     //set new tab item
     NSString * identifier;
     switch (fCurrentTabTag)
@@ -222,7 +201,7 @@ typedef enum
                 fGeneralViewController = [[InfoGeneralViewController alloc] init];
                 [fGeneralViewController setInfoForTorrents: fTorrents];
             }
-            
+
             fViewController = fGeneralViewController;
             identifier = TAB_INFO_IDENT;
             break;
@@ -232,7 +211,7 @@ typedef enum
                 fActivityViewController = [[InfoActivityViewController alloc] init];
                 [fActivityViewController setInfoForTorrents: fTorrents];
             }
-            
+
             fViewController = fActivityViewController;
             identifier = TAB_ACTIVITY_IDENT;
             break;
@@ -242,7 +221,7 @@ typedef enum
                 fTrackersViewController = [[InfoTrackersViewController alloc] init];
                 [fTrackersViewController setInfoForTorrents: fTorrents];
             }
-            
+
             fViewController = fTrackersViewController;
             identifier = TAB_TRACKER_IDENT;
             break;
@@ -252,7 +231,7 @@ typedef enum
                 fPeersViewController = [[InfoPeersViewController alloc] init];
                 [fPeersViewController setInfoForTorrents: fTorrents];
             }
-            
+
             fViewController = fPeersViewController;
             identifier = TAB_PEERS_IDENT;
             break;
@@ -262,7 +241,7 @@ typedef enum
                 fFileViewController = [[InfoFileViewController alloc] init];
                 [fFileViewController setInfoForTorrents: fTorrents];
             }
-            
+
             fViewController = fFileViewController;
             identifier = TAB_FILES_IDENT;
             break;
@@ -272,7 +251,7 @@ typedef enum
                 fOptionsViewController = [[InfoOptionsViewController alloc] init];
                 [fOptionsViewController setInfoForTorrents: fTorrents];
             }
-            
+
             fViewController = fOptionsViewController;
             identifier = TAB_OPTIONS_IDENT;
             break;
@@ -280,27 +259,30 @@ typedef enum
             NSAssert1(NO, @"Unknown info tab selected: %ld", fCurrentTabTag);
             return;
     }
-    
+
     [[NSUserDefaults standardUserDefaults] setObject: identifier forKey: @"InspectorSelected"];
-    
+
     NSWindow * window = [self window];
-    
+
     [window setTitle: [NSString stringWithFormat: @"%@ - %@", [fViewController title],
                         NSLocalizedString(@"Torrent Inspector", "Inspector -> title")]];
-    
+
     //selected tab item
     [(InfoTabButtonCell *)[fTabMatrix selectedCell] setSelectedTab: YES];
-    
+
     NSView * view = [fViewController view];
-    
+
     [fViewController updateInfo];
-    
+
     NSRect windowRect = [window frame], viewRect = [view frame];
-    
-    const CGFloat difference = (NSHeight(viewRect) - oldHeight) * [window userSpaceScaleFactor];
+
+    const CGFloat difference = NSHeight(viewRect) - oldHeight;
     windowRect.origin.y -= difference;
     windowRect.size.height += difference;
-    
+
+    const CGFloat minWindowWidth = MAX(fMinWindowWidth, [view fittingSize].width);
+    windowRect.size.width = MAX(NSWidth(windowRect), minWindowWidth);
+
     if ([fViewController respondsToSelector: @selector(saveViewSize)]) //a little bit hacky, but avoids requiring an extra method
     {
         if ([window screen])
@@ -308,29 +290,38 @@ typedef enum
             const CGFloat screenHeight = NSHeight([[window screen] visibleFrame]);
             if (NSHeight(windowRect) > screenHeight)
             {
-                const CGFloat difference = (screenHeight - NSHeight(windowRect)) * [window userSpaceScaleFactor];
+                const CGFloat difference = screenHeight - NSHeight(windowRect);
                 windowRect.origin.y -= difference;
                 windowRect.size.height += difference;
-                
+
                 viewRect.size.height += difference;
             }
         }
-        
-        [window setMinSize: NSMakeSize([window minSize].width, NSHeight(windowRect) - NSHeight(viewRect) + TAB_MIN_HEIGHT)];
+
+        [window setMinSize: NSMakeSize(minWindowWidth, NSHeight(windowRect) - NSHeight(viewRect) + TAB_MIN_HEIGHT)];
         [window setMaxSize: NSMakeSize(FLT_MAX, FLT_MAX)];
     }
     else
     {
-        [window setMinSize: NSMakeSize([window minSize].width, NSHeight(windowRect))];
+        [window setMinSize: NSMakeSize(minWindowWidth, NSHeight(windowRect))];
         [window setMaxSize: NSMakeSize(FLT_MAX, NSHeight(windowRect))];
     }
-    
+
     viewRect.size.width = NSWidth(windowRect);
     [view setFrame: viewRect];
-    
+
     [window setFrame: windowRect display: YES animate: oldTabTag != INVALID];
     [[window contentView] addSubview: view];
-    
+
+    [[window contentView] addConstraints: [NSLayoutConstraint constraintsWithVisualFormat: @"H:|-0-[view]-0-|"
+                                                                                  options: 0
+                                                                                  metrics: nil
+                                                                                    views: @{ @"view": view }]];
+    [[window contentView] addConstraints: [NSLayoutConstraint constraintsWithVisualFormat: @"V:[tabs]-0-[view]-0-|"
+                                                                                  options: 0
+                                                                                  metrics: nil
+                                                                                    views: @{ @"tabs": fTabMatrix, @"view": view }]];
+
     if ((fCurrentTabTag == TAB_FILE_TAG || oldTabTag == TAB_FILE_TAG)
         && ([QLPreviewPanel sharedPreviewPanelExists] && [[QLPreviewPanel sharedPreviewPanel] isVisible]))
         [[QLPreviewPanel sharedPreviewPanel] reloadData];
@@ -341,7 +332,7 @@ typedef enum
     NSInteger tag = [fTabMatrix selectedTag]+1;
     if (tag >= [fTabMatrix numberOfColumns])
         tag = 0;
-    
+
     [fTabMatrix selectCellWithTag: tag];
     [self setTab: nil];
 }
@@ -351,7 +342,7 @@ typedef enum
     NSInteger tag = [fTabMatrix selectedTag]-1;
     if (tag < 0)
         tag = [fTabMatrix numberOfColumns]-1;
-    
+
     [fTabMatrix selectCellWithTag: tag];
     [self setTab: nil];
 }
@@ -383,7 +374,7 @@ typedef enum
 {
     if (fCurrentTabTag != TAB_FILE_TAG || ![[self window] isVisible])
         return NO;
-    
+
     return [fFileViewController canQuickLook];
 }
 
@@ -404,12 +395,12 @@ typedef enum
         if (numberSelected > 0)
         {
             [fImageView setImage: [NSImage imageNamed: NSImageNameMultipleDocuments]];
-            
+
             [fNameField setStringValue: [NSString stringWithFormat: NSLocalizedString(@"%@ Torrents Selected",
                                             "Inspector -> selected torrents"),
                                             [NSString formattedUInteger: numberSelected]]];
             [fNameField setHidden: NO];
-        
+
             uint64_t size = 0;
             NSUInteger fileCount = 0, magnetCount = 0;
             for (Torrent * torrent in fTorrents)
@@ -419,7 +410,7 @@ typedef enum
                 if ([torrent isMagnet])
                     ++magnetCount;
             }
-            
+
             NSMutableArray * fileStrings = [NSMutableArray arrayWithCapacity: 2];
             if (fileCount > 0)
             {
@@ -441,26 +432,18 @@ typedef enum
                                     "Inspector -> selected torrents"), [NSString formattedUInteger: magnetCount]];
                 [fileStrings addObject: magnetString];
             }
-            
+
             NSString * fileString = [fileStrings componentsJoinedByString: @" + "];
-            
+
             if (magnetCount < numberSelected)
             {
                 [fBasicInfoField setStringValue: [NSString stringWithFormat: @"%@, %@", fileString,
                     [NSString stringWithFormat: NSLocalizedString(@"%@ total", "Inspector -> selected torrents"),
                         [NSString stringForFileSize: size]]]];
-                
-                NSString * byteString;
-                if ([NSApp isOnMountainLionOrBetter])
-                {
-                    NSByteCountFormatter * formatter = [[NSByteCountFormatterMtLion alloc] init];
-                    [formatter setAllowedUnits: NSByteCountFormatterUseBytes];
-                    byteString = [formatter stringFromByteCount: size];
-                    [formatter release];
-                }
-                else
-                    byteString = [NSString stringWithFormat: NSLocalizedString(@"%@ bytes", "Inspector -> selected torrents"), [NSString formattedUInteger: size]];
-                [fBasicInfoField setToolTip: byteString];
+
+                NSByteCountFormatter * formatter = [[NSByteCountFormatter alloc] init];
+                [formatter setAllowedUnits: NSByteCountFormatterUseBytes];
+                [fBasicInfoField setToolTip: [formatter stringFromByteCount: size]];
             }
             else
             {
@@ -468,31 +451,31 @@ typedef enum
                 [fBasicInfoField setToolTip: nil];
             }
             [fBasicInfoField setHidden: NO];
-            
+
             [fNoneSelectedField setHidden: YES];
         }
         else
         {
             [fImageView setImage: [NSImage imageNamed: NSImageNameApplicationIcon]];
             [fNoneSelectedField setHidden: NO];
-            
+
             [fNameField setHidden: YES];
             [fBasicInfoField setHidden: YES];
         }
-        
+
         [fNameField setToolTip: nil];
     }
     else
     {
-        Torrent * torrent = [fTorrents objectAtIndex: 0];
-        
+        Torrent * torrent = fTorrents[0];
+
         [fImageView setImage: [torrent icon]];
-        
+
         NSString * name = [torrent name];
         [fNameField setStringValue: name];
         [fNameField setToolTip: name];
         [fNameField setHidden: NO];
-        
+
         if (![torrent isMagnet])
         {
             NSString * basicString = [NSString stringForFileSize: [torrent size]];
@@ -508,18 +491,10 @@ typedef enum
                 basicString = [NSString stringWithFormat: @"%@, %@", fileString, basicString];
             }
             [fBasicInfoField setStringValue: basicString];
-            
-            NSString * byteString;
-            if ([NSApp isOnMountainLionOrBetter])
-            {
-                NSByteCountFormatter * formatter = [[NSByteCountFormatterMtLion alloc] init];
-                [formatter setAllowedUnits: NSByteCountFormatterUseBytes];
-                byteString = [formatter stringFromByteCount: [torrent size]];
-                [formatter release];
-            }
-            else
-                byteString = [NSString stringWithFormat: NSLocalizedString(@"%@ bytes", "Inspector -> selected torrents"), [NSString formattedUInteger: [torrent size]]];
-            [fBasicInfoField setToolTip: byteString];
+
+            NSByteCountFormatter * formatter = [[NSByteCountFormatter alloc] init];
+            [formatter setAllowedUnits: NSByteCountFormatterUseBytes];
+            [fBasicInfoField setToolTip: [formatter stringFromByteCount: [torrent size]]];
         }
         else
         {
@@ -527,23 +502,23 @@ typedef enum
             [fBasicInfoField setToolTip: nil];
         }
         [fBasicInfoField setHidden: NO];
-        
+
         [fNoneSelectedField setHidden: YES];
     }
-    
+
     [fGeneralViewController setInfoForTorrents: fTorrents];
     [fActivityViewController setInfoForTorrents: fTorrents];
     [fTrackersViewController setInfoForTorrents: fTorrents];
     [fPeersViewController setInfoForTorrents: fTorrents];
     [fFileViewController setInfoForTorrents: fTorrents];
     [fOptionsViewController setInfoForTorrents: fTorrents];
-    
+
     [fViewController updateInfo];
 }
 
 - (void) resetInfoForTorrent: (NSNotification *) notification
 {
-    Torrent * torrent = [[notification userInfo] objectForKey: @"Torrent"];
+    Torrent * torrent = [notification userInfo][@"Torrent"];
     if (fTorrents && (!torrent || [fTorrents containsObject: torrent]))
         [self resetInfo];
 }
