@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id$
- *
  * Copyright (c) 2006-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -22,13 +20,13 @@
  * DEALINGS IN THE SOFTWARE.
  *****************************************************************************/
 
+#include <libtransmission/transmission.h>
+#include <libtransmission/utils.h>
+
 #import "PiecesView.h"
 #import "Torrent.h"
 #import "InfoWindowController.h"
 
-#import "transmission.h"
-#import "utils.h"
-
 #define MAX_ACROSS 18
 #define BETWEEN 1.0
 
@@ -48,9 +46,9 @@ enum
 - (void) awakeFromNib
 {
     //store box colors
-    fGreenAvailabilityColor = [[NSColor colorWithCalibratedRed: 0.0 green: 1.0 blue: 0.4 alpha: 1.0] retain];
-    fBluePieceColor = [[NSColor colorWithCalibratedRed: 0.0 green: 0.4 blue: 0.8 alpha: 1.0] retain];
-    
+    fGreenAvailabilityColor = [NSColor colorWithCalibratedRed: 0.0 green: 1.0 blue: 0.4 alpha: 1.0];
+    fBluePieceColor = [NSColor colorWithCalibratedRed: 0.0 green: 0.4 blue: 0.8 alpha: 1.0];
+
     //actually draw the box
     [self setTorrent: nil];
 }
@@ -58,41 +56,34 @@ enum
 - (void) dealloc
 {
     tr_free(fPieces);
-    
-    [fGreenAvailabilityColor release];
-    [fBluePieceColor release];
-    
-    [super dealloc];
 }
 
 - (void) setTorrent: (Torrent *) torrent
 {
     [self clearView];
-    
+
     fTorrent = (torrent && ![torrent isMagnet]) ? torrent : nil;
     if (fTorrent)
     {
         //determine relevant values
         fNumPieces = MIN([fTorrent pieceCount], MAX_ACROSS * MAX_ACROSS);
         fAcross = ceil(sqrt(fNumPieces));
-        
+
         const CGFloat width = [self bounds].size.width;
         fWidth = (width - (fAcross + 1) * BETWEEN) / fAcross;
         fExtraBorder = (width - ((fWidth + BETWEEN) * fAcross + BETWEEN)) / 2;
     }
-    
+
     NSImage * back = [[NSImage alloc] initWithSize: [self bounds].size];
     [back lockFocus];
-    
+
     NSGradient * gradient = [[NSGradient alloc] initWithStartingColor: [NSColor colorWithCalibratedWhite: 0.0 alpha: 0.4]
                                 endingColor: [NSColor colorWithCalibratedWhite: 0.2 alpha: 0.4]];
     [gradient drawInRect: [self bounds] angle: 90.0];
-    [gradient release];
     [back unlockFocus];
-    
+
     [self setImage: back];
-    [back release];
-    
+
     [self setNeedsDisplay];
 }
 
@@ -106,7 +97,7 @@ enum
 {
     if (!fTorrent)
         return;
-    
+
     //determine if first time
     const BOOL first = fPieces == NULL;
     if (first)
@@ -114,30 +105,30 @@ enum
 
     int8_t * pieces = NULL;
     float * piecesPercent = NULL;
-    
+
     const BOOL showAvailablity = [[NSUserDefaults standardUserDefaults] boolForKey: @"PiecesViewShowAvailability"];
     if (showAvailablity)
-    {   
+    {
         pieces = (int8_t *)tr_malloc(fNumPieces * sizeof(int8_t));
         [fTorrent getAvailability: pieces size: fNumPieces];
     }
     else
-    {   
+    {
         piecesPercent = (float *)tr_malloc(fNumPieces * sizeof(float));
         [fTorrent getAmountFinished: piecesPercent size: fNumPieces];
     }
-    
+
     NSImage * image = [self image];
-    
+
     NSRect fillRects[fNumPieces];
     NSColor * fillColors[fNumPieces];
-    
+
     NSInteger usedCount = 0;
-    
+
     for (NSInteger index = 0; index < fNumPieces; index++)
     {
         NSColor * pieceColor = nil;
-        
+
         if (showAvailablity ? pieces[index] == -1 : piecesPercent[index] == 1.0)
         {
             if (first || fPieces[index] != PIECE_FINISHED)
@@ -178,7 +169,7 @@ enum
             pieceColor = [[NSColor whiteColor] blendedColorWithFraction: percent ofColor: fullColor];
             fPieces[index] = PIECE_SOME;
         }
-        
+
         if (pieceColor)
         {
             const NSInteger across = index % fAcross,
@@ -187,11 +178,11 @@ enum
                                                 [image size].width - (down + 1) * (fWidth + BETWEEN) - fExtraBorder,
                                                 fWidth, fWidth);
             fillColors[usedCount] = pieceColor;
-            
+
             usedCount++;
         }
     }
-    
+
     if (usedCount > 0)
     {
         [image lockFocus];
@@ -199,7 +190,7 @@ enum
         [image unlockFocus];
         [self setNeedsDisplay];
     }
-    
+
     tr_free(pieces);
     tr_free(piecesPercent);
 }
@@ -215,10 +206,10 @@ enum
     {
         const BOOL availability = ![[NSUserDefaults standardUserDefaults] boolForKey: @"PiecesViewShowAvailability"];
         [[NSUserDefaults standardUserDefaults] setBool: availability forKey: @"PiecesViewShowAvailability"];
-        
+
         [self sendAction:[self action] to:[self target]];
     }
-    
+
     [super mouseDown: event];
 }
 
