@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: PortChecker.m 13492 2012-09-10 02:37:29Z livings124 $
- *
  * Copyright (c) 2006-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -24,7 +22,7 @@
 
 #import "PortChecker.h"
 
-#define CHECKER_URL(port) [NSString stringWithFormat: @"http://portcheck.transmissionbt.com/%ld", port]
+#define CHECKER_URL(port) [NSString stringWithFormat: @"https://portcheck.transmissionbt.com/%ld", port]
 #define CHECK_FIRE 3.0
 
 @interface PortChecker (Private)
@@ -42,25 +40,20 @@
     if ((self = [super init]))
     {
         fDelegate = delegate;
-        
+
         fStatus = PORT_STATUS_CHECKING;
-        
-        fTimer = [[NSTimer scheduledTimerWithTimeInterval: CHECK_FIRE target: self selector: @selector(startProbe:) userInfo: [NSNumber numberWithInteger: portNumber] repeats: NO] retain];
+
+        fTimer = [NSTimer scheduledTimerWithTimeInterval: CHECK_FIRE target: self selector: @selector(startProbe:) userInfo: @(portNumber) repeats: NO];
         if (!delay)
             [fTimer fire];
     }
-    
+
     return self;
 }
 
 - (void) dealloc
 {
     [fTimer invalidate];
-    [fTimer release];
-    
-    [fConnection release];
-    [fPortProbeData release];
-    [super dealloc];
 }
 
 - (port_status_t) status
@@ -71,9 +64,8 @@
 - (void) cancelProbe
 {
     [fTimer invalidate];
-    [fTimer release];
     fTimer = nil;
-    
+
     [fConnection cancel];
 }
 
@@ -96,9 +88,8 @@
 - (void) connectionDidFinishLoading: (NSURLConnection *) connection
 {
     NSString * probeString = [[NSString alloc] initWithData: fPortProbeData encoding: NSUTF8StringEncoding];
-    [fPortProbeData release];
     fPortProbeData = nil;
-    
+
     if (probeString)
     {
         if ([probeString isEqualToString: @"1"])
@@ -110,7 +101,6 @@
             NSLog(@"Unable to get port status: invalid response (%@)", probeString);
             [self callBackWithStatus: PORT_STATUS_ERROR];
         }
-        [probeString release];
     }
     else
     {
@@ -125,12 +115,11 @@
 
 - (void) startProbe: (NSTimer *) timer
 {
-    [fTimer release];
     fTimer = nil;
-    
+
     NSURLRequest * portProbeRequest = [NSURLRequest requestWithURL: [NSURL URLWithString: CHECKER_URL([[timer userInfo] integerValue])]
                                         cachePolicy: NSURLRequestReloadIgnoringLocalAndRemoteCacheData timeoutInterval: 15.0];
-    
+
     if ((fConnection = [[NSURLConnection alloc] initWithRequest: portProbeRequest delegate: self]))
         fPortProbeData = [[NSMutableData alloc] init];
     else
@@ -143,7 +132,7 @@
 - (void) callBackWithStatus: (port_status_t) status
 {
     fStatus = status;
-    
+
     if (fDelegate && [fDelegate respondsToSelector: @selector(portCheckerDidFinishProbing:)])
         [fDelegate performSelectorOnMainThread: @selector(portCheckerDidFinishProbing:) withObject: self waitUntilDone: NO];
 }
