@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: StatsWindowController.m 14662 2016-01-06 11:05:37Z mikedld $
- *
  * Copyright (c) 2007-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -62,54 +60,54 @@ tr_session * fLib = NULL;
 - (void) awakeFromNib
 {
     [self updateStats];
-    
-    fTimer = [[NSTimer scheduledTimerWithTimeInterval: UPDATE_SECONDS target: self selector: @selector(updateStats) userInfo: nil repeats: YES] retain];
+
+    fTimer = [NSTimer scheduledTimerWithTimeInterval: UPDATE_SECONDS target: self selector: @selector(updateStats) userInfo: nil repeats: YES];
     [[NSRunLoop currentRunLoop] addTimer: fTimer forMode: NSModalPanelRunLoopMode];
     [[NSRunLoop currentRunLoop] addTimer: fTimer forMode: NSEventTrackingRunLoopMode];
 
     [[self window] setRestorationClass: [self class]];
-    
+
     [[self window] setTitle: NSLocalizedString(@"Statistics", "Stats window -> title")];
-    
+
     //set label text
     [fUploadedLabelField setStringValue: [NSLocalizedString(@"Uploaded", "Stats window -> label") stringByAppendingString: @":"]];
     [fDownloadedLabelField setStringValue: [NSLocalizedString(@"Downloaded", "Stats window -> label") stringByAppendingString: @":"]];
     [fRatioLabelField setStringValue: [NSLocalizedString(@"Ratio", "Stats window -> label") stringByAppendingString: @":"]];
     [fTimeLabelField setStringValue: [NSLocalizedString(@"Running Time", "Stats window -> label") stringByAppendingString: @":"]];
     [fNumOpenedLabelField setStringValue: [NSLocalizedString(@"Program Started", "Stats window -> label") stringByAppendingString: @":"]];
-    
+
     //size of all labels
     const CGFloat oldWidth = [fUploadedLabelField frame].size.width;
-    
+
     NSArray * labels = @[fUploadedLabelField, fDownloadedLabelField, fRatioLabelField, fTimeLabelField, fNumOpenedLabelField];
-    
+
     CGFloat maxWidth = CGFLOAT_MIN;
     for (NSTextField * label in labels)
     {
         [label sizeToFit];
-        
+
         const CGFloat width = [label frame].size.width;
         maxWidth = MAX(maxWidth, width);
     }
-    
+
     for (NSTextField * label in labels)
     {
         NSRect frame = [label frame];
         frame.size.width = maxWidth;
         [label setFrame: frame];
     }
-    
+
     //resize window for new label width - fields are set in nib to adjust correctly
     NSRect windowRect = [[self window] frame];
     windowRect.size.width += maxWidth - oldWidth;
     [[self window] setFrame: windowRect display: YES];
-    
+
     //resize reset button
     const CGFloat oldButtonWidth = [fResetButton frame].size.width;
-    
+
     [fResetButton setTitle: NSLocalizedString(@"Reset", "Stats window -> reset button")];
     [fResetButton sizeToFit];
-    
+
     NSRect buttonFrame = [fResetButton frame];
     buttonFrame.size.width += 10.0;
     buttonFrame.origin.x -= buttonFrame.size.width - oldButtonWidth;
@@ -119,17 +117,14 @@ tr_session * fLib = NULL;
 - (void) windowWillClose: (id) sender
 {
     [fTimer invalidate];
-    [fTimer release];
     fTimer = nil;
-    
-    [fStatsWindowInstance autorelease];
     fStatsWindowInstance = nil;
 }
 
 + (void) restoreWindowWithIdentifier: (NSString *) identifier state: (NSCoder *) state completionHandler: (void (^)(NSWindow *, NSError *)) completionHandler
 {
     NSAssert1([identifier isEqualToString: @"StatsWindow"], @"Trying to restore unexpected identifier %@", identifier);
-    
+
     completionHandler([[StatsWindowController statsWindow] window], nil);
 }
 
@@ -140,7 +135,7 @@ tr_session * fLib = NULL;
         [self performResetStats];
         return;
     }
-    
+
     NSAlert * alert = [[NSAlert alloc] init];
     [alert setMessageText: NSLocalizedString(@"Are you sure you want to reset usage statistics?", "Stats reset -> title")];
     [alert setInformativeText: NSLocalizedString(@"This will clear the global statistics displayed by Transmission."
@@ -149,7 +144,7 @@ tr_session * fLib = NULL;
     [alert addButtonWithTitle: NSLocalizedString(@"Reset", "Stats reset -> button")];
     [alert addButtonWithTitle: NSLocalizedString(@"Cancel", "Stats reset -> button")];
     [alert setShowsSuppressionButton: YES];
-    
+
     [alert beginSheetModalForWindow: [self window] modalDelegate: self
         didEndSelector: @selector(resetSheetClosed:returnCode:contextInfo:) contextInfo: nil];
 }
@@ -168,33 +163,28 @@ tr_session * fLib = NULL;
     tr_session_stats statsAll, statsSession;
     tr_sessionGetCumulativeStats(fLib, &statsAll);
     tr_sessionGetStats(fLib, &statsSession);
-    
-    NSByteCountFormatter * byteFormatter = nil;
-    if ([NSApp isOnMountainLionOrBetter])
-    {
-        byteFormatter = [[NSByteCountFormatterMtLion alloc] init];
-        [byteFormatter setAllowedUnits: NSByteCountFormatterUseBytes];
-    }
-    
+
+    NSByteCountFormatter * byteFormatter = [[NSByteCountFormatter alloc] init];
+    [byteFormatter setAllowedUnits: NSByteCountFormatterUseBytes];
+
     [fUploadedField setStringValue: [NSString stringForFileSize: statsSession.uploadedBytes]];
-    [fUploadedField setToolTip: [NSApp isOnMountainLionOrBetter] ? [byteFormatter stringFromByteCount: statsSession.uploadedBytes] : [NSString stringWithFormat: NSLocalizedString(@"%@ bytes", "stats -> bytes"), [NSString formattedUInteger: statsSession.uploadedBytes]]];
+    [fUploadedField setToolTip: [byteFormatter stringFromByteCount: statsSession.uploadedBytes]];
     [fUploadedAllField setStringValue: [NSString stringWithFormat: NSLocalizedString(@"%@ total", "stats total"), [NSString stringForFileSize: statsAll.uploadedBytes]]];
-    [fUploadedAllField setToolTip: [NSApp isOnMountainLionOrBetter] ? [byteFormatter stringFromByteCount: statsAll.uploadedBytes] : [NSString stringWithFormat: NSLocalizedString(@"%@ bytes", "stats -> bytes"), [NSString formattedUInteger: statsAll.uploadedBytes]]];
-    
+    [fUploadedAllField setToolTip: [byteFormatter stringFromByteCount: statsAll.uploadedBytes]];
+
     [fDownloadedField setStringValue: [NSString stringForFileSize: statsSession.downloadedBytes]];
-    [fDownloadedField setToolTip: [NSApp isOnMountainLionOrBetter] ? [byteFormatter stringFromByteCount: statsSession.downloadedBytes] : [NSString stringWithFormat: NSLocalizedString(@"%@ bytes", "stats -> bytes"), [NSString formattedUInteger: statsSession.downloadedBytes]]];
+    [fDownloadedField setToolTip: [byteFormatter stringFromByteCount: statsSession.downloadedBytes]];
     [fDownloadedAllField setStringValue: [NSString stringWithFormat: NSLocalizedString(@"%@ total", "stats total"), [NSString stringForFileSize: statsAll.downloadedBytes]]];
-    [fDownloadedAllField setToolTip: [NSApp isOnMountainLionOrBetter] ? [byteFormatter stringFromByteCount: statsAll.downloadedBytes] : [NSString stringWithFormat: NSLocalizedString(@"%@ bytes", "stats -> bytes"), [NSString formattedUInteger: statsAll.downloadedBytes]]];
-    
-    [byteFormatter release];
-    
+    [fDownloadedAllField setToolTip: [byteFormatter stringFromByteCount: statsAll.downloadedBytes]];
+
+
     [fRatioField setStringValue: [NSString stringForRatio: statsSession.ratio]];
-    
+
     NSString * totalRatioString = statsAll.ratio != TR_RATIO_NA
         ? [NSString stringWithFormat: NSLocalizedString(@"%@ total", "stats total"), [NSString stringForRatio: statsAll.ratio]]
         : NSLocalizedString(@"Total N/A", "stats total");
     [fRatioAllField setStringValue: totalRatioString];
-    
+
     if ([NSApp isOnYosemiteOrBetter]) {
         static NSDateComponentsFormatter *timeFormatter;
         static dispatch_once_t onceToken;
@@ -204,7 +194,7 @@ tr_session * fLib = NULL;
             timeFormatter.maximumUnitCount = 3;
             timeFormatter.allowedUnits = NSCalendarUnitYear | NSCalendarUnitMonth | NSCalendarUnitWeekOfMonth | NSCalendarUnitDay | NSCalendarUnitHour | NSCalendarUnitMinute;
         });
-        
+
         [fTimeField setStringValue: [timeFormatter stringFromTimeInterval:statsSession.secondsActive]];
         [fTimeAllField setStringValue: [NSString stringWithFormat: NSLocalizedString(@"%@ total", "stats total"), [timeFormatter stringFromTimeInterval:statsAll.secondsActive]]];
     }
@@ -212,7 +202,7 @@ tr_session * fLib = NULL;
         [fTimeField setStringValue: [NSString timeString: statsSession.secondsActive includesTimeRemainingPhrase:NO showSeconds: NO]];
         [fTimeAllField setStringValue: [NSString stringWithFormat: NSLocalizedString(@"%@ total", "stats total"), [NSString timeString: statsAll.secondsActive includesTimeRemainingPhrase:NO showSeconds: NO]]];
     }
-    
+
     if (statsAll.sessionCount == 1)
         [fNumOpenedField setStringValue: NSLocalizedString(@"1 time", "stats window -> times opened")];
     else
@@ -228,10 +218,10 @@ tr_session * fLib = NULL;
 - (void) resetSheetClosed: (NSAlert *) alert returnCode: (NSInteger) code contextInfo: (void *) info
 {
     [[alert window] orderOut: nil];
-    
+
     if ([[alert suppressionButton] state] == NSOnState)
         [[NSUserDefaults standardUserDefaults] setBool: NO forKey: @"WarningResetStats"];
-    
+
     if (code == NSAlertFirstButtonReturn)
         [self performResetStats];
 }
