@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: StatusBarController.h 13343 2012-06-10 13:47:32Z livings124 $
- * 
  * Copyright (c) 2011-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -24,16 +22,16 @@
 
 #import <Cocoa/Cocoa.h>
 
-#import <transmission.h>
+#include <libtransmission/transmission.h>
 
 @interface StatusBarController : NSViewController
 {
     IBOutlet NSButton * fStatusButton;
     IBOutlet NSTextField * fTotalDLField, * fTotalULField;
     IBOutlet NSImageView * fTotalDLImageView, * fTotalULImageView;
-    
+
     tr_session * fLib;
-    
+
     CGFloat fPreviousDownloadRate, fPreviousUploadRate;
 }
 
