@@ -1,7 +1,5 @@
 /******************************************************************************
- * $Id: TorrentTableView.m 13610 2012-11-02 21:46:18Z livings124 $
- *
- * Copyright (c) 2005-2012 Transmission authors and contributors
+ * Copyright (c) 2005-2019 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -60,53 +58,40 @@
     if ((self = [super initWithCoder: decoder]))
     {
         fDefaults = [NSUserDefaults standardUserDefaults];
-        
+
         fTorrentCell = [[TorrentCell alloc] init];
-        
+
         NSData * groupData = [fDefaults dataForKey: @"CollapsedGroups"];
         if (groupData)
             fCollapsedGroups = [[NSUnarchiver unarchiveObjectWithData: groupData] mutableCopy];
         else
             fCollapsedGroups = [[NSMutableIndexSet alloc] init];
-        
+
         fMouseRow = -1;
         fMouseControlRow = -1;
         fMouseRevealRow = -1;
         fMouseActionRow = -1;
-        #warning we can get rid of the on 10.7
-        fActionPushedRow = -1;
-        
+
         fActionPopoverShown = NO;
-        
+
         [self setDelegate: self];
-        
+
         fPiecesBarPercent = [fDefaults boolForKey: @"PiecesBar"] ? 1.0 : 0.0;
     }
-    
+
     return self;
 }
 
 - (void) dealloc
 {
     [[NSNotificationCenter defaultCenter] removeObserver: self];
-    
-    [fCollapsedGroups release];
-    
-    [fPiecesBarAnimation release];
-    [fMenuTorrent release];
-    
-    [fSelectedValues release];
-    
-    [fTorrentCell release];
-    
-    [super dealloc];
 }
 
 - (void) awakeFromNib
 {
     //set group columns to show ratio, needs to be in awakeFromNib to size columns correctly
     [self setGroupStatusColumns];
-    
+
     [[NSNotificationCenter defaultCenter] addObserver: self selector: @selector(setNeedsDisplay) name: @"RefreshTorrentTable" object: nil];
 }
 
@@ -114,7 +99,7 @@
 {
     if (value == -1)
         value = MAX_GROUP;
-    
+
     return [fCollapsedGroups containsIndex: value];
 }
 
@@ -122,7 +107,7 @@
 {
     if (value == -1)
         value = MAX_GROUP;
-    
+
     [fCollapsedGroups removeIndex: value];
 }
 
@@ -163,22 +148,12 @@
         if (!tableColumn)
         {
             [cell setRepresentedObject: item];
-            
+
             const NSInteger row = [self rowForItem: item];
             [cell setHover: row == fMouseRow];
             [cell setControlHover: row == fMouseControlRow];
             [cell setRevealHover: row == fMouseRevealRow];
             [cell setActionHover: row == fMouseActionRow];
-            [cell setActionPushed: row == fActionPushedRow];
-        }
-    }
-    else
-    {
-        NSString * ident = [tableColumn identifier];
-        if ([ident isEqualToString: @"UL Image"] || [ident isEqualToString: @"DL Image"])
-        {
-            //ensure arrows are white only when selected
-            [[cell image] setTemplate: [cell backgroundStyle] == NSBackgroundStyleLowered];
         }
     }
 }
@@ -190,11 +165,11 @@
     else
     {
         NSRect rect = [super frameOfCellAtColumn: column row: row];
-        
+
         //adjust placement for proper vertical alignment
         if (column == [self columnWithIdentifier: @"Group"])
             rect.size.height -= 1.0f;
-        
+
         return rect;
     }
 }
@@ -232,18 +207,18 @@
 {
     [super updateTrackingAreas];
     [self removeTrackingAreas];
-    
+
     const NSRange rows = [self rowsInRect: [self visibleRect]];
     if (rows.length == 0)
         return;
-    
-    NSPoint mouseLocation = [self convertPoint: [[self window] convertScreenToBase: [NSEvent mouseLocation]] fromView: nil];
+
+    NSPoint mouseLocation = [self convertPoint: [[self window] mouseLocationOutsideOfEventStream] fromView: nil];
     for (NSUInteger row = rows.location; row < NSMaxRange(rows); row++)
     {
         if (![[self itemAtRow: row] isKindOfClass: [Torrent class]])
             continue;
-        
-        NSDictionary * userInfo = [NSDictionary dictionaryWithObject: [NSNumber numberWithInteger: row] forKey: @"Row"];
+
+        NSDictionary * userInfo = @{@"Row": @(row)};
         TorrentCell * cell = (TorrentCell *)[self preparedCellAtColumn: -1 row: row];
         [cell addTrackingAreasForView: self inRect: [self rectOfRow: row] withUserInfo: userInfo mouseLocation: mouseLocation];
     }
@@ -255,10 +230,10 @@
     fMouseControlRow = -1;
     fMouseRevealRow = -1;
     fMouseActionRow = -1;
-    
+
     for (NSTrackingArea * area in [self trackingAreas])
     {
-        if ([area owner] == self && [[area userInfo] objectForKey: @"Row"])
+        if ([area owner] == self && [area userInfo][@"Row"])
             [self removeTrackingArea: area];
     }
 }
@@ -266,7 +241,7 @@
 - (void) setRowHover: (NSInteger) row
 {
     NSAssert([fDefaults boolForKey: @"SmallView"], @"cannot set a hover row when not in compact view");
-    
+
     fMouseRow = row;
     if (row >= 0)
         [self setNeedsDisplayInRect: [self rectOfRow: row]];
@@ -296,12 +271,12 @@
 - (void) mouseEntered: (NSEvent *) event
 {
     NSDictionary * dict = (NSDictionary *)[event userData];
-    
+
     NSNumber * row;
-    if ((row = [dict objectForKey: @"Row"]))
+    if ((row = dict[@"Row"]))
     {
         NSInteger rowVal = [row integerValue];
-        NSString * type = [dict objectForKey: @"Type"];
+        NSString * type = dict[@"Type"];
         if ([type isEqualToString: @"Action"])
             fMouseActionRow = rowVal;
         else if ([type isEqualToString: @"Control"])
@@ -314,7 +289,7 @@
             if (![fDefaults boolForKey: @"SmallView"])
                 return;
         }
-        
+
         [self setNeedsDisplayInRect: [self rectOfRow: rowVal]];
     }
 }
@@ -322,11 +297,11 @@
 - (void) mouseExited: (NSEvent *) event
 {
     NSDictionary * dict = (NSDictionary *)[event userData];
-    
+
     NSNumber * row;
-    if ((row = [dict objectForKey: @"Row"]))
+    if ((row = dict[@"Row"]))
     {
-        NSString * type = [dict objectForKey: @"Type"];
+        NSString * type = dict[@"Type"];
         if ([type isEqualToString: @"Action"])
             fMouseActionRow = -1;
         else if ([type isEqualToString: @"Control"])
@@ -339,7 +314,7 @@
             if (![fDefaults boolForKey: @"SmallView"])
                 return;
         }
-        
+
         [self setNeedsDisplayInRect: [self rectOfRow: [row integerValue]]];
     }
 }
@@ -354,10 +329,10 @@
 
 - (void) outlineViewItemDidExpand: (NSNotification *) notification
 {
-    NSInteger value = [[[notification userInfo] objectForKey: @"NSObject"] groupIndex];
+    NSInteger value = [[notification userInfo][@"NSObject"] groupIndex];
     if (value < 0)
         value = MAX_GROUP;
-    
+
     if ([fCollapsedGroups containsIndex: value])
     {
         [fCollapsedGroups removeIndex: value];
@@ -367,10 +342,10 @@
 
 - (void) outlineViewItemDidCollapse: (NSNotification *) notification
 {
-    NSInteger value = [[[notification userInfo] objectForKey: @"NSObject"] groupIndex];
+    NSInteger value = [[notification userInfo][@"NSObject"] groupIndex];
     if (value < 0)
         value = MAX_GROUP;
-    
+
     [fCollapsedGroups addIndex: value];
     [[NSNotificationCenter defaultCenter] postNotificationName: @"OutlineExpandCollapse" object: self];
 }
@@ -379,51 +354,38 @@
 {
     NSPoint point = [self convertPoint: [event locationInWindow] fromView: nil];
     const NSInteger row = [self rowAtPoint: point];
-    
+
     //check to toggle group status before anything else
     if ([self pointInGroupStatusRect: point])
     {
         [fDefaults setBool: ![fDefaults boolForKey: @"DisplayGroupRowRatio"] forKey: @"DisplayGroupRowRatio"];
         [self setGroupStatusColumns];
-        
+
         return;
     }
-    
+
     const BOOL pushed = row != -1 && (fMouseActionRow == row || fMouseRevealRow == row || fMouseControlRow == row);
-    
+
     //if pushing a button, don't change the selected rows
     if (pushed)
-        fSelectedValues = [[self selectedValues] retain];
-    
+        fSelectedValues = [self selectedValues];
+
     [super mouseDown: event];
-    
-    [fSelectedValues release];
+
     fSelectedValues = nil;
-    
+
     //avoid weird behavior when showing menu by doing this after mouse down
     if (row != -1 && fMouseActionRow == row)
     {
-        if (![NSApp isOnLionOrBetter])
-        {
-            fActionPushedRow = row;
-            [self setNeedsDisplayInRect: [self rectOfRow: row]]; //ensure button is pushed down
-        }
-        
         #warning maybe make appear on mouse down
         [self displayTorrentActionPopoverForEvent: event];
-        
-        if (![NSApp isOnLionOrBetter])
-        {
-            fActionPushedRow = -1;
-            [self setNeedsDisplayInRect: [self rectOfRow: row]];
-        }
     }
     else if (!pushed && [event clickCount] == 2) //double click
     {
         id item = nil;
         if (row != -1)
             item = [self itemAtRow: row];
-        
+
         if (!item || [item isKindOfClass: [Torrent class]])
             [fController showInfo: nil];
         else
@@ -440,7 +402,7 @@
 - (void) selectValues: (NSArray *) values
 {
     NSMutableIndexSet * indexSet = [NSMutableIndexSet indexSet];
-    
+
     for (id item in values)
     {
         if ([item isKindOfClass: [Torrent class]])
@@ -463,7 +425,7 @@
             }
         }
     }
-    
+
     [self selectRowIndexes: indexSet byExtendingSelection: NO];
 }
 
@@ -471,10 +433,10 @@
 {
     NSIndexSet * selectedIndexes = [self selectedRowIndexes];
     NSMutableArray * values = [NSMutableArray arrayWithCapacity: [selectedIndexes count]];
-    
+
     for (NSUInteger i = [selectedIndexes firstIndex]; i != NSNotFound; i = [selectedIndexes indexGreaterThanIndex: i])
         [values addObject: [self itemAtRow: i]];
-    
+
     return values;
 }
 
@@ -482,7 +444,7 @@
 {
     NSIndexSet * selectedIndexes = [self selectedRowIndexes];
     NSMutableArray * torrents = [NSMutableArray arrayWithCapacity: [selectedIndexes count]]; //take a shot at guessing capacity
-    
+
     for (NSUInteger i = [selectedIndexes firstIndex]; i != NSNotFound; i = [selectedIndexes indexGreaterThanIndex: i])
     {
         id item = [self itemAtRow: i];
@@ -496,7 +458,7 @@
                 i +=[groupTorrents count];
         }
     }
-    
+
     return torrents;
 }
 
@@ -527,7 +489,7 @@
 - (void) keyDown: (NSEvent *) event
 {
     const unichar firstChar = [[event charactersIgnoringModifiers] characterAtIndex: 0];
-    
+
     if (firstChar == 'f' && [event modifierFlags] & NSAlternateKeyMask && [event modifierFlags] & NSCommandKeyMask)
         [fController focusFilterField];
     else if (firstChar == ' ')
@@ -548,14 +510,15 @@
     NSURL * url;
     if ((url = [NSURL URLFromPasteboard: [NSPasteboard generalPasteboard]]))
         [fController openURL: [url absoluteString]];
-    else if ([NSApp isOnLionOrBetter])
+    else
     {
-        NSArray * items = [[NSPasteboard generalPasteboard] readObjectsForClasses: [NSArray arrayWithObject: [NSString class]] options: nil];
+        NSArray * items = [[NSPasteboard generalPasteboard] readObjectsForClasses: @[[NSString class]] options: nil];
         if (items)
         {
-            NSDataDetector * detector = [NSDataDetectorLion dataDetectorWithTypes: NSTextCheckingTypeLink error: nil];
-            for (NSString * pbItem in items)
+            NSDataDetector * detector = [NSDataDetector dataDetectorWithTypes: NSTextCheckingTypeLink error: nil];
+            for (__strong NSString * pbItem in items)
             {
+                pbItem = [pbItem stringByTrimmingCharactersInSet: [NSCharacterSet whitespaceAndNewlineCharacterSet]];
                 if ([pbItem rangeOfString: @"magnet:" options: (NSAnchoredSearch | NSCaseInsensitiveSearch)].location != NSNotFound)
                     [fController openURL: pbItem];
                 else
@@ -572,45 +535,43 @@
 - (BOOL) validateMenuItem: (NSMenuItem *) menuItem
 {
     SEL action = [menuItem action];
-    
+
     if (action == @selector(paste:))
     {
         if ([[[NSPasteboard generalPasteboard] types] containsObject: NSURLPboardType])
             return YES;
-        
-        if ([NSApp isOnLionOrBetter])
+
+        NSArray * items = [[NSPasteboard generalPasteboard] readObjectsForClasses: @[[NSString class]] options: nil];
+        if (items)
         {
-            NSArray * items = [[NSPasteboard generalPasteboard] readObjectsForClasses: [NSArray arrayWithObject: [NSString class]] options: nil];
-            if (items)
+            NSDataDetector * detector = [NSDataDetector dataDetectorWithTypes: NSTextCheckingTypeLink error: nil];
+            for (__strong NSString * pbItem in items)
             {
-                NSDataDetector * detector = [NSDataDetectorLion dataDetectorWithTypes: NSTextCheckingTypeLink error: nil];
-                for (NSString * pbItem in items)
-                {
-                    if (([pbItem rangeOfString: @"magnet:" options: (NSAnchoredSearch | NSCaseInsensitiveSearch)].location != NSNotFound)
-                        || [detector firstMatchInString: pbItem options: 0 range: NSMakeRange(0, [pbItem length])])
-                        return YES;
-                }
+                pbItem = [pbItem stringByTrimmingCharactersInSet: [NSCharacterSet whitespaceAndNewlineCharacterSet]];
+                if (([pbItem rangeOfString: @"magnet:" options: (NSAnchoredSearch | NSCaseInsensitiveSearch)].location != NSNotFound)
+                    || [detector firstMatchInString: pbItem options: 0 range: NSMakeRange(0, [pbItem length])])
+                    return YES;
             }
         }
-        
-        return NO;
+
+    return NO;
     }
-    
+
     return YES;
 }
 
 - (void) toggleControlForTorrent: (Torrent *) torrent
 {
     if ([torrent isActive])
-        [fController stopTorrents: [NSArray arrayWithObject: torrent]];
+        [fController stopTorrents: @[torrent]];
     else
     {
         if ([NSEvent modifierFlags] & NSAlternateKeyMask)
-            [fController resumeTorrentsNoWait: [NSArray arrayWithObject: torrent]];
+            [fController resumeTorrentsNoWait: @[torrent]];
         else if ([torrent waitingToStart])
-            [fController stopTorrents: [NSArray arrayWithObject: torrent]];
+            [fController stopTorrents: @[torrent]];
         else
-            [fController resumeTorrents: [NSArray arrayWithObject: torrent]];
+            [fController resumeTorrents: @[torrent]];
     }
 }
 
@@ -619,47 +580,24 @@
     const NSInteger row = [self rowAtPoint: [self convertPoint: [event locationInWindow] fromView: nil]];
     if (row < 0)
         return;
-    
+
     const NSRect rect = [fTorrentCell iconRectForBounds: [self rectOfRow: row]];
-    
-    if ([NSApp isOnLionOrBetter])
-    {
-        if (fActionPopoverShown)
-            return;
-        
-        Torrent * torrent = [self itemAtRow: row];
-        
-        NSPopover * popover = [[NSPopoverLion alloc] init];
-        [popover setBehavior: NSPopoverBehaviorTransient];
-        InfoOptionsViewController * infoViewController = [[InfoOptionsViewController alloc] init];
-        [popover setContentViewController: infoViewController];
-        [popover setDelegate: self];
-        
-        [popover showRelativeToRect: rect ofView: self preferredEdge: NSMaxYEdge];
-        [infoViewController setInfoForTorrents: [NSArray arrayWithObject: torrent]];
-        [infoViewController updateInfo];
-        
-        [infoViewController release];
-        [popover release];
-    }
-    else
-    {
-        //update file action menu
-        fMenuTorrent = [[self itemAtRow: row] retain];
-        
-        //update global limit check
-        [fGlobalLimitItem setState: [fMenuTorrent usesGlobalSpeedLimit] ? NSOnState : NSOffState];
-        
-        //place menu below button
-        NSPoint location = rect.origin;
-        location.y += NSHeight(rect) + 5.0;
-        
-        location = [self convertPoint: location toView: self];
-        [fActionMenu popUpMenuPositioningItem: nil atLocation: location inView: self];
-        
-        [fMenuTorrent release];
-        fMenuTorrent = nil;
-    }
+
+    if (fActionPopoverShown)
+        return;
+
+    Torrent * torrent = [self itemAtRow: row];
+
+    NSPopover * popover = [[NSPopover alloc] init];
+    [popover setBehavior: NSPopoverBehaviorTransient];
+    InfoOptionsViewController * infoViewController = [[InfoOptionsViewController alloc] init];
+    [popover setContentViewController: infoViewController];
+    [popover setDelegate: self];
+
+    [popover showRelativeToRect: rect ofView: self preferredEdge: NSMaxYEdge];
+    [infoViewController setInfoForTorrents: @[torrent]];
+    [infoViewController updateInfo];
+
 }
 
 //don't show multiple popovers when clicking the gear button repeatedly
@@ -679,7 +617,7 @@
     //this method seems to be called when it shouldn't be
     if (!fMenuTorrent || ![menu supermenu])
         return;
-    
+
     if (menu == fUploadMenu || menu == fDownloadMenu)
     {
         NSMenuItem * item;
@@ -687,27 +625,26 @@
         {
             const NSInteger speedLimitActionValue[] = { 0, 5, 10, 20, 30, 40, 50, 75, 100, 150, 200, 250, 500,
                                                         750, 1000, 1500, 2000, -1 };
-            
+
             for (NSInteger i = 0; speedLimitActionValue[i] != -1; i++)
             {
                 item = [[NSMenuItem alloc] initWithTitle: [NSString stringWithFormat: NSLocalizedString(@"%d KB/s",
                         "Action menu -> upload/download limit"), speedLimitActionValue[i]] action: @selector(setQuickLimit:)
                         keyEquivalent: @""];
                 [item setTarget: self];
-                [item setRepresentedObject: [NSNumber numberWithInt: speedLimitActionValue[i]]];
+                [item setRepresentedObject: @(speedLimitActionValue[i])];
                 [menu addItem: item];
-                [item release];
             }
         }
-        
+
         const BOOL upload = menu == fUploadMenu;
         const BOOL limit = [fMenuTorrent usesSpeedLimit: upload];
-        
+
         item = [menu itemWithTag: ACTION_MENU_LIMIT_TAG];
         [item setState: limit ? NSOnState : NSOffState];
         [item setTitle: [NSString stringWithFormat: NSLocalizedString(@"Limit (%d KB/s)",
                             "torrent action menu -> upload/download limit"), [fMenuTorrent speedLimit: upload]]];
-        
+
         item = [menu itemWithTag: ACTION_MENU_UNLIMITED_TAG];
         [item setState: !limit ? NSOnState : NSOffState];
     }
@@ -717,41 +654,40 @@
         if ([menu numberOfItems] == 4)
         {
             const float ratioLimitActionValue[] = { 0.25, 0.5, 0.75, 1.0, 1.5, 2.0, 3.0, -1.0 };
-            
+
             for (NSInteger i = 0; ratioLimitActionValue[i] != -1.0; i++)
             {
                 item = [[NSMenuItem alloc] initWithTitle: [NSString localizedStringWithFormat: @"%.2f", ratioLimitActionValue[i]]
                         action: @selector(setQuickRatio:) keyEquivalent: @""];
                 [item setTarget: self];
-                [item setRepresentedObject: [NSNumber numberWithFloat: ratioLimitActionValue[i]]];
+                [item setRepresentedObject: @(ratioLimitActionValue[i])];
                 [menu addItem: item];
-                [item release];
             }
         }
-        
+
         const tr_ratiolimit mode = [fMenuTorrent ratioSetting];
-        
+
         item = [menu itemWithTag: ACTION_MENU_LIMIT_TAG];
         [item setState: mode == TR_RATIOLIMIT_SINGLE ? NSOnState : NSOffState];
         [item setTitle: [NSString localizedStringWithFormat: NSLocalizedString(@"Stop at Ratio (%.2f)",
             "torrent action menu -> ratio stop"), [fMenuTorrent ratioLimit]]];
-        
+
         item = [menu itemWithTag: ACTION_MENU_UNLIMITED_TAG];
         [item setState: mode == TR_RATIOLIMIT_UNLIMITED ? NSOnState : NSOffState];
-        
+
         item = [menu itemWithTag: ACTION_MENU_GLOBAL_TAG];
         [item setState: mode == TR_RATIOLIMIT_GLOBAL ? NSOnState : NSOffState];
     }
     else if (menu == fPriorityMenu)
     {
         const tr_priority_t priority = [fMenuTorrent priority];
-        
+
         NSMenuItem * item = [menu itemWithTag: ACTION_MENU_PRIORITY_HIGH_TAG];
         [item setState: priority == TR_PRI_HIGH ? NSOnState : NSOffState];
-        
+
         item = [menu itemWithTag: ACTION_MENU_PRIORITY_NORMAL_TAG];
         [item setState: priority == TR_PRI_NORMAL ? NSOnState : NSOffState];
-        
+
         item = [menu itemWithTag: ACTION_MENU_PRIORITY_LOW_TAG];
         [item setState: priority == TR_PRI_LOW ? NSOnState : NSOffState];
     }
@@ -762,7 +698,7 @@
 {
     const BOOL limit = [sender tag] == ACTION_MENU_LIMIT_TAG;
     [fMenuTorrent setUseSpeedLimit: limit upload: [sender menu] == fUploadMenu];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptions" object: nil];
 }
 
@@ -771,14 +707,14 @@
     const BOOL upload = [sender menu] == fUploadMenu;
     [fMenuTorrent setUseSpeedLimit: YES upload: upload];
     [fMenuTorrent setSpeedLimit: [[sender representedObject] intValue] upload: upload];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptions" object: nil];
 }
 
 - (void) setGlobalLimit: (id) sender
 {
     [fMenuTorrent setUseGlobalSpeedLimit: [(NSButton *)sender state] != NSOnState];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptions" object: nil];
 }
 
@@ -799,9 +735,9 @@
         default:
             return;
     }
-    
+
     [fMenuTorrent setRatioSetting: mode];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptions" object: nil];
 }
 
@@ -809,7 +745,7 @@
 {
     [fMenuTorrent setRatioSetting: TR_RATIOLIMIT_SINGLE];
     [fMenuTorrent setRatioLimit: [[sender representedObject] floatValue]];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateOptions" object: nil];
 }
 
@@ -829,10 +765,11 @@
             break;
         default:
             NSAssert1(NO, @"Unknown priority: %ld", [sender tag]);
+            priority = TR_PRI_NORMAL;
     }
-    
+
     [fMenuTorrent setPriority: priority];
-    
+
     [[NSNotificationCenter defaultCenter] postNotificationName: @"UpdateUI" object: nil];
 }
 
@@ -840,15 +777,14 @@
 {
     NSMutableArray * progressMarks = [NSMutableArray arrayWithCapacity: 16];
     for (NSAnimationProgress i = 0.0625; i <= 1.0; i += 0.0625)
-        [progressMarks addObject: [NSNumber numberWithFloat: i]];
-    
+        [progressMarks addObject: @(i)];
+
     //this stops a previous animation
-    [fPiecesBarAnimation release];
     fPiecesBarAnimation = [[NSAnimation alloc] initWithDuration: TOGGLE_PROGRESS_SECONDS animationCurve: NSAnimationEaseIn];
     [fPiecesBarAnimation setAnimationBlockingMode: NSAnimationNonblocking];
     [fPiecesBarAnimation setProgressMarks: progressMarks];
     [fPiecesBarAnimation setDelegate: self];
-    
+
     [fPiecesBarAnimation startAnimation];
 }
 
@@ -856,7 +792,6 @@
 {
     if (animation == fPiecesBarAnimation)
     {
-        [fPiecesBarAnimation release];
         fPiecesBarAnimation = nil;
     }
 }
@@ -869,7 +804,7 @@
             fPiecesBarPercent = progress;
         else
             fPiecesBarPercent = 1.0 - progress;
-        
+
         [self setNeedsDisplay: YES];
     }
 }
@@ -879,6 +814,24 @@
     return fPiecesBarPercent;
 }
 
+- (void) selectAndScrollToRow: (NSInteger) row
+{
+    NSParameterAssert(row >= 0);
+    NSParameterAssert(row < [self numberOfRows]);
+
+    [self selectRowIndexes: [NSIndexSet indexSetWithIndex: row] byExtendingSelection: NO];
+
+    const NSRect rowRect = [self rectOfRow: row];
+    const NSRect viewRect = [[self superview] frame];
+
+    NSPoint scrollOrigin = rowRect.origin;
+    scrollOrigin.y += (rowRect.size.height - viewRect.size.height) / 2;
+    if (scrollOrigin.y < 0)
+        scrollOrigin.y = 0;
+
+    [[[self superview] animator] setBoundsOrigin: scrollOrigin];
+}
+
 @end
 
 @implementation TorrentTableView (Private)
@@ -888,8 +841,8 @@
     NSInteger row = [self rowAtPoint: point];
     if (row < 0 || [[self itemAtRow: row] isKindOfClass: [Torrent class]])
         return NO;
-    
-    NSString * ident = [[[self tableColumns] objectAtIndex: [self columnAtPoint: point]] identifier];
+
+    NSString * ident = [[self tableColumns][[self columnAtPoint: point]] identifier];
     return [ident isEqualToString: @"UL"] || [ident isEqualToString: @"UL Image"]
             || [ident isEqualToString: @"DL"] || [ident isEqualToString: @"DL Image"];
 }
@@ -897,7 +850,7 @@
 - (void) setGroupStatusColumns
 {
     const BOOL ratio = [fDefaults boolForKey: @"DisplayGroupRowRatio"];
-    
+
     [[self tableColumnWithIdentifier: @"DL"] setHidden: ratio];
     [[self tableColumnWithIdentifier: @"DL Image"] setHidden: ratio];
 }
