@@ -1,6 +1,4 @@
 /******************************************************************************
- * $Id: TrackerTableView.m 13162 2012-01-14 17:12:04Z livings124 $
- * 
  * Copyright (c) 2008-2012 Transmission authors and contributors
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -50,40 +48,40 @@
     NSIndexSet * indexes = [self selectedRowIndexes];
     for (NSUInteger i = [indexes firstIndex]; i != NSNotFound; i = [indexes indexGreaterThanIndex: i])
     {
-        id item = [fTrackers objectAtIndex: i];
+        id item = fTrackers[i];
         if (![item isKindOfClass: [TrackerNode class]])
         {
-            for (++i; i < [fTrackers count] && [[fTrackers objectAtIndex: i] isKindOfClass: [TrackerNode class]]; ++i)
-                [addresses addObject: [(TrackerNode *)[fTrackers objectAtIndex: i] fullAnnounceAddress]];
+            for (++i; i < [fTrackers count] && [fTrackers[i] isKindOfClass: [TrackerNode class]]; ++i)
+                [addresses addObject: [(TrackerNode *)fTrackers[i] fullAnnounceAddress]];
             --i;
         }
         else
             [addresses addObject: [(TrackerNode *)item fullAnnounceAddress]];
     }
-    
+
     NSString * text = [addresses componentsJoinedByString: @"\n"];
-    
+
     NSPasteboard * pb = [NSPasteboard generalPasteboard];
     [pb clearContents];
-    [pb writeObjects: [NSArray arrayWithObject: text]];
+    [pb writeObjects: @[text]];
 }
 
 - (void) paste: (id) sender
 {
     NSAssert(fTorrent != nil, @"no torrent but trying to paste; should not be able to call this method");
-    
+
     BOOL added = NO;
-    
-    NSArray * items = [[NSPasteboard generalPasteboard] readObjectsForClasses: [NSArray arrayWithObject: [NSString class]] options: nil];
+
+    NSArray * items = [[NSPasteboard generalPasteboard] readObjectsForClasses: @[[NSString class]] options: nil];
     NSAssert(items != nil, @"no string items to paste; should not be able to call this method");
-    
+
     for (NSString * pbItem in items)
     {
         for (NSString * item in [pbItem componentsSeparatedByString: @"\n"])
             if ([fTorrent addTrackerToNewTier: item])
                 added = YES;
     }
-    
+
     //none added
     if (!added)
         NSBeep();
@@ -92,13 +90,13 @@
 - (BOOL) validateMenuItem: (NSMenuItem *) menuItem
 {
     const SEL action = [menuItem action];
-    
+
     if (action == @selector(copy:))
         return [self numberOfSelectedRows] > 0;
-    
+
     if (action == @selector(paste:))
-        return fTorrent && [[NSPasteboard generalPasteboard] canReadObjectForClasses: [NSArray arrayWithObject: [NSString class]] options: nil];
-    
+        return fTorrent && [[NSPasteboard generalPasteboard] canReadObjectForClasses: @[[NSString class]] options: nil];
+
     return YES;
 }
 
