@@ -20,6 +20,10 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef void
 dht_callback(void *closure, int event,
              const unsigned char *info_hash,
@@ -35,7 +39,7 @@ extern FILE *dht_debug;
 
 int dht_init(int s, int s6, const unsigned char *id, const unsigned char *v);
 int dht_insert_node(const unsigned char *id, struct sockaddr *sa, int salen);
-int dht_ping_node(struct sockaddr *sa, int salen);
+int dht_ping_node(const struct sockaddr *sa, int salen);
 int dht_periodic(const void *buf, size_t buflen,
                  const struct sockaddr *from, int fromlen,
                  time_t *tosleep, dht_callback *callback, void *closure);
@@ -50,9 +54,15 @@ int dht_get_nodes(struct sockaddr_in *sin, int *num,
 int dht_uninit(void);
 
 /* This must be provided by the user. */
+int dht_sendto(int sockfd, const void *buf, int len, int flags,
+               const struct sockaddr *to, int tolen);
 int dht_blacklisted(const struct sockaddr *sa, int salen);
 void dht_hash(void *hash_return, int hash_size,
               const void *v1, int len1,
               const void *v2, int len2,
               const void *v3, int len3);
 int dht_random_bytes(void *buf, size_t size);
+
+#ifdef __cplusplus
+}
+#endif
